Module: Google::Apis::AndroidmanagementV1

Defined in:
lib/google/apis/androidmanagement_v1.rb,
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/service.rb,
lib/google/apis/androidmanagement_v1/gem_version.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Android Management API

The Android Management API provides remote enterprise management of Android devices and apps.

Defined Under Namespace

Classes: AdbShellCommandEvent, AdbShellInteractiveEvent, AddEsimParams, AdvancedSecurityOverrides, AlwaysOnVpnPackage, AndroidManagementService, ApiLevelCondition, ApnPolicy, ApnSetting, AppProcessInfo, AppProcessStartEvent, AppTrackInfo, AppVersion, Application, ApplicationEvent, ApplicationPermission, ApplicationPolicy, ApplicationPolicyChange, ApplicationReport, ApplicationReportingSettings, ApplicationSigningKeyCert, BackupServiceToggledEvent, BatchUsageLogEvents, BlockAction, CertAuthorityInstalledEvent, CertAuthorityRemovedEvent, CertValidationFailureEvent, ChoosePrivateKeyRule, ClearAppsDataParams, ClearAppsDataStatus, Command, CommonCriteriaModeInfo, ComplianceRule, ConnectEvent, ContactInfo, ContentProviderEndpoint, CrossProfilePolicies, CryptoSelfTestCompletedEvent, CustomAppConfig, Date, DefaultApplication, DefaultApplicationContext, DefaultApplicationInfo, DefaultApplicationSetting, DefaultApplicationSettingAttempt, Device, DeviceConnectivityManagement, DeviceRadioState, DeviceSettings, DisplayProp, DisplaySettings, DnsEvent, DpcMigrationInfo, Eid, EidInfo, Empty, EnrollmentCompleteEvent, EnrollmentToken, Enterprise, EnterpriseUpgradeEvent, EsimCommandStatus, EsimInfo, EuiccChipInfo, ExtensionConfig, ExternalData, FilePulledEvent, FilePushedEvent, FreezePeriod, GenerateEnterpriseUpgradeUrlRequest, GenerateEnterpriseUpgradeUrlResponse, GoogleAuthenticationSettings, HardwareInfo, HardwareStatus, InstallConstraint, InternalErrorDetails, IssueCommandResponse, KeyDestructionEvent, KeyGeneratedEvent, KeyImportEvent, KeyIntegrityViolationEvent, KeyedAppState, KeyguardDismissAuthAttemptEvent, KeyguardDismissedEvent, KeyguardSecuredEvent, KioskCustomization, LaunchAppAction, ListDevicesResponse, ListEnrollmentTokensResponse, ListEnterprisesResponse, ListMigrationTokensResponse, ListOperationsResponse, ListPoliciesResponse, ListWebAppsResponse, Location, LogBufferSizeCriticalEvent, LoggingStartedEvent, LoggingStoppedEvent, LostModeLocationEvent, LostModeOutgoingPhoneCallEvent, ManagedConfigurationTemplate, ManagedProperty, ManagedPropertyEntry, MediaMountEvent, MediaUnmountEvent, MemoryEvent, MemoryInfo, MigrationToken, ModifyPolicyApplicationsRequest, ModifyPolicyApplicationsResponse, NetworkInfo, NonComplianceDetail, NonComplianceDetailCondition, OncCertificateProvider, OncWifiContext, Operation, OsShutdownEvent, OsStartupEvent, PackageNameList, PasswordPoliciesContext, PasswordRequirements, PerAppResult, PermissionGrant, PersistentPreferredActivity, PersonalApplicationPolicy, PersonalUsagePolicies, Policy, PolicyEnforcementRule, PostureDetail, PowerManagementEvent, PreferentialNetworkServiceConfig, PreferentialNetworkServiceSettings, ProvisioningInfo, ProxyInfo, RemoteLockEvent, RemoveEsimParams, RemovePolicyApplicationsRequest, RemovePolicyApplicationsResponse, RequestDeviceInfoParams, RequestDeviceInfoStatus, Role, ScreenBrightnessSettings, ScreenTimeoutSettings, SecurityPosture, SetupAction, SigninDetail, SignupUrl, SoftwareInfo, SpecificNonComplianceContext, StartLostModeParams, StartLostModeStatus, Status, StatusReportingSettings, StopLostModeParams, StopLostModeStatus, StopLostModeUserAttemptEvent, SystemUpdate, SystemUpdateInfo, TelephonyInfo, TermsAndConditions, UsageLog, UsageLogEvent, User, UserFacingMessage, WebApp, WebAppIcon, WebToken, WifiRoamingPolicy, WifiRoamingSetting, WifiSsid, WifiSsidPolicy, WipeAction, WipeFailureEvent, WipeParams, WorkAccountSetupConfig

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-androidmanagement_v1 gem

"0.110.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260219"
VERSION =

Version of the Android Management API this client connects to. This is NOT the gem version.

'V1'
AUTH_ANDROIDMANAGEMENT =

Manage Android devices and apps for your customers

'https://www.googleapis.com/auth/androidmanagement'