Class: Google::Apis::AndroidmanagementV1::AdvancedSecurityOverrides

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Advanced security settings. In most cases, setting these is not needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvancedSecurityOverrides

Returns a new instance of AdvancedSecurityOverrides.



147
148
149
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_criteria_modeString

Controls Common Criteria Mode—security standards defined in the Common Criteria for Information Technology Security Evaluation (https://www. commoncriteriaportal.org/) (CC). Enabling Common Criteria Mode increases certain security components on a device, see CommonCriteriaMode for details. Warning: Common Criteria Mode enforces a strict security model typically only required for IT products used in national security systems and other highly sensitive organizations. Standard device use may be affected. Only enabled if required. If Common Criteria Mode is turned off after being enabled previously, all user-configured Wi-Fi networks may be lost and any enterprise-configured Wi-Fi networks that require user input may need to be reconfigured. Corresponds to the JSON property commonCriteriaMode

Returns:

  • (String)


100
101
102
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 100

def common_criteria_mode
  @common_criteria_mode
end

#content_protection_policyString

Optional. Controls whether content protection, which scans for deceptive apps, is enabled. This is supported on Android 15 and above. Corresponds to the JSON property contentProtectionPolicy

Returns:

  • (String)


106
107
108
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 106

def content_protection_policy
  @content_protection_policy
end

#developer_settingsString

Controls access to developer settings: developer options and safe boot. Replaces safeBootDisabled (deprecated) and debuggingFeaturesAllowed ( deprecated). On personally-owned devices with a work profile, setting this policy will not disable safe boot. In this case, a NonComplianceDetail with MANAGEMENT_MODE is reported. Corresponds to the JSON property developerSettings

Returns:

  • (String)


115
116
117
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 115

def developer_settings
  @developer_settings
end

#google_play_protect_verify_appsString

Whether Google Play Protect verification (https://support.google.com/accounts/ answer/2812853) is enforced. Replaces ensureVerifyAppsEnabled (deprecated). Corresponds to the JSON property googlePlayProtectVerifyApps

Returns:

  • (String)


121
122
123
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 121

def google_play_protect_verify_apps
  @google_play_protect_verify_apps
end

#mte_policyString

Optional. Controls Memory Tagging Extension (MTE) (https://source.android.com/ docs/security/test/memory-safety/arm-mte) on the device. The device needs to be rebooted to apply changes to the MTE policy. On Android 15 and above, a NonComplianceDetail with PENDING is reported if the policy change is pending a device reboot. Corresponds to the JSON property mtePolicy

Returns:

  • (String)


130
131
132
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 130

def mte_policy
  @mte_policy
end

#personal_apps_that_can_read_work_notificationsArray<String>

Personal apps that can read work profile notifications using a NotificationListenerService (https://developer.android.com/reference/android/ service/notification/NotificationListenerService). By default, no personal apps (aside from system apps) can read work notifications. Each value in the list must be a package name. Corresponds to the JSON property personalAppsThatCanReadWorkNotifications

Returns:

  • (Array<String>)


139
140
141
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 139

def personal_apps_that_can_read_work_notifications
  @personal_apps_that_can_read_work_notifications
end

#untrusted_apps_policyString

The policy for untrusted apps (apps from unknown sources) enforced on the device. Replaces install_unknown_sources_allowed (deprecated). Corresponds to the JSON property untrustedAppsPolicy

Returns:

  • (String)


145
146
147
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 145

def untrusted_apps_policy
  @untrusted_apps_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



152
153
154
155
156
157
158
159
160
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 152

def update!(**args)
  @common_criteria_mode = args[:common_criteria_mode] if args.key?(:common_criteria_mode)
  @content_protection_policy = args[:content_protection_policy] if args.key?(:content_protection_policy)
  @developer_settings = args[:developer_settings] if args.key?(:developer_settings)
  @google_play_protect_verify_apps = args[:google_play_protect_verify_apps] if args.key?(:google_play_protect_verify_apps)
  @mte_policy = args[:mte_policy] if args.key?(:mte_policy)
  @personal_apps_that_can_read_work_notifications = args[:personal_apps_that_can_read_work_notifications] if args.key?(:personal_apps_that_can_read_work_notifications)
  @untrusted_apps_policy = args[:untrusted_apps_policy] if args.key?(:untrusted_apps_policy)
end