Class: Google::Apis::AndroidmanagementV1::AndroidManagementService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AndroidmanagementV1::AndroidManagementService
- Defined in:
- lib/google/apis/androidmanagement_v1/service.rb
Overview
Android Management API
The Android Management API provides remote enterprise management of Android devices and apps.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://androidmanagement.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_enterprise_device_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_enterprise(enterprise_object = nil, agreement_accepted: nil, enterprise_token: nil, project_id: nil, signup_url_name: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Enterprise
Creates an enterprise.
-
#create_enterprise_enrollment_token(parent, enrollment_token_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::EnrollmentToken
Creates an enrollment token for a given enterprise.
-
#create_enterprise_migration_token(parent, migration_token_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::MigrationToken
Creates a migration token, to migrate an existing device from being managed by the EMM's Device Policy Controller (DPC) to being managed by the Android Management API.
-
#create_enterprise_web_app(parent, web_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebApp
Creates a web app.
-
#create_enterprise_web_token(parent, web_token_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebToken
Creates a web token to access an embeddable managed Google Play web UI for a given enterprise.
-
#create_signup_url(admin_email: nil, allowed_domains: nil, callback_url: nil, project_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::SignupUrl
Creates an enterprise signup URL.
-
#delete_enterprise(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Permanently deletes an enterprise and all accounts and data associated with it.
-
#delete_enterprise_device(name, wipe_data_flags: nil, wipe_reason_message: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes a device.
-
#delete_enterprise_enrollment_token(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes an enrollment token.
-
#delete_enterprise_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes a policy.
-
#delete_enterprise_web_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes a web app.
-
#generate_enterprise_upgrade_url(name, generate_enterprise_upgrade_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlResponse
Generates an enterprise upgrade URL to upgrade an existing managed Google Play Accounts enterprise to a managed Google domain.
-
#get_enterprise(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Enterprise
Gets an enterprise.
-
#get_enterprise_application(name, language_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Application
Gets info about an application.
-
#get_enterprise_device(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Device
Gets a device.
-
#get_enterprise_device_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Operation
Gets the latest state of a long-running operation.
-
#get_enterprise_enrollment_token(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::EnrollmentToken
Gets an active, unexpired enrollment token.
-
#get_enterprise_migration_token(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::MigrationToken
Gets a migration token.
-
#get_enterprise_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Policy
Gets a policy.
-
#get_enterprise_web_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebApp
Gets a web app.
-
#get_provisioning_info(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ProvisioningInfo
Get the device provisioning information by the identifier provided in the sign- in url.
-
#initialize ⇒ AndroidManagementService
constructor
A new instance of AndroidManagementService.
-
#issue_enterprise_device_command(name, command_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Operation
Issues a command to a device.
-
#list_enterprise_device_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_enterprise_devices(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListDevicesResponse
Lists devices for a given enterprise.
-
#list_enterprise_enrollment_tokens(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListEnrollmentTokensResponse
Lists active, unexpired enrollment tokens for a given enterprise.
-
#list_enterprise_migration_tokens(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListMigrationTokensResponse
Lists migration tokens.
-
#list_enterprise_policies(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListPoliciesResponse
Lists policies for a given enterprise.
-
#list_enterprise_web_apps(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListWebAppsResponse
Lists web apps for a given enterprise.
-
#list_enterprises(page_size: nil, page_token: nil, project_id: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListEnterprisesResponse
Lists EMM-managed enterprises.
-
#modify_policy_applications(name, modify_policy_applications_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ModifyPolicyApplicationsResponse
Updates or creates applications in a policy.
-
#patch_enterprise(name, enterprise_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Enterprise
Updates an enterprise.
-
#patch_enterprise_device(name, device_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Device
Updates a device.
-
#patch_enterprise_policy(name, policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Policy
Updates or creates a policy.
-
#patch_enterprise_web_app(name, web_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebApp
Updates a web app.
-
#remove_policy_applications(name, remove_policy_applications_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsResponse
Removes applications in a policy.
Constructor Details
#initialize ⇒ AndroidManagementService
Returns a new instance of AndroidManagementService.
48 49 50 51 52 53 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-androidmanagement_v1', client_version: Google::Apis::AndroidmanagementV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_enterprise_device_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
537 538 539 540 541 542 543 544 545 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 537 def cancel_enterprise_device_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.response_representation = Google::Apis::AndroidmanagementV1::Empty::Representation command.response_class = Google::Apis::AndroidmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_enterprise(enterprise_object = nil, agreement_accepted: nil, enterprise_token: nil, project_id: nil, signup_url_name: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Enterprise
Creates an enterprise. This is the last step in the enterprise signup flow. See also: SigninDetail
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 96 def create_enterprise(enterprise_object = nil, agreement_accepted: nil, enterprise_token: nil, project_id: nil, signup_url_name: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/enterprises', ) command.request_representation = Google::Apis::AndroidmanagementV1::Enterprise::Representation command.request_object = enterprise_object command.response_representation = Google::Apis::AndroidmanagementV1::Enterprise::Representation command.response_class = Google::Apis::AndroidmanagementV1::Enterprise command.query['agreementAccepted'] = agreement_accepted unless agreement_accepted.nil? command.query['enterpriseToken'] = enterprise_token unless enterprise_token.nil? command.query['projectId'] = project_id unless project_id.nil? command.query['signupUrlName'] = signup_url_name unless signup_url_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_enterprise_enrollment_token(parent, enrollment_token_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::EnrollmentToken
Creates an enrollment token for a given enterprise. It's up to the caller's responsibility to manage the lifecycle of newly created tokens and deleting them when they're not intended to be used anymore.
650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 650 def create_enterprise_enrollment_token(parent, enrollment_token_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/enrollmentTokens', ) command.request_representation = Google::Apis::AndroidmanagementV1::EnrollmentToken::Representation command.request_object = enrollment_token_object command.response_representation = Google::Apis::AndroidmanagementV1::EnrollmentToken::Representation command.response_class = Google::Apis::AndroidmanagementV1::EnrollmentToken command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_enterprise_migration_token(parent, migration_token_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::MigrationToken
Creates a migration token, to migrate an existing device from being managed by the EMM's Device Policy Controller (DPC) to being managed by the Android Management API. See the guide (https://developers.google.com/android/ management/dpc-migration) for more details.
799 800 801 802 803 804 805 806 807 808 809 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 799 def create_enterprise_migration_token(parent, migration_token_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/migrationTokens', ) command.request_representation = Google::Apis::AndroidmanagementV1::MigrationToken::Representation command.request_object = migration_token_object command.response_representation = Google::Apis::AndroidmanagementV1::MigrationToken::Representation command.response_class = Google::Apis::AndroidmanagementV1::MigrationToken command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_enterprise_web_app(parent, web_app_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebApp
Creates a web app.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1110 def create_enterprise_web_app(parent, web_app_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/webApps', ) command.request_representation = Google::Apis::AndroidmanagementV1::WebApp::Representation command.request_object = web_app_object command.response_representation = Google::Apis::AndroidmanagementV1::WebApp::Representation command.response_class = Google::Apis::AndroidmanagementV1::WebApp command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_enterprise_web_token(parent, web_token_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebToken
Creates a web token to access an embeddable managed Google Play web UI for a given enterprise.
1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1281 def create_enterprise_web_token(parent, web_token_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/webTokens', ) command.request_representation = Google::Apis::AndroidmanagementV1::WebToken::Representation command.request_object = web_token_object command.response_representation = Google::Apis::AndroidmanagementV1::WebToken::Representation command.response_class = Google::Apis::AndroidmanagementV1::WebToken command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_signup_url(admin_email: nil, allowed_domains: nil, callback_url: nil, project_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::SignupUrl
Creates an enterprise signup URL.
1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1364 def create_signup_url(admin_email: nil, allowed_domains: nil, callback_url: nil, project_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/signupUrls', ) command.response_representation = Google::Apis::AndroidmanagementV1::SignupUrl::Representation command.response_class = Google::Apis::AndroidmanagementV1::SignupUrl command.query['adminEmail'] = admin_email unless admin_email.nil? command.query['allowedDomains'] = allowed_domains unless allowed_domains.nil? command.query['callbackUrl'] = callback_url unless callback_url.nil? command.query['projectId'] = project_id unless project_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_enterprise(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Permanently deletes an enterprise and all accounts and data associated with it. Warning: this will result in a cascaded deletion of all AM API devices associated with the deleted enterprise. Only available for EMM-managed enterprises.
134 135 136 137 138 139 140 141 142 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 134 def delete_enterprise(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Empty::Representation command.response_class = Google::Apis::AndroidmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_enterprise_device(name, wipe_data_flags: nil, wipe_reason_message: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes a device. This operation attempts to wipe the device but this is not guaranteed to succeed if the device is offline for an extended period. Deleted devices do not show up in enterprises.devices.list calls and a 404 is returned from enterprises.devices.get.
354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 354 def delete_enterprise_device(name, wipe_data_flags: nil, wipe_reason_message: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Empty::Representation command.response_class = Google::Apis::AndroidmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['wipeDataFlags'] = wipe_data_flags unless wipe_data_flags.nil? command.query['wipeReasonMessage'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_enterprise_enrollment_token(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes an enrollment token. This operation invalidates the token, preventing its future use.
684 685 686 687 688 689 690 691 692 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 684 def delete_enterprise_enrollment_token(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Empty::Representation command.response_class = Google::Apis::AndroidmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_enterprise_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes a policy. This operation is only permitted if no devices are currently referencing the policy.
905 906 907 908 909 910 911 912 913 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 905 def delete_enterprise_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Empty::Representation command.response_class = Google::Apis::AndroidmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_enterprise_web_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Empty
Deletes a web app.
1143 1144 1145 1146 1147 1148 1149 1150 1151 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1143 def delete_enterprise_web_app(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Empty::Representation command.response_class = Google::Apis::AndroidmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_enterprise_upgrade_url(name, generate_enterprise_upgrade_url_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlResponse
Generates an enterprise upgrade URL to upgrade an existing managed Google Play Accounts enterprise to a managed Google domain. See the guide (https:// developers.google.com/android/management/upgrade-an-enterprise) for more details.
169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 169 def generate_enterprise_upgrade_url(name, generate_enterprise_upgrade_url_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:generateEnterpriseUpgradeUrl', ) command.request_representation = Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlRequest::Representation command.request_object = generate_enterprise_upgrade_url_request_object command.response_representation = Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Enterprise
Gets an enterprise.
201 202 203 204 205 206 207 208 209 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 201 def get_enterprise(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Enterprise::Representation command.response_class = Google::Apis::AndroidmanagementV1::Enterprise command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_application(name, language_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Application
Gets info about an application.
313 314 315 316 317 318 319 320 321 322 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 313 def get_enterprise_application(name, language_code: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Application::Representation command.response_class = Google::Apis::AndroidmanagementV1::Application command.params['name'] = name unless name.nil? command.query['languageCode'] = language_code unless language_code.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_device(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Device
Gets a device. Deleted devices will respond with a 404 error.
387 388 389 390 391 392 393 394 395 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 387 def get_enterprise_device(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Device::Representation command.response_class = Google::Apis::AndroidmanagementV1::Device command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_device_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
568 569 570 571 572 573 574 575 576 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 568 def get_enterprise_device_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Operation::Representation command.response_class = Google::Apis::AndroidmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_enrollment_token(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::EnrollmentToken
Gets an active, unexpired enrollment token. A partial view of the enrollment token is returned. Only the following fields are populated: name, expirationTimestamp, allowPersonalUsage, value, qrCode. This method is meant to help manage active enrollment tokens lifecycle. For security reasons, it's recommended to delete active enrollment tokens as soon as they're not intended to be used anymore.
720 721 722 723 724 725 726 727 728 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 720 def get_enterprise_enrollment_token(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::EnrollmentToken::Representation command.response_class = Google::Apis::AndroidmanagementV1::EnrollmentToken command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_migration_token(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::MigrationToken
Gets a migration token.
832 833 834 835 836 837 838 839 840 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 832 def get_enterprise_migration_token(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::MigrationToken::Representation command.response_class = Google::Apis::AndroidmanagementV1::MigrationToken command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Policy
Gets a policy.
936 937 938 939 940 941 942 943 944 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 936 def get_enterprise_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::Policy::Representation command.response_class = Google::Apis::AndroidmanagementV1::Policy command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_enterprise_web_app(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebApp
Gets a web app.
1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1174 def get_enterprise_web_app(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::WebApp::Representation command.response_class = Google::Apis::AndroidmanagementV1::WebApp command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_provisioning_info(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ProvisioningInfo
Get the device provisioning information by the identifier provided in the sign- in url.
1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1315 def get_provisioning_info(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::ProvisioningInfo::Representation command.response_class = Google::Apis::AndroidmanagementV1::ProvisioningInfo command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#issue_enterprise_device_command(name, command_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Operation
Issues a command to a device. The Operation resource returned contains a Command in its metadata field. Use the get operation method to get the status of the command.
421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 421 def issue_enterprise_device_command(name, command_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:issueCommand', ) command.request_representation = Google::Apis::AndroidmanagementV1::Command::Representation command.request_object = command_object command.response_representation = Google::Apis::AndroidmanagementV1::Operation::Representation command.response_class = Google::Apis::AndroidmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprise_device_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 613 def list_enterprise_device_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprise_devices(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListDevicesResponse
Lists devices for a given enterprise. Deleted devices are not returned in the response.
460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 460 def list_enterprise_devices(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/devices', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListDevicesResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListDevicesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprise_enrollment_tokens(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListEnrollmentTokensResponse
Lists active, unexpired enrollment tokens for a given enterprise. The list items contain only a partial view of EnrollmentToken object. Only the following fields are populated: name, expirationTimestamp, allowPersonalUsage, value, qrCode. This method is meant to help manage active enrollment tokens lifecycle. For security reasons, it's recommended to delete active enrollment tokens as soon as they're not intended to be used anymore.
761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 761 def list_enterprise_enrollment_tokens(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/enrollmentTokens', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListEnrollmentTokensResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListEnrollmentTokensResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprise_migration_tokens(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListMigrationTokensResponse
Lists migration tokens.
871 872 873 874 875 876 877 878 879 880 881 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 871 def list_enterprise_migration_tokens(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/migrationTokens', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListMigrationTokensResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListMigrationTokensResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprise_policies(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListPoliciesResponse
Lists policies for a given enterprise.
971 972 973 974 975 976 977 978 979 980 981 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 971 def list_enterprise_policies(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/policies', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListPoliciesResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListPoliciesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprise_web_apps(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListWebAppsResponse
Lists web apps for a given enterprise.
1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1209 def list_enterprise_web_apps(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/webApps', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListWebAppsResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListWebAppsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_enterprises(page_size: nil, page_token: nil, project_id: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ListEnterprisesResponse
Lists EMM-managed enterprises. Only BASIC fields are returned.
238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 238 def list_enterprises(page_size: nil, page_token: nil, project_id: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/enterprises', ) command.response_representation = Google::Apis::AndroidmanagementV1::ListEnterprisesResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ListEnterprisesResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['projectId'] = project_id unless project_id.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#modify_policy_applications(name, modify_policy_applications_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::ModifyPolicyApplicationsResponse
Updates or creates applications in a policy.
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1005 def modify_policy_applications(name, modify_policy_applications_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:modifyPolicyApplications', ) command.request_representation = Google::Apis::AndroidmanagementV1::ModifyPolicyApplicationsRequest::Representation command.request_object = modify_policy_applications_request_object command.response_representation = Google::Apis::AndroidmanagementV1::ModifyPolicyApplicationsResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::ModifyPolicyApplicationsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_enterprise(name, enterprise_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Enterprise
Updates an enterprise. See also: SigninDetail
275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 275 def patch_enterprise(name, enterprise_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AndroidmanagementV1::Enterprise::Representation command.request_object = enterprise_object command.response_representation = Google::Apis::AndroidmanagementV1::Enterprise::Representation command.response_class = Google::Apis::AndroidmanagementV1::Enterprise command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_enterprise_device(name, device_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Device
Updates a device.
497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 497 def patch_enterprise_device(name, device_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AndroidmanagementV1::Device::Representation command.request_object = device_object command.response_representation = Google::Apis::AndroidmanagementV1::Device::Representation command.response_class = Google::Apis::AndroidmanagementV1::Device command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_enterprise_policy(name, policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::Policy
Updates or creates a policy.
1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1042 def patch_enterprise_policy(name, policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AndroidmanagementV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::AndroidmanagementV1::Policy::Representation command.response_class = Google::Apis::AndroidmanagementV1::Policy command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_enterprise_web_app(name, web_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::WebApp
Updates a web app.
1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1246 def patch_enterprise_web_app(name, web_app_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::AndroidmanagementV1::WebApp::Representation command.request_object = web_app_object command.response_representation = Google::Apis::AndroidmanagementV1::WebApp::Representation command.response_class = Google::Apis::AndroidmanagementV1::WebApp command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_policy_applications(name, remove_policy_applications_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsResponse
Removes applications in a policy.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/google/apis/androidmanagement_v1/service.rb', line 1077 def remove_policy_applications(name, remove_policy_applications_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:removePolicyApplications', ) command.request_representation = Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsRequest::Representation command.request_object = remove_policy_applications_request_object command.response_representation = Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsResponse::Representation command.response_class = Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |