Class: Google::Apis::AndroidmanagementV1::AppProcessInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information about a process. It contains process name, start time, app Uid, app Pid, seinfo tag, hash of the base APK.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppProcessInfo

Returns a new instance of AppProcessInfo.



458
459
460
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apk_sha256_hashString

SHA-256 hash of the base APK, in hexadecimal format. Corresponds to the JSON property apkSha256Hash

Returns:

  • (String)


423
424
425
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 423

def apk_sha256_hash
  @apk_sha256_hash
end

#package_namesArray<String>

Package names of all packages that are associated with the particular user ID. In most cases, this will be a single package name, the package that has been assigned that user ID. If multiple application share a UID then all packages sharing UID will be included. Corresponds to the JSON property packageNames

Returns:

  • (Array<String>)


431
432
433
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 431

def package_names
  @package_names
end

#pidFixnum

Process ID. Corresponds to the JSON property pid

Returns:

  • (Fixnum)


436
437
438
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 436

def pid
  @pid
end

#process_nameString

Process name. Corresponds to the JSON property processName

Returns:

  • (String)


441
442
443
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 441

def process_name
  @process_name
end

#seinfoString

SELinux policy info. Corresponds to the JSON property seinfo

Returns:

  • (String)


446
447
448
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 446

def seinfo
  @seinfo
end

#start_timeString

Process start time. Corresponds to the JSON property startTime

Returns:

  • (String)


451
452
453
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 451

def start_time
  @start_time
end

#uidFixnum

UID of the package. Corresponds to the JSON property uid

Returns:

  • (Fixnum)


456
457
458
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 456

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



463
464
465
466
467
468
469
470
471
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 463

def update!(**args)
  @apk_sha256_hash = args[:apk_sha256_hash] if args.key?(:apk_sha256_hash)
  @package_names = args[:package_names] if args.key?(:package_names)
  @pid = args[:pid] if args.key?(:pid)
  @process_name = args[:process_name] if args.key?(:process_name)
  @seinfo = args[:seinfo] if args.key?(:seinfo)
  @start_time = args[:start_time] if args.key?(:start_time)
  @uid = args[:uid] if args.key?(:uid)
end