Class: Google::Apis::AndroidmanagementV1::AppTrackInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Id to name association of a app track.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppTrackInfo

Returns a new instance of AppTrackInfo.



512
513
514
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#track_aliasString

The track name associated with the trackId, set in the Play Console. The name is modifiable from Play Console. Corresponds to the JSON property trackAlias

Returns:

  • (String)


504
505
506
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 504

def track_alias
  @track_alias
end

#track_idString

The unmodifiable unique track identifier, taken from the releaseTrackId in the URL of the Play Console page that displays the app’s track information. Corresponds to the JSON property trackId

Returns:

  • (String)


510
511
512
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 510

def track_id
  @track_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



517
518
519
520
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 517

def update!(**args)
  @track_alias = args[:track_alias] if args.key?(:track_alias)
  @track_id = args[:track_id] if args.key?(:track_id)
end