Class: Google::Apis::AndroidmanagementV1::AppVersion
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::AppVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
This represents a single version of the app.
Instance Attribute Summary collapse
-
#production ⇒ Boolean
(also: #production?)
If the value is True, it indicates that this version is a production track.
-
#track_ids ⇒ Array<String>
Track identifiers that the app version is published in.
-
#version_code ⇒ Fixnum
Unique increasing identifier for the app version.
-
#version_string ⇒ String
The string used in the Play store by the app developer to identify the version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppVersion
constructor
A new instance of AppVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppVersion
Returns a new instance of AppVersion.
551 552 553 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#production ⇒ Boolean Also known as: production?
If the value is True, it indicates that this version is a production track.
Corresponds to the JSON property production
530 531 532 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 530 def production @production end |
#track_ids ⇒ Array<String>
Track identifiers that the app version is published in. This does not include
the production track (see production instead).
Corresponds to the JSON property trackIds
537 538 539 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 537 def track_ids @track_ids end |
#version_code ⇒ Fixnum
Unique increasing identifier for the app version.
Corresponds to the JSON property versionCode
542 543 544 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 542 def version_code @version_code end |
#version_string ⇒ String
The string used in the Play store by the app developer to identify the version.
The string is not necessarily unique or localized (for example, the string
could be "1.4").
Corresponds to the JSON property versionString
549 550 551 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 549 def version_string @version_string end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
556 557 558 559 560 561 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 556 def update!(**args) @production = args[:production] if args.key?(:production) @track_ids = args[:track_ids] if args.key?(:track_ids) @version_code = args[:version_code] if args.key?(:version_code) @version_string = args[:version_string] if args.key?(:version_string) end |