Class: Google::Apis::AndroidmanagementV1::ApplicationPolicyChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A change to be made to a single ApplicationPolicy object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ApplicationPolicyChange

Returns a new instance of ApplicationPolicyChange.



1036
1037
1038
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicationGoogle::Apis::AndroidmanagementV1::ApplicationPolicy

Policy for an individual app. Note: Application availability on a given device cannot be changed using this policy if installAppsDisabled is enabled. The maximum number of applications that you can specify per policy is 3,000. Corresponds to the JSON property application



1028
1029
1030
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1028

def application
  @application
end

#update_maskString

The field mask indicating the fields to update. If omitted, all modifiable fields are updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1034

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1041
1042
1043
1044
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1041

def update!(**args)
  @application = args[:application] if args.key?(:application)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end