Class: Google::Apis::AndroidmanagementV1::BackupServiceToggledEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::BackupServiceToggledEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An admin has enabled or disabled backup service.
Instance Attribute Summary collapse
-
#admin_package_name ⇒ String
Package name of the admin app requesting the change.
-
#admin_user_id ⇒ Fixnum
User ID of the admin app from the which the change was requested.
-
#backup_service_state ⇒ String
Whether the backup service is enabled Corresponds to the JSON property
backupServiceState.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupServiceToggledEvent
constructor
A new instance of BackupServiceToggledEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupServiceToggledEvent
Returns a new instance of BackupServiceToggledEvent.
1198 1199 1200 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_package_name ⇒ String
Package name of the admin app requesting the change.
Corresponds to the JSON property adminPackageName
1186 1187 1188 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1186 def admin_package_name @admin_package_name end |
#admin_user_id ⇒ Fixnum
User ID of the admin app from the which the change was requested.
Corresponds to the JSON property adminUserId
1191 1192 1193 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1191 def admin_user_id @admin_user_id end |
#backup_service_state ⇒ String
Whether the backup service is enabled
Corresponds to the JSON property backupServiceState
1196 1197 1198 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1196 def backup_service_state @backup_service_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1203 1204 1205 1206 1207 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1203 def update!(**args) @admin_package_name = args[:admin_package_name] if args.key?(:admin_package_name) @admin_user_id = args[:admin_user_id] if args.key?(:admin_user_id) @backup_service_state = args[:backup_service_state] if args.key?(:backup_service_state) end |