Class: Google::Apis::AndroidmanagementV1::BlockAction
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::BlockAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An action to block access to apps and data on a fully managed device or in a work profile. This action also triggers a device or work profile to displays a user-facing notification with information (where possible) on how to correct the compliance issue. Note: wipeAction must also be specified.
Instance Attribute Summary collapse
-
#block_after_days ⇒ Fixnum
Number of days the policy is non-compliant before the device or work profile is blocked.
-
#block_scope ⇒ String
Specifies the scope of this BlockAction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BlockAction
constructor
A new instance of BlockAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BlockAction
Returns a new instance of BlockAction.
1276 1277 1278 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block_after_days ⇒ Fixnum
Number of days the policy is non-compliant before the device or work profile
is blocked. To block access immediately, set to 0. blockAfterDays must be less
than wipeAfterDays.
Corresponds to the JSON property blockAfterDays
1268 1269 1270 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1268 def block_after_days @block_after_days end |
#block_scope ⇒ String
Specifies the scope of this BlockAction. Only applicable to devices that are
company-owned.
Corresponds to the JSON property blockScope
1274 1275 1276 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1274 def block_scope @block_scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1281 1282 1283 1284 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1281 def update!(**args) @block_after_days = args[:block_after_days] if args.key?(:block_after_days) @block_scope = args[:block_scope] if args.key?(:block_scope) end |