Class: Google::Apis::AndroidmanagementV1::CertValidationFailureEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::CertValidationFailureEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An X.509v3 certificate failed to validate, currently this validation is performed on the Wi-FI access point and failure may be due to a mismatch upon server certificate validation. However it may in the future include other validation events of an X.509v3 certificate.
Instance Attribute Summary collapse
-
#failure_reason ⇒ String
The reason why certification validation failed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertValidationFailureEvent
constructor
A new instance of CertValidationFailureEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertValidationFailureEvent
Returns a new instance of CertValidationFailureEvent.
1363 1364 1365 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_reason ⇒ String
The reason why certification validation failed.
Corresponds to the JSON property failureReason
1361 1362 1363 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1361 def failure_reason @failure_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1368 1369 1370 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1368 def update!(**args) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) end |