Class: Google::Apis::AndroidmanagementV1::CrossDevicePolicies

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Policies controlling cross-device communication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossDevicePolicies

Returns a new instance of CrossDevicePolicies.



1846
1847
1848
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nearby_app_streamingString

Optional. Manages video streaming of apps on the device for fully managed devices or in the work profile for devices with work profiles to nearby devices. This is supported on Android 13 and above. Corresponds to the JSON property nearbyAppStreaming

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1837

def nearby_app_streaming
  @nearby_app_streaming
end

#nearby_notification_streamingString

Optional. Manages streaming of notifications from apps on the device for fully managed devices or in the work profile for devices with work profiles to nearby devices. This is supported on Android 13 and above. Corresponds to the JSON property nearbyNotificationStreaming

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1844

def nearby_notification_streaming
  @nearby_notification_streaming
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1851
1852
1853
1854
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1851

def update!(**args)
  @nearby_app_streaming = args[:nearby_app_streaming] if args.key?(:nearby_app_streaming)
  @nearby_notification_streaming = args[:nearby_notification_streaming] if args.key?(:nearby_notification_streaming)
end