Class: Google::Apis::AndroidmanagementV1::CrossProfilePolicies

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls the data from the work profile that can be accessed from the personal profile and vice versa. A NonComplianceDetail with MANAGEMENT_MODE is reported if the device does not have a work profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossProfilePolicies

Returns a new instance of CrossProfilePolicies.



1867
1868
1869
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cross_profile_app_functionsString

Optional. Controls whether personal profile apps can invoke app functions exposed by apps in the work profile. Corresponds to the JSON property crossProfileAppFunctions

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1832

def cross_profile_app_functions
  @cross_profile_app_functions
end

#cross_profile_copy_pasteString

Whether text copied from one profile (personal or work) can be pasted in the other profile. Corresponds to the JSON property crossProfileCopyPaste

Returns:

  • (String)


1838
1839
1840
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1838

def cross_profile_copy_paste
  @cross_profile_copy_paste
end

#cross_profile_data_sharingString

Whether data from one profile (personal or work) can be shared with apps in the other profile. Specifically controls simple data sharing via intents. Management of other cross-profile communication channels, such as contact search, copy/paste, or connected work & personal apps, are configured separately. Corresponds to the JSON property crossProfileDataSharing

Returns:

  • (String)


1847
1848
1849
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1847

def cross_profile_data_sharing
  @cross_profile_data_sharing
end

#exemptions_to_show_work_contacts_in_personal_profileGoogle::Apis::AndroidmanagementV1::PackageNameList

A list of package names. Corresponds to the JSON property exemptionsToShowWorkContactsInPersonalProfile



1852
1853
1854
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1852

def exemptions_to_show_work_contacts_in_personal_profile
  @exemptions_to_show_work_contacts_in_personal_profile
end

#show_work_contacts_in_personal_profileString

Whether personal apps can access contacts stored in the work profile.See also exemptions_to_show_work_contacts_in_personal_profile. Corresponds to the JSON property showWorkContactsInPersonalProfile

Returns:

  • (String)


1858
1859
1860
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1858

def show_work_contacts_in_personal_profile
  @show_work_contacts_in_personal_profile
end

#work_profile_widgets_defaultString

Specifies the default behaviour for work profile widgets. If the policy does not specify work_profile_widgets for a specific application, it will behave according to the value specified here. Corresponds to the JSON property workProfileWidgetsDefault

Returns:

  • (String)


1865
1866
1867
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1865

def work_profile_widgets_default
  @work_profile_widgets_default
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1872

def update!(**args)
  @cross_profile_app_functions = args[:cross_profile_app_functions] if args.key?(:cross_profile_app_functions)
  @cross_profile_copy_paste = args[:cross_profile_copy_paste] if args.key?(:cross_profile_copy_paste)
  @cross_profile_data_sharing = args[:cross_profile_data_sharing] if args.key?(:cross_profile_data_sharing)
  @exemptions_to_show_work_contacts_in_personal_profile = args[:exemptions_to_show_work_contacts_in_personal_profile] if args.key?(:exemptions_to_show_work_contacts_in_personal_profile)
  @show_work_contacts_in_personal_profile = args[:show_work_contacts_in_personal_profile] if args.key?(:show_work_contacts_in_personal_profile)
  @work_profile_widgets_default = args[:work_profile_widgets_default] if args.key?(:work_profile_widgets_default)
end