Class: Google::Apis::AndroidmanagementV1::DeviceRadioState
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::DeviceRadioState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Controls for device radio settings.
Instance Attribute Summary collapse
-
#airplane_mode_state ⇒ String
Controls whether airplane mode can be toggled by the user or not.
-
#cellular_two_g_state ⇒ String
Controls whether cellular 2G setting can be toggled by the user or not.
-
#minimum_wifi_security_level ⇒ String
The minimum required security level of Wi-Fi networks that the device can connect to.
-
#ultra_wideband_state ⇒ String
Controls the state of the ultra wideband setting and whether the user can toggle it on or off.
-
#user_initiated_add_esim_settings ⇒ String
Optional.
-
#wifi_state ⇒ String
Controls current state of Wi-Fi and if user can change its state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceRadioState
constructor
A new instance of DeviceRadioState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceRadioState
Returns a new instance of DeviceRadioState.
2553 2554 2555 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#airplane_mode_state ⇒ String
Controls whether airplane mode can be toggled by the user or not.
Corresponds to the JSON property airplaneModeState
2524 2525 2526 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2524 def airplane_mode_state @airplane_mode_state end |
#cellular_two_g_state ⇒ String
Controls whether cellular 2G setting can be toggled by the user or not.
Corresponds to the JSON property cellularTwoGState
2529 2530 2531 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2529 def cellular_two_g_state @cellular_two_g_state end |
#minimum_wifi_security_level ⇒ String
The minimum required security level of Wi-Fi networks that the device can
connect to.
Corresponds to the JSON property minimumWifiSecurityLevel
2535 2536 2537 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2535 def minimum_wifi_security_level @minimum_wifi_security_level end |
#ultra_wideband_state ⇒ String
Controls the state of the ultra wideband setting and whether the user can
toggle it on or off.
Corresponds to the JSON property ultraWidebandState
2541 2542 2543 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2541 def ultra_wideband_state @ultra_wideband_state end |
#user_initiated_add_esim_settings ⇒ String
Optional. Controls whether the user is allowed to add eSIM profiles.
Corresponds to the JSON property userInitiatedAddEsimSettings
2546 2547 2548 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2546 def user_initiated_add_esim_settings @user_initiated_add_esim_settings end |
#wifi_state ⇒ String
Controls current state of Wi-Fi and if user can change its state.
Corresponds to the JSON property wifiState
2551 2552 2553 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2551 def wifi_state @wifi_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2558 2559 2560 2561 2562 2563 2564 2565 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2558 def update!(**args) @airplane_mode_state = args[:airplane_mode_state] if args.key?(:airplane_mode_state) @cellular_two_g_state = args[:cellular_two_g_state] if args.key?(:cellular_two_g_state) @minimum_wifi_security_level = args[:minimum_wifi_security_level] if args.key?(:minimum_wifi_security_level) @ultra_wideband_state = args[:ultra_wideband_state] if args.key?(:ultra_wideband_state) @user_initiated_add_esim_settings = args[:user_initiated_add_esim_settings] if args.key?(:user_initiated_add_esim_settings) @wifi_state = args[:wifi_state] if args.key?(:wifi_state) end |