Class: Google::Apis::AndroidmanagementV1::DisplayProp
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::DisplayProp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Device display information.
Instance Attribute Summary collapse
-
#density ⇒ Fixnum
Display density expressed as dots-per-inch.
-
#display_id ⇒ Fixnum
Unique display id.
-
#height ⇒ Fixnum
Display height in pixels.
-
#name ⇒ String
Name of the display.
-
#refresh_rate ⇒ Fixnum
Refresh rate of the display in frames per second.
-
#state ⇒ String
State of the display.
-
#width ⇒ Fixnum
Display width in pixels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DisplayProp
constructor
A new instance of DisplayProp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DisplayProp
Returns a new instance of DisplayProp.
2641 2642 2643 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#density ⇒ Fixnum
Display density expressed as dots-per-inch.
Corresponds to the JSON property density
2609 2610 2611 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2609 def density @density end |
#display_id ⇒ Fixnum
Unique display id.
Corresponds to the JSON property displayId
2614 2615 2616 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2614 def display_id @display_id end |
#height ⇒ Fixnum
Display height in pixels.
Corresponds to the JSON property height
2619 2620 2621 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2619 def height @height end |
#name ⇒ String
Name of the display.
Corresponds to the JSON property name
2624 2625 2626 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2624 def name @name end |
#refresh_rate ⇒ Fixnum
Refresh rate of the display in frames per second.
Corresponds to the JSON property refreshRate
2629 2630 2631 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2629 def refresh_rate @refresh_rate end |
#state ⇒ String
State of the display.
Corresponds to the JSON property state
2634 2635 2636 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2634 def state @state end |
#width ⇒ Fixnum
Display width in pixels.
Corresponds to the JSON property width
2639 2640 2641 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2639 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2646 2647 2648 2649 2650 2651 2652 2653 2654 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2646 def update!(**args) @density = args[:density] if args.key?(:density) @display_id = args[:display_id] if args.key?(:display_id) @height = args[:height] if args.key?(:height) @name = args[:name] if args.key?(:name) @refresh_rate = args[:refresh_rate] if args.key?(:refresh_rate) @state = args[:state] if args.key?(:state) @width = args[:width] if args.key?(:width) end |