Class: Google::Apis::AndroidmanagementV1::DpcMigrationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information related to whether this device was migrated from being managed by another Device Policy Controller (DPC).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DpcMigrationInfo

Returns a new instance of DpcMigrationInfo.



2726
2727
2728
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_dataString

Output only. If this device was migrated from another DPC, the additionalData field of the migration token is populated here. Corresponds to the JSON property additionalData

Returns:

  • (String)


2718
2719
2720
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2718

def additional_data
  @additional_data
end

#previous_dpcString

Output only. If this device was migrated from another DPC, this is its package name. Not populated otherwise. Corresponds to the JSON property previousDpc

Returns:

  • (String)


2724
2725
2726
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2724

def previous_dpc
  @previous_dpc
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2731
2732
2733
2734
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2731

def update!(**args)
  @additional_data = args[:additional_data] if args.key?(:additional_data)
  @previous_dpc = args[:previous_dpc] if args.key?(:previous_dpc)
end