Class: Google::Apis::AndroidmanagementV1::ExternalData
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ExternalData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Data hosted at an external location. The data is to be downloaded by Android Device Policy and verified against the hash.
Instance Attribute Summary collapse
-
#sha256_hash ⇒ String
The base-64 encoded SHA-256 hash of the content hosted at url.
-
#url ⇒ String
The absolute URL to the data, which must use either the http or https scheme.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalData
constructor
A new instance of ExternalData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalData
Returns a new instance of ExternalData.
3197 3198 3199 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sha256_hash ⇒ String
The base-64 encoded SHA-256 hash of the content hosted at url. If the content
doesn't match this hash, Android Device Policy won't use the data.
Corresponds to the JSON property sha256Hash
3187 3188 3189 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3187 def sha256_hash @sha256_hash end |
#url ⇒ String
The absolute URL to the data, which must use either the http or https scheme.
Android Device Policy doesn't provide any credentials in the GET request, so
the URL must be publicly accessible. Including a long, random component in the
URL may be used to prevent attackers from discovering the URL.
Corresponds to the JSON property url
3195 3196 3197 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3195 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3202 3203 3204 3205 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3202 def update!(**args) @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash) @url = args[:url] if args.key?(:url) end |