Class: Google::Apis::AndroidmanagementV1::InternalErrorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Internal error details if present for the ADD_ESIM or REMOVE_ESIM command.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InternalErrorDetails

Returns a new instance of InternalErrorDetails.



3621
3622
3623
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Output only. Integer representation of the error code as specified here (https: //developer.android.com/reference/android/telephony/euicc/EuiccManager# EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE). See also, OPERATION_SMDX_SUBJECT_REASON_CODE. See error_code_detail for more details. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


3601
3602
3603
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3601

def error_code
  @error_code
end

#error_code_detailString

Output only. The error code detail corresponding to the error_code. Corresponds to the JSON property errorCodeDetail

Returns:

  • (String)


3606
3607
3608
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3606

def error_code_detail
  @error_code_detail
end

#operation_codeFixnum

Output only. Integer representation of the operation code as specified here ( https://developer.android.com/reference/android/telephony/euicc/EuiccManager# EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE). See operation_code_detail for more details. Corresponds to the JSON property operationCode

Returns:

  • (Fixnum)


3614
3615
3616
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3614

def operation_code
  @operation_code
end

#operation_code_detailString

Output only. The operation code detail corresponding to the operation_code. Corresponds to the JSON property operationCodeDetail

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3619

def operation_code_detail
  @operation_code_detail
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3626
3627
3628
3629
3630
3631
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3626

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_code_detail = args[:error_code_detail] if args.key?(:error_code_detail)
  @operation_code = args[:operation_code] if args.key?(:operation_code)
  @operation_code_detail = args[:operation_code_detail] if args.key?(:operation_code_detail)
end