Class: Google::Apis::AndroidmanagementV1::KeyDestructionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A cryptographic key including user installed, admin installed and system maintained private key is removed from the device either by the user or management. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyDestructionEvent

Returns a new instance of KeyDestructionEvent.



3724
3725
3726
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_uidFixnum

UID of the application which owns the key. Corresponds to the JSON property applicationUid

Returns:

  • (Fixnum)


3711
3712
3713
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3711

def application_uid
  @application_uid
end

#key_aliasString

Alias of the key. Corresponds to the JSON property keyAlias

Returns:

  • (String)


3716
3717
3718
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3716

def key_alias
  @key_alias
end

#successBoolean Also known as: success?

Whether the operation was successful. Corresponds to the JSON property success

Returns:

  • (Boolean)


3721
3722
3723
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3721

def success
  @success
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3729
3730
3731
3732
3733
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3729

def update!(**args)
  @application_uid = args[:application_uid] if args.key?(:application_uid)
  @key_alias = args[:key_alias] if args.key?(:key_alias)
  @success = args[:success] if args.key?(:success)
end