Class: Google::Apis::AndroidmanagementV1::KeyImportEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::KeyImportEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A cryptographic key including user installed, admin installed and system maintained private key is imported on the device either by the user or management. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.
Instance Attribute Summary collapse
-
#application_uid ⇒ Fixnum
UID of the application which imported the key Corresponds to the JSON property
applicationUid. -
#key_alias ⇒ String
Alias of the key.
-
#success ⇒ Boolean
(also: #success?)
Whether the operation was successful.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyImportEvent
constructor
A new instance of KeyImportEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyImportEvent
Returns a new instance of KeyImportEvent.
3728 3729 3730 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_uid ⇒ Fixnum
UID of the application which imported the key
Corresponds to the JSON property applicationUid
3715 3716 3717 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3715 def application_uid @application_uid end |
#key_alias ⇒ String
Alias of the key.
Corresponds to the JSON property keyAlias
3720 3721 3722 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3720 def key_alias @key_alias end |
#success ⇒ Boolean Also known as: success?
Whether the operation was successful.
Corresponds to the JSON property success
3725 3726 3727 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3725 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3733 3734 3735 3736 3737 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3733 def update!(**args) @application_uid = args[:application_uid] if args.key?(:application_uid) @key_alias = args[:key_alias] if args.key?(:key_alias) @success = args[:success] if args.key?(:success) end |