Class: Google::Apis::AndroidmanagementV1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

The device location containing the latitude and longitude.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



4210
4211
4212
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude position of the location Corresponds to the JSON property latitude

Returns:

  • (Float)


4203
4204
4205
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4203

def latitude
  @latitude
end

#longitudeFloat

The longitude position of the location Corresponds to the JSON property longitude

Returns:

  • (Float)


4208
4209
4210
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4208

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4215
4216
4217
4218
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4215

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end