Class: Google::Apis::AndroidmanagementV1::ManagedConfigurationTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ManagedConfigurationTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
The managed configurations template for the app, saved from the managed configurations iframe.
Instance Attribute Summary collapse
-
#configuration_variables ⇒ Hash<String,String>
Optional, a map containing configuration variables defined for the configuration.
-
#template_id ⇒ String
The ID of the managed configurations template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedConfigurationTemplate
constructor
A new instance of ManagedConfigurationTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedConfigurationTemplate
Returns a new instance of ManagedConfigurationTemplate.
4347 4348 4349 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration_variables ⇒ Hash<String,String>
Optional, a map containing configuration variables defined for the
configuration.
Corresponds to the JSON property configurationVariables
4339 4340 4341 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4339 def configuration_variables @configuration_variables end |
#template_id ⇒ String
The ID of the managed configurations template. This value must be a numeric
string containing exactly one or more digits (for example, "123456").
Corresponds to the JSON property templateId
4345 4346 4347 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4345 def template_id @template_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4352 4353 4354 4355 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4352 def update!(**args) @configuration_variables = args[:configuration_variables] if args.key?(:configuration_variables) @template_id = args[:template_id] if args.key?(:template_id) end |