Class: Google::Apis::AndroidmanagementV1::ManagedPropertyEntry
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ManagedPropertyEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An entry of a managed property.
Instance Attribute Summary collapse
-
#name ⇒ String
The human-readable name of the value.
-
#value ⇒ String
The machine-readable value of the entry, which should be used in the configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedPropertyEntry
constructor
A new instance of ManagedPropertyEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedPropertyEntry
Returns a new instance of ManagedPropertyEntry.
4402 4403 4404 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The human-readable name of the value. Localized.
Corresponds to the JSON property name
4394 4395 4396 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4394 def name @name end |
#value ⇒ String
The machine-readable value of the entry, which should be used in the
configuration. Not localized.
Corresponds to the JSON property value
4400 4401 4402 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4400 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4407 4408 4409 4410 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4407 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |