Class: Google::Apis::AndroidmanagementV1::ModifyPolicyApplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Response to a request to update or create ApplicationPolicy objects in the given policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModifyPolicyApplicationsResponse

Returns a new instance of ModifyPolicyApplicationsResponse.



4654
4655
4656
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::AndroidmanagementV1::Policy

A policy resource represents a group of settings that govern the behavior of a managed device and the apps installed on it. Corresponds to the JSON property policy



4652
4653
4654
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4652

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4659
4660
4661
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4659

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
end