Class: Google::Apis::AndroidmanagementV1::NonComplianceDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Provides detail about non-compliance with a policy setting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NonComplianceDetail

Returns a new instance of NonComplianceDetail.



4792
4793
4794
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_valueObject

If the policy setting could not be applied, the current value of the setting on the device. Corresponds to the JSON property currentValue

Returns:

  • (Object)


4746
4747
4748
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4746

def current_value
  @current_value
end

#field_pathString

For settings with nested fields, if a particular nested field is out of compliance, this specifies the full path to the offending field. The path is formatted in the same way the policy JSON field would be referenced in JavaScript, that is: 1) For object-typed fields, the field name is followed by a dot then by a subfield name. 2) For array-typed fields, the field name is followed by the array index enclosed in brackets. For example, to indicate a problem with the url field in the externalData field in the 3rd application, the path would be applications[2].externalData.url Corresponds to the JSON property fieldPath

Returns:

  • (String)


4758
4759
4760
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4758

def field_path
  @field_path
end

#installation_failure_reasonString

If package_name is set and the non-compliance reason is APP_NOT_INSTALLED or APP_NOT_UPDATED, the detailed reason the app can't be installed or updated. Corresponds to the JSON property installationFailureReason

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4764

def installation_failure_reason
  @installation_failure_reason
end

#non_compliance_reasonString

The reason the device is not in compliance with the setting. Corresponds to the JSON property nonComplianceReason

Returns:

  • (String)


4769
4770
4771
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4769

def non_compliance_reason
  @non_compliance_reason
end

#package_nameString

The package name indicating which app is out of compliance, if applicable. Corresponds to the JSON property packageName

Returns:

  • (String)


4774
4775
4776
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4774

def package_name
  @package_name
end

#setting_nameString

The name of the policy setting. This is the JSON field name of a top-level Policy field. Corresponds to the JSON property settingName

Returns:

  • (String)


4780
4781
4782
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4780

def setting_name
  @setting_name
end

#specific_non_compliance_contextGoogle::Apis::AndroidmanagementV1::SpecificNonComplianceContext

Additional context for SpecificNonComplianceReason. Corresponds to the JSON property specificNonComplianceContext



4785
4786
4787
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4785

def specific_non_compliance_context
  @specific_non_compliance_context
end

#specific_non_compliance_reasonString

The policy-specific reason the device is not in compliance with the setting. Corresponds to the JSON property specificNonComplianceReason

Returns:

  • (String)


4790
4791
4792
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4790

def specific_non_compliance_reason
  @specific_non_compliance_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4797

def update!(**args)
  @current_value = args[:current_value] if args.key?(:current_value)
  @field_path = args[:field_path] if args.key?(:field_path)
  @installation_failure_reason = args[:installation_failure_reason] if args.key?(:installation_failure_reason)
  @non_compliance_reason = args[:non_compliance_reason] if args.key?(:non_compliance_reason)
  @package_name = args[:package_name] if args.key?(:package_name)
  @setting_name = args[:setting_name] if args.key?(:setting_name)
  @specific_non_compliance_context = args[:specific_non_compliance_context] if args.key?(:specific_non_compliance_context)
  @specific_non_compliance_reason = args[:specific_non_compliance_reason] if args.key?(:specific_non_compliance_reason)
end