Class: Google::Apis::AndroidmanagementV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



4910
4911
4912
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true, the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


4871
4872
4873
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4871

def done
  @done
end

#errorGoogle::Apis::AndroidmanagementV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC (https://github.com/grpc). Each Status message contains three pieces of data: error code, error message, and error details.You can find out more about this error model and how to work with it in the API Design Guide (https://cloud. google.com/apis/design/errors). Corresponds to the JSON property error



4882
4883
4884
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4882

def error
  @error
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


4890
4891
4892
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4890

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id. Corresponds to the JSON property name

Returns:

  • (String)


4897
4898
4899
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4897

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


4908
4909
4910
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4908

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4915
4916
4917
4918
4919
4920
4921
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4915

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end