Class: Google::Apis::AndroidmanagementV1::PerAppResult
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::PerAppResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
The result of an attempt to clear the data of a single app.
Instance Attribute Summary collapse
-
#clearing_result ⇒ String
The result of an attempt to clear the data of a single app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerAppResult
constructor
A new instance of PerAppResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerAppResult
Returns a new instance of PerAppResult.
5065 5066 5067 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clearing_result ⇒ String
The result of an attempt to clear the data of a single app.
Corresponds to the JSON property clearingResult
5063 5064 5065 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5063 def clearing_result @clearing_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5070 5071 5072 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5070 def update!(**args) @clearing_result = args[:clearing_result] if args.key?(:clearing_result) end |