Class: Google::Apis::AndroidmanagementV1::PersonalUsagePolicies
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::PersonalUsagePolicies
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Policies controlling personal usage on a company-owned device with a work profile.
Instance Attribute Summary collapse
-
#account_types_with_management_disabled ⇒ Array<String>
Account types that can't be managed by the user.
-
#bluetooth_sharing ⇒ String
Optional.
-
#camera_disabled ⇒ Boolean
(also: #camera_disabled?)
If true, the camera is disabled on the personal profile.
-
#max_days_with_work_off ⇒ Fixnum
Controls how long the work profile can stay off.
-
#personal_applications ⇒ Array<Google::Apis::AndroidmanagementV1::PersonalApplicationPolicy>
Policy applied to applications in the personal profile.
-
#personal_play_store_mode ⇒ String
Used together with personalApplications to control how apps in the personal profile are allowed or blocked.
-
#private_space_policy ⇒ String
Optional.
-
#screen_capture_disabled ⇒ Boolean
(also: #screen_capture_disabled?)
If true, screen capture is disabled for all users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PersonalUsagePolicies
constructor
A new instance of PersonalUsagePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PersonalUsagePolicies
Returns a new instance of PersonalUsagePolicies.
5216 5217 5218 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_types_with_management_disabled ⇒ Array<String>
Account types that can't be managed by the user.
Corresponds to the JSON property accountTypesWithManagementDisabled
5171 5172 5173 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5171 def account_types_with_management_disabled @account_types_with_management_disabled end |
#bluetooth_sharing ⇒ String
Optional. Whether bluetooth sharing is allowed.
Corresponds to the JSON property bluetoothSharing
5176 5177 5178 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5176 def bluetooth_sharing @bluetooth_sharing end |
#camera_disabled ⇒ Boolean Also known as: camera_disabled?
If true, the camera is disabled on the personal profile.
Corresponds to the JSON property cameraDisabled
5181 5182 5183 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5181 def camera_disabled @camera_disabled end |
#max_days_with_work_off ⇒ Fixnum
Controls how long the work profile can stay off. The minimum duration must be
at least 3 days. Other details are as follows: - If the duration is set to 0,
the feature is turned off. - If the duration is set to a value smaller than
the minimum duration, the feature returns an error. Note: If you want to
avoid personal profiles being suspended during long periods of off-time, you
can temporarily set a large value for this parameter.
Corresponds to the JSON property maxDaysWithWorkOff
5192 5193 5194 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5192 def max_days_with_work_off @max_days_with_work_off end |
#personal_applications ⇒ Array<Google::Apis::AndroidmanagementV1::PersonalApplicationPolicy>
Policy applied to applications in the personal profile.
Corresponds to the JSON property personalApplications
5197 5198 5199 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5197 def personal_applications @personal_applications end |
#personal_play_store_mode ⇒ String
Used together with personalApplications to control how apps in the personal
profile are allowed or blocked.
Corresponds to the JSON property personalPlayStoreMode
5203 5204 5205 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5203 def personal_play_store_mode @personal_play_store_mode end |
#private_space_policy ⇒ String
Optional. Controls whether a private space is allowed on the device.
Corresponds to the JSON property privateSpacePolicy
5208 5209 5210 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5208 def private_space_policy @private_space_policy end |
#screen_capture_disabled ⇒ Boolean Also known as: screen_capture_disabled?
If true, screen capture is disabled for all users.
Corresponds to the JSON property screenCaptureDisabled
5213 5214 5215 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5213 def screen_capture_disabled @screen_capture_disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5221 5222 5223 5224 5225 5226 5227 5228 5229 5230 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5221 def update!(**args) @account_types_with_management_disabled = args[:account_types_with_management_disabled] if args.key?(:account_types_with_management_disabled) @bluetooth_sharing = args[:bluetooth_sharing] if args.key?(:bluetooth_sharing) @camera_disabled = args[:camera_disabled] if args.key?(:camera_disabled) @max_days_with_work_off = args[:max_days_with_work_off] if args.key?(:max_days_with_work_off) @personal_applications = args[:personal_applications] if args.key?(:personal_applications) @personal_play_store_mode = args[:personal_play_store_mode] if args.key?(:personal_play_store_mode) @private_space_policy = args[:private_space_policy] if args.key?(:private_space_policy) @screen_capture_disabled = args[:screen_capture_disabled] if args.key?(:screen_capture_disabled) end |