Class: Google::Apis::AndroidmanagementV1::PostureDetail
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::PostureDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Additional details regarding the security posture of the device.
Instance Attribute Summary collapse
-
#advice ⇒ Array<Google::Apis::AndroidmanagementV1::UserFacingMessage>
Corresponding admin-facing advice to mitigate this security risk and improve the security posture of the device.
-
#security_risk ⇒ String
A specific security risk that negatively affects the security posture of the device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostureDetail
constructor
A new instance of PostureDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostureDetail
Returns a new instance of PostureDetail.
6148 6149 6150 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advice ⇒ Array<Google::Apis::AndroidmanagementV1::UserFacingMessage>
Corresponding admin-facing advice to mitigate this security risk and improve
the security posture of the device.
Corresponds to the JSON property advice
6140 6141 6142 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6140 def advice @advice end |
#security_risk ⇒ String
A specific security risk that negatively affects the security posture of the
device.
Corresponds to the JSON property securityRisk
6146 6147 6148 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6146 def security_risk @security_risk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6153 6154 6155 6156 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6153 def update!(**args) @advice = args[:advice] if args.key?(:advice) @security_risk = args[:security_risk] if args.key?(:security_risk) end |