Class: Google::Apis::AndroidmanagementV1::PrivateDnsSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls the device's private DNS settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateDnsSettings

Returns a new instance of PrivateDnsSettings.



6225
6226
6227
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_dns_hostString

Optional. The hostname of the DNS server. This must be set if and only if private_dns_mode is set to PRIVATE_DNS_SPECIFIED_HOST. Supported on Android 10 and above on fully managed devices. A NonComplianceDetail with MANAGEMENT_MODE is reported on other management modes. A NonComplianceDetail with API_LEVEL is reported if the Android version is less than 10. A NonComplianceDetail with PENDING is reported if the device is not connected to a network. A NonComplianceDetail with nonComplianceReason INVALID_VALUE and specificNonComplianceReason PRIVATE_DNS_HOST_NOT_SERVING is reported if the specified host is not a DNS server or not supported on Android. A NonComplianceDetail with INVALID_VALUE is reported if applying this setting fails for any other reason. Corresponds to the JSON property privateDnsHost

Returns:

  • (String)


6217
6218
6219
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6217

def private_dns_host
  @private_dns_host
end

#private_dns_modeString

Optional. The configuration mode for device's global private DNS settings. If this is set to PRIVATE_DNS_SPECIFIED_HOST, then private_dns_host must be set. Corresponds to the JSON property privateDnsMode

Returns:

  • (String)


6223
6224
6225
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6223

def private_dns_mode
  @private_dns_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6230
6231
6232
6233
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6230

def update!(**args)
  @private_dns_host = args[:private_dns_host] if args.key?(:private_dns_host)
  @private_dns_mode = args[:private_dns_mode] if args.key?(:private_dns_mode)
end