Class: Google::Apis::AndroidmanagementV1::ProxyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Configuration info for an HTTP proxy. For a direct proxy, set the host, port, and excluded_hosts fields. For a PAC script proxy, set the pac_uri field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProxyInfo

Returns a new instance of ProxyInfo.



6301
6302
6303
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_hostsArray<String>

For a direct proxy, the hosts for which the proxy is bypassed. The host names may contain wildcards such as *.example.com. Corresponds to the JSON property excludedHosts

Returns:

  • (Array<String>)


6284
6285
6286
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6284

def excluded_hosts
  @excluded_hosts
end

#hostString

The host of the direct proxy. Corresponds to the JSON property host

Returns:

  • (String)


6289
6290
6291
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6289

def host
  @host
end

#pac_uriString

The URI of the PAC script used to configure the proxy. Corresponds to the JSON property pacUri

Returns:

  • (String)


6294
6295
6296
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6294

def pac_uri
  @pac_uri
end

#portFixnum

The port of the direct proxy. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6299
6300
6301
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6299

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6306
6307
6308
6309
6310
6311
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6306

def update!(**args)
  @excluded_hosts = args[:excluded_hosts] if args.key?(:excluded_hosts)
  @host = args[:host] if args.key?(:host)
  @pac_uri = args[:pac_uri] if args.key?(:pac_uri)
  @port = args[:port] if args.key?(:port)
end