Class: Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Response to a request to remove ApplicationPolicy objects in the given policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemovePolicyApplicationsResponse

Returns a new instance of RemovePolicyApplicationsResponse.



6450
6451
6452
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::AndroidmanagementV1::Policy

A policy resource represents a group of settings that govern the behavior of a managed device and the apps installed on it. Corresponds to the JSON property policy



6448
6449
6450
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6448

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6455
6456
6457
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6455

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
end