Class: Google::Apis::AndroidmanagementV1::SecurityPosture
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SecurityPosture
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
The security posture of the device, as determined by the current device state and the policies applied.
Instance Attribute Summary collapse
-
#device_posture ⇒ String
Device's security posture value.
-
#posture_details ⇒ Array<Google::Apis::AndroidmanagementV1::PostureDetail>
Additional details regarding the security posture of the device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPosture
constructor
A new instance of SecurityPosture.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPosture
Returns a new instance of SecurityPosture.
6700 6701 6702 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_posture ⇒ String
Device's security posture value.
Corresponds to the JSON property devicePosture
6693 6694 6695 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6693 def device_posture @device_posture end |
#posture_details ⇒ Array<Google::Apis::AndroidmanagementV1::PostureDetail>
Additional details regarding the security posture of the device.
Corresponds to the JSON property postureDetails
6698 6699 6700 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6698 def posture_details @posture_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6705 6706 6707 6708 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6705 def update!(**args) @device_posture = args[:device_posture] if args.key?(:device_posture) @posture_details = args[:posture_details] if args.key?(:posture_details) end |