Class: Google::Apis::AndroidmanagementV1::SignupUrl
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SignupUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An enterprise signup URL.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the resource.
-
#url ⇒ String
A URL where an enterprise admin can register their enterprise.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignupUrl
constructor
A new instance of SignupUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignupUrl
Returns a new instance of SignupUrl.
6883 6884 6885 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the resource. Use this value in the signupUrl field when calling
enterprises.create to complete the enterprise signup flow.
Corresponds to the JSON property name
6875 6876 6877 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6875 def name @name end |
#url ⇒ String
A URL where an enterprise admin can register their enterprise. The page can't
be rendered in an iframe.
Corresponds to the JSON property url
6881 6882 6883 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6881 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6888 6889 6890 6891 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6888 def update!(**args) @name = args[:name] if args.key?(:name) @url = args[:url] if args.key?(:url) end |