Class: Google::Apis::AndroidmanagementV1::StopLostModeUserAttemptEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A lost mode event indicating the user has attempted to stop lost mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StopLostModeUserAttemptEvent

Returns a new instance of StopLostModeUserAttemptEvent.



7216
7217
7218
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusString

The status of the attempt to stop lost mode. Corresponds to the JSON property status

Returns:

  • (String)


7214
7215
7216
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7214

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7221
7222
7223
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7221

def update!(**args)
  @status = args[:status] if args.key?(:status)
end