Class: Google::Apis::AndroidmanagementV1::SystemUpdateInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information about a potential pending system update.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SystemUpdateInfo

Returns a new instance of SystemUpdateInfo.



7202
7203
7204
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7202

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#update_received_timeString

The time when the update was first available. A zero value indicates that this field is not set. This field is set only if an update is available (that is, updateStatus is neither UPDATE_STATUS_UNKNOWN nor UP_TO_DATE). Corresponds to the JSON property updateReceivedTime

Returns:

  • (String)


7195
7196
7197
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7195

def update_received_time
  @update_received_time
end

#update_statusString

The status of an update: whether an update exists and what type it is. Corresponds to the JSON property updateStatus

Returns:

  • (String)


7200
7201
7202
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7200

def update_status
  @update_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7207
7208
7209
7210
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7207

def update!(**args)
  @update_received_time = args[:update_received_time] if args.key?(:update_received_time)
  @update_status = args[:update_status] if args.key?(:update_status)
end