Class: Google::Apis::AndroidmanagementV1::User
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A user belonging to an enterprise.
Instance Attribute Summary collapse
-
#account_identifier ⇒ String
A unique identifier you create for this user, such as user342 or asset#44418.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
7721 7722 7723 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_identifier ⇒ String
A unique identifier you create for this user, such as user342 or asset#44418.
This field must be set when the user is created and can't be updated. This
field must not contain personally identifiable information (PII). This
identifier must be 1024 characters or less; otherwise, the update policy
request will fail.
Corresponds to the JSON property accountIdentifier
7719 7720 7721 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7719 def account_identifier @account_identifier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7726 7727 7728 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7726 def update!(**args) @account_identifier = args[:account_identifier] if args.key?(:account_identifier) end |