Class: Google::Apis::AndroidmanagementV1::WebApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A web app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebApp

Returns a new instance of WebApp.



7800
7801
7802
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_modeString

The display mode of the web app. Corresponds to the JSON property displayMode

Returns:

  • (String)


7768
7769
7770
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7768

def display_mode
  @display_mode
end

#iconsArray<Google::Apis::AndroidmanagementV1::WebAppIcon>

A list of icons for the web app. Must have at least one element. Corresponds to the JSON property icons



7773
7774
7775
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7773

def icons
  @icons
end

#nameString

The name of the web app, which is generated by the server during creation in the form enterprises/enterpriseId/webApps/packageName. Corresponds to the JSON property name

Returns:

  • (String)


7779
7780
7781
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7779

def name
  @name
end

#start_urlString

The start URL, i.e. the URL that should load when the user opens the application. Corresponds to the JSON property startUrl

Returns:

  • (String)


7785
7786
7787
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7785

def start_url
  @start_url
end

#titleString

The title of the web app as displayed to the user (e.g., amongst a list of other applications, or as a label for an icon). Corresponds to the JSON property title

Returns:

  • (String)


7791
7792
7793
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7791

def title
  @title
end

#version_codeFixnum

The current version of the app.Note that the version can automatically increase during the lifetime of the web app, while Google does internal housekeeping to keep the web app up-to-date. Corresponds to the JSON property versionCode

Returns:

  • (Fixnum)


7798
7799
7800
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7798

def version_code
  @version_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7805
7806
7807
7808
7809
7810
7811
7812
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7805

def update!(**args)
  @display_mode = args[:display_mode] if args.key?(:display_mode)
  @icons = args[:icons] if args.key?(:icons)
  @name = args[:name] if args.key?(:name)
  @start_url = args[:start_url] if args.key?(:start_url)
  @title = args[:title] if args.key?(:title)
  @version_code = args[:version_code] if args.key?(:version_code)
end