Class: Google::Apis::AndroidmanagementV1::ApnPolicy
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ApnPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Access Point Name (APN) policy. Configuration for Access Point Names (APNs) which may override any other APNs on the device. See OVERRIDE_APNS_ENABLED and overrideApns for details.
Instance Attribute Summary collapse
-
#apn_settings ⇒ Array<Google::Apis::AndroidmanagementV1::ApnSetting>
Optional.
-
#override_apns ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApnPolicy
constructor
A new instance of ApnPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApnPolicy
Returns a new instance of ApnPolicy.
241 242 243 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apn_settings ⇒ Array<Google::Apis::AndroidmanagementV1::ApnSetting>
Optional. APN settings for override APNs. There must not be any conflict
between any of APN settings provided, otherwise the policy will be rejected.
Two ApnSettings are considered to conflict when all of the following fields
match on both: numericOperatorId, apn, proxyAddress, proxyPort,
mmsProxyAddress, mmsProxyPort, mmsc, mvnoType, protocol, roamingProtocol. If
some of the APN settings result in non-compliance of INVALID_VALUE , they will
be ignored. This can be set on fully managed devices on Android 10 and above.
This can also be set on work profiles on Android 13 and above and only with
ApnSetting's with ENTERPRISE APN type. A NonComplianceDetail with API_LEVEL is
reported if the Android version is less than 10. A NonComplianceDetail with
MANAGEMENT_MODE is reported for work profiles on Android versions less than 13.
Corresponds to the JSON property apnSettings
231 232 233 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 231 def apn_settings @apn_settings end |
#override_apns ⇒ String
Optional. Whether override APNs are disabled or enabled. See
DevicePolicyManager.setOverrideApnsEnabled (https://developer.android.com/
reference/android/app/admin/DevicePolicyManager#setOverrideApnsEnabled) for
more details.
Corresponds to the JSON property overrideApns
239 240 241 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 239 def override_apns @override_apns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
246 247 248 249 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 246 def update!(**args) @apn_settings = args[:apn_settings] if args.key?(:apn_settings) @override_apns = args[:override_apns] if args.key?(:override_apns) end |