Class: Google::Apis::AndroidmanagementV1::ApnSetting
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ApnSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An Access Point Name (APN) configuration for a carrier data connection. The APN provides configuration to connect a cellular network device to an IP data network. A carrier uses this setting to decide which IP address to assign, any security methods to apply, and how the device might be connected to private networks.
Instance Attribute Summary collapse
-
#always_on_setting ⇒ String
Optional.
-
#apn ⇒ String
Required.
-
#apn_types ⇒ Array<String>
Required.
-
#auth_type ⇒ String
Optional.
-
#carrier_id ⇒ Fixnum
Optional.
-
#display_name ⇒ String
Required.
-
#mms_proxy_address ⇒ String
Optional.
-
#mms_proxy_port ⇒ Fixnum
Optional.
-
#mmsc ⇒ String
Optional.
-
#mtu_v4 ⇒ Fixnum
Optional.
-
#mtu_v6 ⇒ Fixnum
Optional.
-
#mvno_type ⇒ String
Optional.
-
#network_types ⇒ Array<String>
Optional.
-
#numeric_operator_id ⇒ String
Optional.
-
#password ⇒ String
Optional.
-
#protocol ⇒ String
Optional.
-
#proxy_address ⇒ String
Optional.
-
#proxy_port ⇒ Fixnum
Optional.
-
#roaming_protocol ⇒ String
Optional.
-
#username ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApnSetting
constructor
A new instance of ApnSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApnSetting
Returns a new instance of ApnSetting.
386 387 388 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#always_on_setting ⇒ String
Optional. Whether User Plane resources have to be activated during every
transition from CM-IDLE mode to CM-CONNECTED state for this APN. See 3GPP TS
23.501 section 5.6.13.
Corresponds to the JSON property alwaysOnSetting
265 266 267 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 265 def always_on_setting @always_on_setting end |
#apn ⇒ String
Required. Name of the APN. Policy will be rejected if this field is empty.
Corresponds to the JSON property apn
270 271 272 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 270 def apn @apn end |
#apn_types ⇒ Array<String>
Required. Usage categories for the APN. Policy will be rejected if this field
is empty or contains APN_TYPE_UNSPECIFIED or duplicates. Multiple APN types
can be set on fully managed devices. ENTERPRISE is the only allowed APN type
on work profiles. A NonComplianceDetail with MANAGEMENT_MODE is reported for
any other value on work profiles. APN types that are not supported on the
device or management mode will be ignored. If this results in the empty list,
the APN setting will be ignored, because apnTypes is a required field. A
NonComplianceDetail with INVALID_VALUE is reported if none of the APN types
are supported on the device or management mode.
Corresponds to the JSON property apnTypes
283 284 285 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 283 def apn_types @apn_types end |
#auth_type ⇒ String
Optional. Authentication type of the APN.
Corresponds to the JSON property authType
288 289 290 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 288 def auth_type @auth_type end |
#carrier_id ⇒ Fixnum
Optional. Carrier ID for the APN. A value of 0 (default) means not set and
negative values are rejected.
Corresponds to the JSON property carrierId
294 295 296 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 294 def carrier_id @carrier_id end |
#display_name ⇒ String
Required. Human-readable name that describes the APN. Policy will be rejected
if this field is empty.
Corresponds to the JSON property displayName
300 301 302 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 300 def display_name @display_name end |
#mms_proxy_address ⇒ String
Optional. MMS (Multimedia Messaging Service) proxy address of the APN which
can be an IP address or hostname (not a URL).
Corresponds to the JSON property mmsProxyAddress
306 307 308 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 306 def mms_proxy_address @mms_proxy_address end |
#mms_proxy_port ⇒ Fixnum
Optional. MMS (Multimedia Messaging Service) proxy port of the APN. A value of
0 (default) means not set and negative values are rejected.
Corresponds to the JSON property mmsProxyPort
312 313 314 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 312 def mms_proxy_port @mms_proxy_port end |
#mmsc ⇒ String
Optional. MMSC (Multimedia Messaging Service Center) URI of the APN.
Corresponds to the JSON property mmsc
317 318 319 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 317 def mmsc @mmsc end |
#mtu_v4 ⇒ Fixnum
Optional. The default MTU (Maximum Transmission Unit) size in bytes of the
IPv4 routes brought up by this APN setting. A value of 0 (default) means not
set and negative values are rejected. Supported on Android 13 and above. A
NonComplianceDetail with API_LEVEL is reported if the Android version is less
than 13.
Corresponds to the JSON property mtuV4
326 327 328 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 326 def mtu_v4 @mtu_v4 end |
#mtu_v6 ⇒ Fixnum
Optional. The MTU (Maximum Transmission Unit) size of the IPv6 mobile
interface to which the APN connected. A value of 0 (default) means not set and
negative values are rejected. Supported on Android 13 and above. A
NonComplianceDetail with API_LEVEL is reported if the Android version is less
than 13.
Corresponds to the JSON property mtuV6
335 336 337 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 335 def mtu_v6 @mtu_v6 end |
#mvno_type ⇒ String
Optional. MVNO match type for the APN.
Corresponds to the JSON property mvnoType
340 341 342 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 340 def mvno_type @mvno_type end |
#network_types ⇒ Array<String>
Optional. Radio technologies (network types) the APN may use. Policy will be
rejected if this field contains NETWORK_TYPE_UNSPECIFIED or duplicates.
Corresponds to the JSON property networkTypes
346 347 348 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 346 def network_types @network_types end |
#numeric_operator_id ⇒ String
Optional. The numeric operator ID of the APN. Numeric operator ID is defined
as MCC (Mobile Country Code) + MNC (Mobile Network Code).
Corresponds to the JSON property numericOperatorId
352 353 354 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 352 def numeric_operator_id @numeric_operator_id end |
#password ⇒ String
Optional. APN password of the APN.
Corresponds to the JSON property password
357 358 359 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 357 def password @password end |
#protocol ⇒ String
Optional. The protocol to use to connect to this APN.
Corresponds to the JSON property protocol
362 363 364 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 362 def protocol @protocol end |
#proxy_address ⇒ String
Optional. The proxy address of the APN.
Corresponds to the JSON property proxyAddress
367 368 369 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 367 def proxy_address @proxy_address end |
#proxy_port ⇒ Fixnum
Optional. The proxy port of the APN. A value of 0 (default) means not set and
negative values are rejected.
Corresponds to the JSON property proxyPort
373 374 375 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 373 def proxy_port @proxy_port end |
#roaming_protocol ⇒ String
Optional. The protocol to use to connect to this APN while the device is
roaming.
Corresponds to the JSON property roamingProtocol
379 380 381 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 379 def roaming_protocol @roaming_protocol end |
#username ⇒ String
Optional. APN username of the APN.
Corresponds to the JSON property username
384 385 386 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 384 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 391 def update!(**args) @always_on_setting = args[:always_on_setting] if args.key?(:always_on_setting) @apn = args[:apn] if args.key?(:apn) @apn_types = args[:apn_types] if args.key?(:apn_types) @auth_type = args[:auth_type] if args.key?(:auth_type) @carrier_id = args[:carrier_id] if args.key?(:carrier_id) @display_name = args[:display_name] if args.key?(:display_name) @mms_proxy_address = args[:mms_proxy_address] if args.key?(:mms_proxy_address) @mms_proxy_port = args[:mms_proxy_port] if args.key?(:mms_proxy_port) @mmsc = args[:mmsc] if args.key?(:mmsc) @mtu_v4 = args[:mtu_v4] if args.key?(:mtu_v4) @mtu_v6 = args[:mtu_v6] if args.key?(:mtu_v6) @mvno_type = args[:mvno_type] if args.key?(:mvno_type) @network_types = args[:network_types] if args.key?(:network_types) @numeric_operator_id = args[:numeric_operator_id] if args.key?(:numeric_operator_id) @password = args[:password] if args.key?(:password) @protocol = args[:protocol] if args.key?(:protocol) @proxy_address = args[:proxy_address] if args.key?(:proxy_address) @proxy_port = args[:proxy_port] if args.key?(:proxy_port) @roaming_protocol = args[:roaming_protocol] if args.key?(:roaming_protocol) @username = args[:username] if args.key?(:username) end |