Class: Google::Apis::AndroidmanagementV1::Application
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::Application
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Information about an app.
Instance Attribute Summary collapse
-
#app_pricing ⇒ String
Whether this app is free, free with in-app purchases, or paid.
-
#app_tracks ⇒ Array<Google::Apis::AndroidmanagementV1::AppTrackInfo>
Application tracks visible to the enterprise.
-
#app_versions ⇒ Array<Google::Apis::AndroidmanagementV1::AppVersion>
Versions currently available for this app.
-
#author ⇒ String
The name of the author of the apps (for example, the app developer).
-
#available_countries ⇒ Array<String>
The countries which this app is available in as per ISO 3166-1 alpha-2.
-
#category ⇒ String
The app category (e.g. RACING, SOCIAL, etc.) Corresponds to the JSON property
category. -
#content_rating ⇒ String
The content rating for this app.
-
#description ⇒ String
The localized promotional description, if available.
-
#distribution_channel ⇒ String
How and to whom the package is made available.
-
#features ⇒ Array<String>
Noteworthy features (if any) of this app.
-
#full_description ⇒ String
Full app description, if available.
-
#icon_url ⇒ String
A link to an image that can be used as an icon for the app.
-
#managed_properties ⇒ Array<Google::Apis::AndroidmanagementV1::ManagedProperty>
The set of managed properties available to be pre-configured for the app.
-
#min_android_sdk_version ⇒ Fixnum
The minimum Android SDK necessary to run the app.
-
#name ⇒ String
The name of the app in the form enterprises/
enterprise/applications/package_name. -
#permissions ⇒ Array<Google::Apis::AndroidmanagementV1::ApplicationPermission>
The permissions required by the app.
-
#play_store_url ⇒ String
A link to the (consumer) Google Play details page for the app.
-
#recent_changes ⇒ String
A localised description of the recent changes made to the app.
-
#screenshot_urls ⇒ Array<String>
A list of screenshot links representing the app.
-
#small_icon_url ⇒ String
A link to a smaller image that can be used as an icon for the app.
-
#title ⇒ String
The title of the app.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Application
constructor
A new instance of Application.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Application
Returns a new instance of Application.
683 684 685 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_pricing ⇒ String
Whether this app is free, free with in-app purchases, or paid. If the pricing
is unspecified, this means the app is not generally available anymore (even
though it might still be available to people who own it).
Corresponds to the JSON property appPricing
573 574 575 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 573 def app_pricing @app_pricing end |
#app_tracks ⇒ Array<Google::Apis::AndroidmanagementV1::AppTrackInfo>
Application tracks visible to the enterprise.
Corresponds to the JSON property appTracks
578 579 580 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 578 def app_tracks @app_tracks end |
#app_versions ⇒ Array<Google::Apis::AndroidmanagementV1::AppVersion>
Versions currently available for this app.
Corresponds to the JSON property appVersions
583 584 585 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 583 def app_versions @app_versions end |
#author ⇒ String
The name of the author of the apps (for example, the app developer).
Corresponds to the JSON property author
588 589 590 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 588 def @author end |
#available_countries ⇒ Array<String>
The countries which this app is available in as per ISO 3166-1 alpha-2.
Corresponds to the JSON property availableCountries
593 594 595 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 593 def available_countries @available_countries end |
#category ⇒ String
The app category (e.g. RACING, SOCIAL, etc.)
Corresponds to the JSON property category
598 599 600 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 598 def category @category end |
#content_rating ⇒ String
The content rating for this app.
Corresponds to the JSON property contentRating
603 604 605 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 603 def @content_rating end |
#description ⇒ String
The localized promotional description, if available.
Corresponds to the JSON property description
608 609 610 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 608 def description @description end |
#distribution_channel ⇒ String
How and to whom the package is made available.
Corresponds to the JSON property distributionChannel
613 614 615 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 613 def distribution_channel @distribution_channel end |
#features ⇒ Array<String>
Noteworthy features (if any) of this app.
Corresponds to the JSON property features
618 619 620 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 618 def features @features end |
#full_description ⇒ String
Full app description, if available.
Corresponds to the JSON property fullDescription
623 624 625 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 623 def full_description @full_description end |
#icon_url ⇒ String
A link to an image that can be used as an icon for the app. This image is
suitable for use up to a pixel size of 512 x 512.
Corresponds to the JSON property iconUrl
629 630 631 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 629 def icon_url @icon_url end |
#managed_properties ⇒ Array<Google::Apis::AndroidmanagementV1::ManagedProperty>
The set of managed properties available to be pre-configured for the app.
Corresponds to the JSON property managedProperties
634 635 636 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 634 def managed_properties @managed_properties end |
#min_android_sdk_version ⇒ Fixnum
The minimum Android SDK necessary to run the app.
Corresponds to the JSON property minAndroidSdkVersion
639 640 641 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 639 def min_android_sdk_version @min_android_sdk_version end |
#name ⇒ String
The name of the app in the form enterprises/enterprise/applications/
package_name.
Corresponds to the JSON property name
645 646 647 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 645 def name @name end |
#permissions ⇒ Array<Google::Apis::AndroidmanagementV1::ApplicationPermission>
The permissions required by the app.
Corresponds to the JSON property permissions
650 651 652 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 650 def @permissions end |
#play_store_url ⇒ String
A link to the (consumer) Google Play details page for the app.
Corresponds to the JSON property playStoreUrl
655 656 657 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 655 def play_store_url @play_store_url end |
#recent_changes ⇒ String
A localised description of the recent changes made to the app.
Corresponds to the JSON property recentChanges
660 661 662 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 660 def recent_changes @recent_changes end |
#screenshot_urls ⇒ Array<String>
A list of screenshot links representing the app.
Corresponds to the JSON property screenshotUrls
665 666 667 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 665 def screenshot_urls @screenshot_urls end |
#small_icon_url ⇒ String
A link to a smaller image that can be used as an icon for the app. This image
is suitable for use up to a pixel size of 128 x 128.
Corresponds to the JSON property smallIconUrl
671 672 673 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 671 def small_icon_url @small_icon_url end |
#title ⇒ String
The title of the app. Localized.
Corresponds to the JSON property title
676 677 678 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 676 def title @title end |
#update_time ⇒ String
Output only. The approximate time (within 7 days) the app was last published.
Corresponds to the JSON property updateTime
681 682 683 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 681 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 688 def update!(**args) @app_pricing = args[:app_pricing] if args.key?(:app_pricing) @app_tracks = args[:app_tracks] if args.key?(:app_tracks) @app_versions = args[:app_versions] if args.key?(:app_versions) @author = args[:author] if args.key?(:author) @available_countries = args[:available_countries] if args.key?(:available_countries) @category = args[:category] if args.key?(:category) @content_rating = args[:content_rating] if args.key?(:content_rating) @description = args[:description] if args.key?(:description) @distribution_channel = args[:distribution_channel] if args.key?(:distribution_channel) @features = args[:features] if args.key?(:features) @full_description = args[:full_description] if args.key?(:full_description) @icon_url = args[:icon_url] if args.key?(:icon_url) @managed_properties = args[:managed_properties] if args.key?(:managed_properties) @min_android_sdk_version = args[:min_android_sdk_version] if args.key?(:min_android_sdk_version) @name = args[:name] if args.key?(:name) @permissions = args[:permissions] if args.key?(:permissions) @play_store_url = args[:play_store_url] if args.key?(:play_store_url) @recent_changes = args[:recent_changes] if args.key?(:recent_changes) @screenshot_urls = args[:screenshot_urls] if args.key?(:screenshot_urls) @small_icon_url = args[:small_icon_url] if args.key?(:small_icon_url) @title = args[:title] if args.key?(:title) @update_time = args[:update_time] if args.key?(:update_time) end |