Class: Google::Apis::AndroidmanagementV1::Command
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::Command
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A command.
Instance Attribute Summary collapse
-
#add_esim_params ⇒ Google::Apis::AndroidmanagementV1::AddEsimParams
Parameters associated with the ADD_ESIM command to add an eSIM profile to the device.
-
#clear_apps_data_params ⇒ Google::Apis::AndroidmanagementV1::ClearAppsDataParams
Parameters associated with the CLEAR_APP_DATA command to clear the data of specified apps from the device.
-
#clear_apps_data_status ⇒ Google::Apis::AndroidmanagementV1::ClearAppsDataStatus
Status of the CLEAR_APP_DATA command to clear the data of specified apps from the device.
-
#create_time ⇒ String
The timestamp at which the command was created.
-
#duration ⇒ String
The duration for which the command is valid.
-
#error_code ⇒ String
If the command failed, an error code explaining the failure.
-
#esim_status ⇒ Google::Apis::AndroidmanagementV1::EsimCommandStatus
Status and error details (if present) of an ADD_ESIM or REMOVE_ESIM command.
-
#new_password ⇒ String
For commands of type RESET_PASSWORD, optionally specifies the new password.
-
#remove_esim_params ⇒ Google::Apis::AndroidmanagementV1::RemoveEsimParams
Parameters associated with the REMOVE_ESIM command to remove an eSIM profile from the device.
-
#request_device_info_params ⇒ Google::Apis::AndroidmanagementV1::RequestDeviceInfoParams
Parameters associated with the REQUEST_DEVICE_INFO command to get device related information.
-
#request_device_info_status ⇒ Google::Apis::AndroidmanagementV1::RequestDeviceInfoStatus
Status of the REQUEST_DEVICE_INFO command.
-
#reset_password_flags ⇒ Array<String>
For commands of type RESET_PASSWORD, optionally specifies flags.
-
#start_lost_mode_params ⇒ Google::Apis::AndroidmanagementV1::StartLostModeParams
Parameters associated with the START_LOST_MODE command to put the device into lost mode.
-
#start_lost_mode_status ⇒ Google::Apis::AndroidmanagementV1::StartLostModeStatus
Status of the START_LOST_MODE command to put the device into lost mode.
-
#stop_lost_mode_params ⇒ Google::Apis::AndroidmanagementV1::StopLostModeParams
Parameters associated with the STOP_LOST_MODE command to take the device out of lost mode.
-
#stop_lost_mode_status ⇒ Google::Apis::AndroidmanagementV1::StopLostModeStatus
Status of the STOP_LOST_MODE command to take the device out of lost mode.
-
#type ⇒ String
The type of the command.
-
#user_name ⇒ String
The resource name of the user that owns the device in the form enterprises/
enterpriseId/users/userId. -
#wipe_params ⇒ Google::Apis::AndroidmanagementV1::WipeParams
Parameters associated with the WIPE command to wipe the device.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Command
constructor
A new instance of Command.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Command
Returns a new instance of Command.
1591 1592 1593 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_esim_params ⇒ Google::Apis::AndroidmanagementV1::AddEsimParams
Parameters associated with the ADD_ESIM command to add an eSIM profile to the
device.
Corresponds to the JSON property addEsimParams
1480 1481 1482 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1480 def add_esim_params @add_esim_params end |
#clear_apps_data_params ⇒ Google::Apis::AndroidmanagementV1::ClearAppsDataParams
Parameters associated with the CLEAR_APP_DATA command to clear the data of
specified apps from the device.
Corresponds to the JSON property clearAppsDataParams
1486 1487 1488 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1486 def clear_apps_data_params @clear_apps_data_params end |
#clear_apps_data_status ⇒ Google::Apis::AndroidmanagementV1::ClearAppsDataStatus
Status of the CLEAR_APP_DATA command to clear the data of specified apps from
the device.
Corresponds to the JSON property clearAppsDataStatus
1492 1493 1494 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1492 def clear_apps_data_status @clear_apps_data_status end |
#create_time ⇒ String
The timestamp at which the command was created. The timestamp is automatically
generated by the server.
Corresponds to the JSON property createTime
1498 1499 1500 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1498 def create_time @create_time end |
#duration ⇒ String
The duration for which the command is valid. The command will expire if not
executed by the device during this time. The default duration if unspecified
is ten minutes. There is no maximum duration.
Corresponds to the JSON property duration
1505 1506 1507 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1505 def duration @duration end |
#error_code ⇒ String
If the command failed, an error code explaining the failure. This is not set
when the command is cancelled by the caller. For reasoning about command
errors, prefer fields in the following order (most preferred first): 1.
Command-specific fields like clearAppsDataStatus, startLostModeStatus, or
similar, if they exist. 2. This field, if set. 3. The generic error field in
the Operation that wraps the command.
Corresponds to the JSON property errorCode
1515 1516 1517 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1515 def error_code @error_code end |
#esim_status ⇒ Google::Apis::AndroidmanagementV1::EsimCommandStatus
Status and error details (if present) of an ADD_ESIM or REMOVE_ESIM command.
Corresponds to the JSON property esimStatus
1520 1521 1522 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1520 def esim_status @esim_status end |
#new_password ⇒ String
For commands of type RESET_PASSWORD, optionally specifies the new password.
Note: The new password must be at least 6 characters long if it is numeric in
case of Android 14 devices. Else the command will fail with INVALID_VALUE.
Corresponds to the JSON property newPassword
1527 1528 1529 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1527 def new_password @new_password end |
#remove_esim_params ⇒ Google::Apis::AndroidmanagementV1::RemoveEsimParams
Parameters associated with the REMOVE_ESIM command to remove an eSIM profile
from the device.
Corresponds to the JSON property removeEsimParams
1533 1534 1535 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1533 def remove_esim_params @remove_esim_params end |
#request_device_info_params ⇒ Google::Apis::AndroidmanagementV1::RequestDeviceInfoParams
Parameters associated with the REQUEST_DEVICE_INFO command to get device
related information.
Corresponds to the JSON property requestDeviceInfoParams
1539 1540 1541 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1539 def request_device_info_params @request_device_info_params end |
#request_device_info_status ⇒ Google::Apis::AndroidmanagementV1::RequestDeviceInfoStatus
Status of the REQUEST_DEVICE_INFO command.
Corresponds to the JSON property requestDeviceInfoStatus
1544 1545 1546 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1544 def request_device_info_status @request_device_info_status end |
#reset_password_flags ⇒ Array<String>
For commands of type RESET_PASSWORD, optionally specifies flags.
Corresponds to the JSON property resetPasswordFlags
1549 1550 1551 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1549 def reset_password_flags @reset_password_flags end |
#start_lost_mode_params ⇒ Google::Apis::AndroidmanagementV1::StartLostModeParams
Parameters associated with the START_LOST_MODE command to put the device into
lost mode. At least one of the parameters, not including the organization name,
must be provided in order for the device to be put into lost mode.
Corresponds to the JSON property startLostModeParams
1556 1557 1558 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1556 def start_lost_mode_params @start_lost_mode_params end |
#start_lost_mode_status ⇒ Google::Apis::AndroidmanagementV1::StartLostModeStatus
Status of the START_LOST_MODE command to put the device into lost mode.
Corresponds to the JSON property startLostModeStatus
1561 1562 1563 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1561 def start_lost_mode_status @start_lost_mode_status end |
#stop_lost_mode_params ⇒ Google::Apis::AndroidmanagementV1::StopLostModeParams
Parameters associated with the STOP_LOST_MODE command to take the device out
of lost mode.
Corresponds to the JSON property stopLostModeParams
1567 1568 1569 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1567 def stop_lost_mode_params @stop_lost_mode_params end |
#stop_lost_mode_status ⇒ Google::Apis::AndroidmanagementV1::StopLostModeStatus
Status of the STOP_LOST_MODE command to take the device out of lost mode.
Corresponds to the JSON property stopLostModeStatus
1572 1573 1574 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1572 def stop_lost_mode_status @stop_lost_mode_status end |
#type ⇒ String
The type of the command.
Corresponds to the JSON property type
1577 1578 1579 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1577 def type @type end |
#user_name ⇒ String
The resource name of the user that owns the device in the form enterprises/
enterpriseId/users/userId. This is automatically generated by the server
based on the device the command is sent to.
Corresponds to the JSON property userName
1584 1585 1586 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1584 def user_name @user_name end |
#wipe_params ⇒ Google::Apis::AndroidmanagementV1::WipeParams
Parameters associated with the WIPE command to wipe the device.
Corresponds to the JSON property wipeParams
1589 1590 1591 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1589 def wipe_params @wipe_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1596 def update!(**args) @add_esim_params = args[:add_esim_params] if args.key?(:add_esim_params) @clear_apps_data_params = args[:clear_apps_data_params] if args.key?(:clear_apps_data_params) @clear_apps_data_status = args[:clear_apps_data_status] if args.key?(:clear_apps_data_status) @create_time = args[:create_time] if args.key?(:create_time) @duration = args[:duration] if args.key?(:duration) @error_code = args[:error_code] if args.key?(:error_code) @esim_status = args[:esim_status] if args.key?(:esim_status) @new_password = args[:new_password] if args.key?(:new_password) @remove_esim_params = args[:remove_esim_params] if args.key?(:remove_esim_params) @request_device_info_params = args[:request_device_info_params] if args.key?(:request_device_info_params) @request_device_info_status = args[:request_device_info_status] if args.key?(:request_device_info_status) @reset_password_flags = args[:reset_password_flags] if args.key?(:reset_password_flags) @start_lost_mode_params = args[:start_lost_mode_params] if args.key?(:start_lost_mode_params) @start_lost_mode_status = args[:start_lost_mode_status] if args.key?(:start_lost_mode_status) @stop_lost_mode_params = args[:stop_lost_mode_params] if args.key?(:stop_lost_mode_params) @stop_lost_mode_status = args[:stop_lost_mode_status] if args.key?(:stop_lost_mode_status) @type = args[:type] if args.key?(:type) @user_name = args[:user_name] if args.key?(:user_name) @wipe_params = args[:wipe_params] if args.key?(:wipe_params) end |