Class: Google::Apis::AndroidmanagementV1::DefaultApplication
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::DefaultApplication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Information about the application to be set as the default.
Instance Attribute Summary collapse
-
#package_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DefaultApplication
constructor
A new instance of DefaultApplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DefaultApplication
Returns a new instance of DefaultApplication.
2009 2010 2011 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#package_name ⇒ String
Required. The package name that should be set as the default application. The
policy is rejected if the package name is invalid.
Corresponds to the JSON property packageName
2007 2008 2009 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2007 def package_name @package_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2014 2015 2016 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2014 def update!(**args) @package_name = args[:package_name] if args.key?(:package_name) end |