Class: Google::Apis::AndroidmanagementV1::DefaultApplication
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::DefaultApplication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Information about the application to be set as the default.
Instance Attribute Summary collapse
-
#package_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DefaultApplication
constructor
A new instance of DefaultApplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DefaultApplication
Returns a new instance of DefaultApplication.
1974 1975 1976 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#package_name ⇒ String
Required. The package name that should be set as the default application. The
policy is rejected if the package name is invalid.
Corresponds to the JSON property packageName
1972 1973 1974 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1972 def package_name @package_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1979 1980 1981 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 1979 def update!(**args) @package_name = args[:package_name] if args.key?(:package_name) end |