Class: Google::Apis::AndroidmanagementV1::DefaultApplicationSetting
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::DefaultApplicationSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
The default application setting for a DefaultApplicationType.
Instance Attribute Summary collapse
-
#default_application_scopes ⇒ Array<String>
Required.
-
#default_application_type ⇒ String
Required.
-
#default_applications ⇒ Array<Google::Apis::AndroidmanagementV1::DefaultApplication>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DefaultApplicationSetting
constructor
A new instance of DefaultApplicationSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DefaultApplicationSetting
Returns a new instance of DefaultApplicationSetting.
2078 2079 2080 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_application_scopes ⇒ Array<String>
Required. The scopes to which the policy should be applied. This list must not
be empty or contain duplicates.A NonComplianceDetail with MANAGEMENT_MODE
reason and DEFAULT_APPLICATION_SETTING_UNSUPPORTED_SCOPES specific reason is
reported if none of the specified scopes can be applied to the management mode
(e.g. a fully managed device receives a policy with only
SCOPE_PERSONAL_PROFILE in the list).
Corresponds to the JSON property defaultApplicationScopes
2047 2048 2049 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2047 def default_application_scopes @default_application_scopes end |
#default_application_type ⇒ String
Required. The app type to set the default application.
Corresponds to the JSON property defaultApplicationType
2052 2053 2054 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2052 def default_application_type @default_application_type end |
#default_applications ⇒ Array<Google::Apis::AndroidmanagementV1::DefaultApplication>
Required. The list of applications that can be set as the default app for a
given type. This list must not be empty or contain duplicates. The first app
in the list that is installed and qualified for the defaultApplicationType (e.
g. SMS app for DEFAULT_SMS) is set as the default app. The signing key
certificate fingerprint of the app on the device must also match one of the
signing key certificate fingerprints obtained from Play Store or one of the
entries in ApplicationPolicy.signingKeyCerts in order to be set as the default.
If the defaultApplicationScopes contains SCOPE_FULLY_MANAGED or
SCOPE_WORK_PROFILE, the app must have an entry in applications with
installType set to a value other than BLOCKED.A NonComplianceDetail with
APP_NOT_INSTALLED reason and DEFAULT_APPLICATION_SETTING_FAILED_FOR_SCOPE
specific reason is reported if none of the apps in the list are installed. A
NonComplianceDetail with INVALID_VALUE reason and
DEFAULT_APPLICATION_SETTING_FAILED_FOR_SCOPE specific reason is reported if at
least one app is installed but the policy fails to apply due to other reasons (
e.g. the app is not of the right type).When applying to SCOPE_PERSONAL_PROFILE
on a company-owned device with a work profile, only pre-installed system apps
can be set as the default. A NonComplianceDetail with INVALID_VALUE reason and
DEFAULT_APPLICATION_SETTING_FAILED_FOR_SCOPE specific reason is reported if
the policy fails to apply to the personal profile.
Corresponds to the JSON property defaultApplications
2076 2077 2078 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2076 def default_applications @default_applications end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2083 2084 2085 2086 2087 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2083 def update!(**args) @default_application_scopes = args[:default_application_scopes] if args.key?(:default_application_scopes) @default_application_type = args[:default_application_type] if args.key?(:default_application_type) @default_applications = args[:default_applications] if args.key?(:default_applications) end |