Class: Google::Apis::AndroidmanagementV1::Device
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::Device
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A device owned by an enterprise. Unless otherwise noted, all fields are read- only and can't be modified by enterprises.devices.patch.
Instance Attribute Summary collapse
-
#api_level ⇒ Fixnum
The API level of the Android platform version running on the device.
-
#application_reports ⇒ Array<Google::Apis::AndroidmanagementV1::ApplicationReport>
Reports for apps installed on the device.
-
#applied_password_policies ⇒ Array<Google::Apis::AndroidmanagementV1::PasswordRequirements>
The password requirements currently applied to the device.
-
#applied_policy_name ⇒ String
The name of the policy currently applied to the device.
-
#applied_policy_version ⇒ Fixnum
The version of the policy currently applied to the device.
-
#applied_state ⇒ String
The state currently applied to the device.
-
#common_criteria_mode_info ⇒ Google::Apis::AndroidmanagementV1::CommonCriteriaModeInfo
Information about Common Criteria Mode—security standards defined in the Common Criteria for Information Technology Security Evaluation (https://www. commoncriteriaportal.org/) (CC).This information is only available if statusReportingSettings.commonCriteriaModeEnabled is true in the device's policy.
-
#default_application_info ⇒ Array<Google::Apis::AndroidmanagementV1::DefaultApplicationInfo>
Output only.
-
#device_settings ⇒ Google::Apis::AndroidmanagementV1::DeviceSettings
Information about security related device settings on device.
-
#disabled_reason ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#displays ⇒ Array<Google::Apis::AndroidmanagementV1::DisplayProp>
Detailed information about displays on the device.
-
#dpc_migration_info ⇒ Google::Apis::AndroidmanagementV1::DpcMigrationInfo
Information related to whether this device was migrated from being managed by another Device Policy Controller (DPC).
-
#enrollment_time ⇒ String
The time of device enrollment.
-
#enrollment_token_data ⇒ String
If the device was enrolled with an enrollment token with additional data provided, this field contains that data.
-
#enrollment_token_name ⇒ String
If the device was enrolled with an enrollment token, this field contains the name of the token.
-
#hardware_info ⇒ Google::Apis::AndroidmanagementV1::HardwareInfo
Information about device hardware.
-
#hardware_status_samples ⇒ Array<Google::Apis::AndroidmanagementV1::HardwareStatus>
Hardware status samples in chronological order.
-
#last_policy_compliance_report_time ⇒ String
Deprecated.
-
#last_policy_sync_time ⇒ String
The last time the device fetched its policy.
-
#last_status_report_time ⇒ String
The last time the device sent a status report.
-
#management_mode ⇒ String
The type of management mode Android Device Policy takes on the device.
-
#memory_events ⇒ Array<Google::Apis::AndroidmanagementV1::MemoryEvent>
Events related to memory and storage measurements in chronological order.
-
#memory_info ⇒ Google::Apis::AndroidmanagementV1::MemoryInfo
Information about device memory and storage.
-
#name ⇒ String
The name of the device in the form enterprises/
enterpriseId/devices/deviceId. -
#network_info ⇒ Google::Apis::AndroidmanagementV1::NetworkInfo
Device network info.
-
#non_compliance_details ⇒ Array<Google::Apis::AndroidmanagementV1::NonComplianceDetail>
Details about policy settings that the device is not compliant with.
-
#ownership ⇒ String
Ownership of the managed device.
-
#policy_compliant ⇒ Boolean
(also: #policy_compliant?)
Whether the device is compliant with its policy.
-
#policy_name ⇒ String
The name of the policy applied to the device, in the form enterprises/
enterpriseId/policies/policyId. -
#power_management_events ⇒ Array<Google::Apis::AndroidmanagementV1::PowerManagementEvent>
Power management events on the device in chronological order.
-
#previous_device_names ⇒ Array<String>
If the same physical device has been enrolled multiple times, this field contains its previous device names.
-
#security_posture ⇒ Google::Apis::AndroidmanagementV1::SecurityPosture
The security posture of the device, as determined by the current device state and the policies applied.
-
#software_info ⇒ Google::Apis::AndroidmanagementV1::SoftwareInfo
Information about device software.
-
#state ⇒ String
The state to be applied to the device.
-
#system_properties ⇒ Hash<String,String>
Map of selected system properties name and value related to the device.
-
#user ⇒ Google::Apis::AndroidmanagementV1::User
A user belonging to an enterprise.
-
#user_name ⇒ String
The resource name of the user that owns this device in the form enterprises/
enterpriseId/users/userId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Device
constructor
A new instance of Device.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Device
Returns a new instance of Device.
2389 2390 2391 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_level ⇒ Fixnum
The API level of the Android platform version running on the device.
Corresponds to the JSON property apiLevel
2158 2159 2160 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2158 def api_level @api_level end |
#application_reports ⇒ Array<Google::Apis::AndroidmanagementV1::ApplicationReport>
Reports for apps installed on the device. This information is only available
when application_reports_enabled is true in the device's policy.
Corresponds to the JSON property applicationReports
2164 2165 2166 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2164 def application_reports @application_reports end |
#applied_password_policies ⇒ Array<Google::Apis::AndroidmanagementV1::PasswordRequirements>
The password requirements currently applied to the device. This field exists
because the applied requirements may be slightly different from those
specified in passwordPolicies in some cases. Note that this field does not
provide information about password compliance. For non-compliance information,
see nonComplianceDetails. NonComplianceDetail.fieldPath, is set based on
passwordPolicies, not based on this field.
Corresponds to the JSON property appliedPasswordPolicies
2174 2175 2176 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2174 def applied_password_policies @applied_password_policies end |
#applied_policy_name ⇒ String
The name of the policy currently applied to the device.
Corresponds to the JSON property appliedPolicyName
2179 2180 2181 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2179 def applied_policy_name @applied_policy_name end |
#applied_policy_version ⇒ Fixnum
The version of the policy currently applied to the device.
Corresponds to the JSON property appliedPolicyVersion
2184 2185 2186 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2184 def applied_policy_version @applied_policy_version end |
#applied_state ⇒ String
The state currently applied to the device.
Corresponds to the JSON property appliedState
2189 2190 2191 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2189 def applied_state @applied_state end |
#common_criteria_mode_info ⇒ Google::Apis::AndroidmanagementV1::CommonCriteriaModeInfo
Information about Common Criteria Mode—security standards defined in the
Common Criteria for Information Technology Security Evaluation (https://www.
commoncriteriaportal.org/) (CC).This information is only available if
statusReportingSettings.commonCriteriaModeEnabled is true in the device's
policy.
Corresponds to the JSON property commonCriteriaModeInfo
2198 2199 2200 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2198 def common_criteria_mode_info @common_criteria_mode_info end |
#default_application_info ⇒ Array<Google::Apis::AndroidmanagementV1::DefaultApplicationInfo>
Output only. The default application information for the
DefaultApplicationType. This information is only available if
defaultApplicationInfoReportingEnabled is true in the device's policy.
Available on Android 16 and above.All app types are reported on fully managed
devices. DEFAULT_BROWSER, DEFAULT_CALL_REDIRECTION, DEFAULT_CALL_SCREENING and
DEFAULT_DIALER types are reported for the work profiles on company-owned
devices with a work profile and personally-owned devices. DEFAULT_WALLET is
also reported for company-owned devices with a work profile, but will only
include work profile information.
Corresponds to the JSON property defaultApplicationInfo
2211 2212 2213 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2211 def default_application_info @default_application_info end |
#device_settings ⇒ Google::Apis::AndroidmanagementV1::DeviceSettings
Information about security related device settings on device.
Corresponds to the JSON property deviceSettings
2216 2217 2218 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2216 def device_settings @device_settings end |
#disabled_reason ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property disabledReason
2222 2223 2224 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2222 def disabled_reason @disabled_reason end |
#displays ⇒ Array<Google::Apis::AndroidmanagementV1::DisplayProp>
Detailed information about displays on the device. This information is only
available if displayInfoEnabled is true in the device's policy.
Corresponds to the JSON property displays
2228 2229 2230 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2228 def displays @displays end |
#dpc_migration_info ⇒ Google::Apis::AndroidmanagementV1::DpcMigrationInfo
Information related to whether this device was migrated from being managed by
another Device Policy Controller (DPC).
Corresponds to the JSON property dpcMigrationInfo
2234 2235 2236 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2234 def dpc_migration_info @dpc_migration_info end |
#enrollment_time ⇒ String
The time of device enrollment.
Corresponds to the JSON property enrollmentTime
2239 2240 2241 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2239 def enrollment_time @enrollment_time end |
#enrollment_token_data ⇒ String
If the device was enrolled with an enrollment token with additional data
provided, this field contains that data.
Corresponds to the JSON property enrollmentTokenData
2245 2246 2247 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2245 def enrollment_token_data @enrollment_token_data end |
#enrollment_token_name ⇒ String
If the device was enrolled with an enrollment token, this field contains the
name of the token.
Corresponds to the JSON property enrollmentTokenName
2251 2252 2253 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2251 def enrollment_token_name @enrollment_token_name end |
#hardware_info ⇒ Google::Apis::AndroidmanagementV1::HardwareInfo
Information about device hardware. The fields related to temperature
thresholds are only available if hardwareStatusEnabled is true in the device's
policy.
Corresponds to the JSON property hardwareInfo
2258 2259 2260 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2258 def hardware_info @hardware_info end |
#hardware_status_samples ⇒ Array<Google::Apis::AndroidmanagementV1::HardwareStatus>
Hardware status samples in chronological order. This information is only
available if hardwareStatusEnabled is true in the device's policy.
Corresponds to the JSON property hardwareStatusSamples
2264 2265 2266 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2264 def hardware_status_samples @hardware_status_samples end |
#last_policy_compliance_report_time ⇒ String
Deprecated.
Corresponds to the JSON property lastPolicyComplianceReportTime
2269 2270 2271 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2269 def last_policy_compliance_report_time @last_policy_compliance_report_time end |
#last_policy_sync_time ⇒ String
The last time the device fetched its policy.
Corresponds to the JSON property lastPolicySyncTime
2274 2275 2276 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2274 def last_policy_sync_time @last_policy_sync_time end |
#last_status_report_time ⇒ String
The last time the device sent a status report.
Corresponds to the JSON property lastStatusReportTime
2279 2280 2281 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2279 def last_status_report_time @last_status_report_time end |
#management_mode ⇒ String
The type of management mode Android Device Policy takes on the device. This
influences which policy settings are supported.
Corresponds to the JSON property managementMode
2285 2286 2287 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2285 def management_mode @management_mode end |
#memory_events ⇒ Array<Google::Apis::AndroidmanagementV1::MemoryEvent>
Events related to memory and storage measurements in chronological order. This
information is only available if memoryInfoEnabled is true in the device's
policy.Events are retained for a certain period of time and old events are
deleted.
Corresponds to the JSON property memoryEvents
2293 2294 2295 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2293 def memory_events @memory_events end |
#memory_info ⇒ Google::Apis::AndroidmanagementV1::MemoryInfo
Information about device memory and storage.
Corresponds to the JSON property memoryInfo
2298 2299 2300 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2298 def memory_info @memory_info end |
#name ⇒ String
The name of the device in the form enterprises/enterpriseId/devices/
deviceId.
Corresponds to the JSON property name
2304 2305 2306 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2304 def name @name end |
#network_info ⇒ Google::Apis::AndroidmanagementV1::NetworkInfo
Device network info.
Corresponds to the JSON property networkInfo
2309 2310 2311 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2309 def network_info @network_info end |
#non_compliance_details ⇒ Array<Google::Apis::AndroidmanagementV1::NonComplianceDetail>
Details about policy settings that the device is not compliant with.
Corresponds to the JSON property nonComplianceDetails
2314 2315 2316 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2314 def non_compliance_details @non_compliance_details end |
#ownership ⇒ String
Ownership of the managed device.
Corresponds to the JSON property ownership
2319 2320 2321 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2319 def ownership @ownership end |
#policy_compliant ⇒ Boolean Also known as: policy_compliant?
Whether the device is compliant with its policy.
Corresponds to the JSON property policyCompliant
2324 2325 2326 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2324 def policy_compliant @policy_compliant end |
#policy_name ⇒ String
The name of the policy applied to the device, in the form enterprises/
enterpriseId/policies/policyId. If not specified, the policy_name for the
device's user is applied. This field can be modified by a patch request. You
can specify only the policyId when calling enterprises.devices.patch, as long
as the policyId doesn’t contain any slashes. The rest of the policy name is
inferred.
Corresponds to the JSON property policyName
2335 2336 2337 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2335 def policy_name @policy_name end |
#power_management_events ⇒ Array<Google::Apis::AndroidmanagementV1::PowerManagementEvent>
Power management events on the device in chronological order. This information
is only available if powerManagementEventsEnabled is true in the device's
policy.
Corresponds to the JSON property powerManagementEvents
2342 2343 2344 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2342 def power_management_events @power_management_events end |
#previous_device_names ⇒ Array<String>
If the same physical device has been enrolled multiple times, this field
contains its previous device names. The serial number is used as the unique
identifier to determine if the same physical device has enrolled previously.
The names are in chronological order.
Corresponds to the JSON property previousDeviceNames
2350 2351 2352 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2350 def previous_device_names @previous_device_names end |
#security_posture ⇒ Google::Apis::AndroidmanagementV1::SecurityPosture
The security posture of the device, as determined by the current device state
and the policies applied.
Corresponds to the JSON property securityPosture
2356 2357 2358 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2356 def security_posture @security_posture end |
#software_info ⇒ Google::Apis::AndroidmanagementV1::SoftwareInfo
Information about device software.
Corresponds to the JSON property softwareInfo
2361 2362 2363 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2361 def software_info @software_info end |
#state ⇒ String
The state to be applied to the device. This field can be modified by a patch
request. Note that when calling enterprises.devices.patch, ACTIVE and DISABLED
are the only allowable values. To enter the device into a DELETED state, call
enterprises.devices.delete.
Corresponds to the JSON property state
2369 2370 2371 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2369 def state @state end |
#system_properties ⇒ Hash<String,String>
Map of selected system properties name and value related to the device. This
information is only available if systemPropertiesEnabled is true in the device'
s policy.
Corresponds to the JSON property systemProperties
2376 2377 2378 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2376 def system_properties @system_properties end |
#user ⇒ Google::Apis::AndroidmanagementV1::User
A user belonging to an enterprise.
Corresponds to the JSON property user
2381 2382 2383 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2381 def user @user end |
#user_name ⇒ String
The resource name of the user that owns this device in the form enterprises/
enterpriseId/users/userId.
Corresponds to the JSON property userName
2387 2388 2389 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2387 def user_name @user_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2394 def update!(**args) @api_level = args[:api_level] if args.key?(:api_level) @application_reports = args[:application_reports] if args.key?(:application_reports) @applied_password_policies = args[:applied_password_policies] if args.key?(:applied_password_policies) @applied_policy_name = args[:applied_policy_name] if args.key?(:applied_policy_name) @applied_policy_version = args[:applied_policy_version] if args.key?(:applied_policy_version) @applied_state = args[:applied_state] if args.key?(:applied_state) @common_criteria_mode_info = args[:common_criteria_mode_info] if args.key?(:common_criteria_mode_info) @default_application_info = args[:default_application_info] if args.key?(:default_application_info) @device_settings = args[:device_settings] if args.key?(:device_settings) @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason) @displays = args[:displays] if args.key?(:displays) @dpc_migration_info = args[:dpc_migration_info] if args.key?(:dpc_migration_info) @enrollment_time = args[:enrollment_time] if args.key?(:enrollment_time) @enrollment_token_data = args[:enrollment_token_data] if args.key?(:enrollment_token_data) @enrollment_token_name = args[:enrollment_token_name] if args.key?(:enrollment_token_name) @hardware_info = args[:hardware_info] if args.key?(:hardware_info) @hardware_status_samples = args[:hardware_status_samples] if args.key?(:hardware_status_samples) @last_policy_compliance_report_time = args[:last_policy_compliance_report_time] if args.key?(:last_policy_compliance_report_time) @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time) @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time) @management_mode = args[:management_mode] if args.key?(:management_mode) @memory_events = args[:memory_events] if args.key?(:memory_events) @memory_info = args[:memory_info] if args.key?(:memory_info) @name = args[:name] if args.key?(:name) @network_info = args[:network_info] if args.key?(:network_info) @non_compliance_details = args[:non_compliance_details] if args.key?(:non_compliance_details) @ownership = args[:ownership] if args.key?(:ownership) @policy_compliant = args[:policy_compliant] if args.key?(:policy_compliant) @policy_name = args[:policy_name] if args.key?(:policy_name) @power_management_events = args[:power_management_events] if args.key?(:power_management_events) @previous_device_names = args[:previous_device_names] if args.key?(:previous_device_names) @security_posture = args[:security_posture] if args.key?(:security_posture) @software_info = args[:software_info] if args.key?(:software_info) @state = args[:state] if args.key?(:state) @system_properties = args[:system_properties] if args.key?(:system_properties) @user = args[:user] if args.key?(:user) @user_name = args[:user_name] if args.key?(:user_name) end |