Class: Google::Apis::AndroidmanagementV1::Device

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A device owned by an enterprise. Unless otherwise noted, all fields are read- only and can't be modified by enterprises.devices.patch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Device

Returns a new instance of Device.



2360
2361
2362
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_levelFixnum

The API level of the Android platform version running on the device. Corresponds to the JSON property apiLevel

Returns:

  • (Fixnum)


2129
2130
2131
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2129

def api_level
  @api_level
end

#application_reportsArray<Google::Apis::AndroidmanagementV1::ApplicationReport>

Reports for apps installed on the device. This information is only available when application_reports_enabled is true in the device's policy. Corresponds to the JSON property applicationReports



2135
2136
2137
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2135

def application_reports
  @application_reports
end

#applied_password_policiesArray<Google::Apis::AndroidmanagementV1::PasswordRequirements>

The password requirements currently applied to the device. This field exists because the applied requirements may be slightly different from those specified in passwordPolicies in some cases. Note that this field does not provide information about password compliance. For non-compliance information, see nonComplianceDetails. NonComplianceDetail.fieldPath, is set based on passwordPolicies, not based on this field. Corresponds to the JSON property appliedPasswordPolicies



2145
2146
2147
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2145

def applied_password_policies
  @applied_password_policies
end

#applied_policy_nameString

The name of the policy currently applied to the device. Corresponds to the JSON property appliedPolicyName

Returns:

  • (String)


2150
2151
2152
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2150

def applied_policy_name
  @applied_policy_name
end

#applied_policy_versionFixnum

The version of the policy currently applied to the device. Corresponds to the JSON property appliedPolicyVersion

Returns:

  • (Fixnum)


2155
2156
2157
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2155

def applied_policy_version
  @applied_policy_version
end

#applied_stateString

The state currently applied to the device. Corresponds to the JSON property appliedState

Returns:

  • (String)


2160
2161
2162
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2160

def applied_state
  @applied_state
end

#common_criteria_mode_infoGoogle::Apis::AndroidmanagementV1::CommonCriteriaModeInfo

Information about Common Criteria Mode—security standards defined in the Common Criteria for Information Technology Security Evaluation (https://www. commoncriteriaportal.org/) (CC).This information is only available if statusReportingSettings.commonCriteriaModeEnabled is true in the device's policy. Corresponds to the JSON property commonCriteriaModeInfo



2169
2170
2171
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2169

def common_criteria_mode_info
  @common_criteria_mode_info
end

#default_application_infoArray<Google::Apis::AndroidmanagementV1::DefaultApplicationInfo>

Output only. The default application information for the DefaultApplicationType. This information is only available if defaultApplicationInfoReportingEnabled is true in the device's policy. Available on Android 16 and above.All app types are reported on fully managed devices. DEFAULT_BROWSER, DEFAULT_CALL_REDIRECTION, DEFAULT_CALL_SCREENING and DEFAULT_DIALER types are reported for the work profiles on company-owned devices with a work profile and personally-owned devices. DEFAULT_WALLET is also reported for company-owned devices with a work profile, but will only include work profile information. Corresponds to the JSON property defaultApplicationInfo



2182
2183
2184
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2182

def default_application_info
  @default_application_info
end

#device_settingsGoogle::Apis::AndroidmanagementV1::DeviceSettings

Information about security related device settings on device. Corresponds to the JSON property deviceSettings



2187
2188
2189
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2187

def device_settings
  @device_settings
end

#disabled_reasonGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property disabledReason



2193
2194
2195
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2193

def disabled_reason
  @disabled_reason
end

#displaysArray<Google::Apis::AndroidmanagementV1::DisplayProp>

Detailed information about displays on the device. This information is only available if displayInfoEnabled is true in the device's policy. Corresponds to the JSON property displays



2199
2200
2201
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2199

def displays
  @displays
end

#dpc_migration_infoGoogle::Apis::AndroidmanagementV1::DpcMigrationInfo

Information related to whether this device was migrated from being managed by another Device Policy Controller (DPC). Corresponds to the JSON property dpcMigrationInfo



2205
2206
2207
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2205

def dpc_migration_info
  @dpc_migration_info
end

#enrollment_timeString

The time of device enrollment. Corresponds to the JSON property enrollmentTime

Returns:

  • (String)


2210
2211
2212
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2210

def enrollment_time
  @enrollment_time
end

#enrollment_token_dataString

If the device was enrolled with an enrollment token with additional data provided, this field contains that data. Corresponds to the JSON property enrollmentTokenData

Returns:

  • (String)


2216
2217
2218
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2216

def enrollment_token_data
  @enrollment_token_data
end

#enrollment_token_nameString

If the device was enrolled with an enrollment token, this field contains the name of the token. Corresponds to the JSON property enrollmentTokenName

Returns:

  • (String)


2222
2223
2224
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2222

def enrollment_token_name
  @enrollment_token_name
end

#hardware_infoGoogle::Apis::AndroidmanagementV1::HardwareInfo

Information about device hardware. The fields related to temperature thresholds are only available if hardwareStatusEnabled is true in the device's policy. Corresponds to the JSON property hardwareInfo



2229
2230
2231
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2229

def hardware_info
  @hardware_info
end

#hardware_status_samplesArray<Google::Apis::AndroidmanagementV1::HardwareStatus>

Hardware status samples in chronological order. This information is only available if hardwareStatusEnabled is true in the device's policy. Corresponds to the JSON property hardwareStatusSamples



2235
2236
2237
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2235

def hardware_status_samples
  @hardware_status_samples
end

#last_policy_compliance_report_timeString

Deprecated. Corresponds to the JSON property lastPolicyComplianceReportTime

Returns:

  • (String)


2240
2241
2242
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2240

def last_policy_compliance_report_time
  @last_policy_compliance_report_time
end

#last_policy_sync_timeString

The last time the device fetched its policy. Corresponds to the JSON property lastPolicySyncTime

Returns:

  • (String)


2245
2246
2247
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2245

def last_policy_sync_time
  @last_policy_sync_time
end

#last_status_report_timeString

The last time the device sent a status report. Corresponds to the JSON property lastStatusReportTime

Returns:

  • (String)


2250
2251
2252
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2250

def last_status_report_time
  @last_status_report_time
end

#management_modeString

The type of management mode Android Device Policy takes on the device. This influences which policy settings are supported. Corresponds to the JSON property managementMode

Returns:

  • (String)


2256
2257
2258
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2256

def management_mode
  @management_mode
end

#memory_eventsArray<Google::Apis::AndroidmanagementV1::MemoryEvent>

Events related to memory and storage measurements in chronological order. This information is only available if memoryInfoEnabled is true in the device's policy.Events are retained for a certain period of time and old events are deleted. Corresponds to the JSON property memoryEvents



2264
2265
2266
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2264

def memory_events
  @memory_events
end

#memory_infoGoogle::Apis::AndroidmanagementV1::MemoryInfo

Information about device memory and storage. Corresponds to the JSON property memoryInfo



2269
2270
2271
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2269

def memory_info
  @memory_info
end

#nameString

The name of the device in the form enterprises/enterpriseId/devices/ deviceId. Corresponds to the JSON property name

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2275

def name
  @name
end

#network_infoGoogle::Apis::AndroidmanagementV1::NetworkInfo

Device network info. Corresponds to the JSON property networkInfo



2280
2281
2282
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2280

def network_info
  @network_info
end

#non_compliance_detailsArray<Google::Apis::AndroidmanagementV1::NonComplianceDetail>

Details about policy settings that the device is not compliant with. Corresponds to the JSON property nonComplianceDetails



2285
2286
2287
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2285

def non_compliance_details
  @non_compliance_details
end

#ownershipString

Ownership of the managed device. Corresponds to the JSON property ownership

Returns:

  • (String)


2290
2291
2292
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2290

def ownership
  @ownership
end

#policy_compliantBoolean Also known as: policy_compliant?

Whether the device is compliant with its policy. Corresponds to the JSON property policyCompliant

Returns:

  • (Boolean)


2295
2296
2297
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2295

def policy_compliant
  @policy_compliant
end

#policy_nameString

The name of the policy applied to the device, in the form enterprises/ enterpriseId/policies/policyId. If not specified, the policy_name for the device's user is applied. This field can be modified by a patch request. You can specify only the policyId when calling enterprises.devices.patch, as long as the policyId doesn’t contain any slashes. The rest of the policy name is inferred. Corresponds to the JSON property policyName

Returns:

  • (String)


2306
2307
2308
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2306

def policy_name
  @policy_name
end

#power_management_eventsArray<Google::Apis::AndroidmanagementV1::PowerManagementEvent>

Power management events on the device in chronological order. This information is only available if powerManagementEventsEnabled is true in the device's policy. Corresponds to the JSON property powerManagementEvents



2313
2314
2315
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2313

def power_management_events
  @power_management_events
end

#previous_device_namesArray<String>

If the same physical device has been enrolled multiple times, this field contains its previous device names. The serial number is used as the unique identifier to determine if the same physical device has enrolled previously. The names are in chronological order. Corresponds to the JSON property previousDeviceNames

Returns:

  • (Array<String>)


2321
2322
2323
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2321

def previous_device_names
  @previous_device_names
end

#security_postureGoogle::Apis::AndroidmanagementV1::SecurityPosture

The security posture of the device, as determined by the current device state and the policies applied. Corresponds to the JSON property securityPosture



2327
2328
2329
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2327

def security_posture
  @security_posture
end

#software_infoGoogle::Apis::AndroidmanagementV1::SoftwareInfo

Information about device software. Corresponds to the JSON property softwareInfo



2332
2333
2334
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2332

def software_info
  @software_info
end

#stateString

The state to be applied to the device. This field can be modified by a patch request. Note that when calling enterprises.devices.patch, ACTIVE and DISABLED are the only allowable values. To enter the device into a DELETED state, call enterprises.devices.delete. Corresponds to the JSON property state

Returns:

  • (String)


2340
2341
2342
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2340

def state
  @state
end

#system_propertiesHash<String,String>

Map of selected system properties name and value related to the device. This information is only available if systemPropertiesEnabled is true in the device' s policy. Corresponds to the JSON property systemProperties

Returns:

  • (Hash<String,String>)


2347
2348
2349
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2347

def system_properties
  @system_properties
end

#userGoogle::Apis::AndroidmanagementV1::User

A user belonging to an enterprise. Corresponds to the JSON property user



2352
2353
2354
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2352

def user
  @user
end

#user_nameString

The resource name of the user that owns this device in the form enterprises/ enterpriseId/users/userId. Corresponds to the JSON property userName

Returns:

  • (String)


2358
2359
2360
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2358

def user_name
  @user_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2365

def update!(**args)
  @api_level = args[:api_level] if args.key?(:api_level)
  @application_reports = args[:application_reports] if args.key?(:application_reports)
  @applied_password_policies = args[:applied_password_policies] if args.key?(:applied_password_policies)
  @applied_policy_name = args[:applied_policy_name] if args.key?(:applied_policy_name)
  @applied_policy_version = args[:applied_policy_version] if args.key?(:applied_policy_version)
  @applied_state = args[:applied_state] if args.key?(:applied_state)
  @common_criteria_mode_info = args[:common_criteria_mode_info] if args.key?(:common_criteria_mode_info)
  @default_application_info = args[:default_application_info] if args.key?(:default_application_info)
  @device_settings = args[:device_settings] if args.key?(:device_settings)
  @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason)
  @displays = args[:displays] if args.key?(:displays)
  @dpc_migration_info = args[:dpc_migration_info] if args.key?(:dpc_migration_info)
  @enrollment_time = args[:enrollment_time] if args.key?(:enrollment_time)
  @enrollment_token_data = args[:enrollment_token_data] if args.key?(:enrollment_token_data)
  @enrollment_token_name = args[:enrollment_token_name] if args.key?(:enrollment_token_name)
  @hardware_info = args[:hardware_info] if args.key?(:hardware_info)
  @hardware_status_samples = args[:hardware_status_samples] if args.key?(:hardware_status_samples)
  @last_policy_compliance_report_time = args[:last_policy_compliance_report_time] if args.key?(:last_policy_compliance_report_time)
  @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time)
  @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time)
  @management_mode = args[:management_mode] if args.key?(:management_mode)
  @memory_events = args[:memory_events] if args.key?(:memory_events)
  @memory_info = args[:memory_info] if args.key?(:memory_info)
  @name = args[:name] if args.key?(:name)
  @network_info = args[:network_info] if args.key?(:network_info)
  @non_compliance_details = args[:non_compliance_details] if args.key?(:non_compliance_details)
  @ownership = args[:ownership] if args.key?(:ownership)
  @policy_compliant = args[:policy_compliant] if args.key?(:policy_compliant)
  @policy_name = args[:policy_name] if args.key?(:policy_name)
  @power_management_events = args[:power_management_events] if args.key?(:power_management_events)
  @previous_device_names = args[:previous_device_names] if args.key?(:previous_device_names)
  @security_posture = args[:security_posture] if args.key?(:security_posture)
  @software_info = args[:software_info] if args.key?(:software_info)
  @state = args[:state] if args.key?(:state)
  @system_properties = args[:system_properties] if args.key?(:system_properties)
  @user = args[:user] if args.key?(:user)
  @user_name = args[:user_name] if args.key?(:user_name)
end