Class: Google::Apis::AndroidmanagementV1::Device
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::Device
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A device owned by an enterprise. Unless otherwise noted, all fields are read- only and can't be modified by enterprises.devices.patch.
Instance Attribute Summary collapse
-
#api_level ⇒ Fixnum
The API level of the Android platform version running on the device.
-
#application_reports ⇒ Array<Google::Apis::AndroidmanagementV1::ApplicationReport>
Reports for apps installed on the device.
-
#applied_password_policies ⇒ Array<Google::Apis::AndroidmanagementV1::PasswordRequirements>
The password requirements currently applied to the device.
-
#applied_policy_name ⇒ String
The name of the policy currently applied to the device.
-
#applied_policy_version ⇒ Fixnum
The version of the policy currently applied to the device.
-
#applied_state ⇒ String
The state currently applied to the device.
-
#common_criteria_mode_info ⇒ Google::Apis::AndroidmanagementV1::CommonCriteriaModeInfo
Information about Common Criteria Mode—security standards defined in the Common Criteria for Information Technology Security Evaluation (https://www. commoncriteriaportal.org/) (CC).This information is only available if statusReportingSettings.commonCriteriaModeEnabled is true in the device's policy.
-
#default_application_info ⇒ Array<Google::Apis::AndroidmanagementV1::DefaultApplicationInfo>
Output only.
-
#device_settings ⇒ Google::Apis::AndroidmanagementV1::DeviceSettings
Information about security related device settings on device.
-
#disabled_reason ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#displays ⇒ Array<Google::Apis::AndroidmanagementV1::DisplayProp>
Detailed information about displays on the device.
-
#dpc_migration_info ⇒ Google::Apis::AndroidmanagementV1::DpcMigrationInfo
Information related to whether this device was migrated from being managed by another Device Policy Controller (DPC).
-
#enrollment_time ⇒ String
The time of device enrollment.
-
#enrollment_token_data ⇒ String
If the device was enrolled with an enrollment token with additional data provided, this field contains that data.
-
#enrollment_token_name ⇒ String
If the device was enrolled with an enrollment token, this field contains the name of the token.
-
#hardware_info ⇒ Google::Apis::AndroidmanagementV1::HardwareInfo
Information about device hardware.
-
#hardware_status_samples ⇒ Array<Google::Apis::AndroidmanagementV1::HardwareStatus>
Hardware status samples in chronological order.
-
#last_policy_compliance_report_time ⇒ String
Deprecated.
-
#last_policy_sync_time ⇒ String
The last time the device fetched its policy.
-
#last_status_report_time ⇒ String
The last time the device sent a status report.
-
#management_mode ⇒ String
The type of management mode Android Device Policy takes on the device.
-
#memory_events ⇒ Array<Google::Apis::AndroidmanagementV1::MemoryEvent>
Events related to memory and storage measurements in chronological order.
-
#memory_info ⇒ Google::Apis::AndroidmanagementV1::MemoryInfo
Information about device memory and storage.
-
#name ⇒ String
The name of the device in the form enterprises/
enterpriseId/devices/deviceId. -
#network_info ⇒ Google::Apis::AndroidmanagementV1::NetworkInfo
Device network info.
-
#non_compliance_details ⇒ Array<Google::Apis::AndroidmanagementV1::NonComplianceDetail>
Details about policy settings that the device is not compliant with.
-
#ownership ⇒ String
Ownership of the managed device.
-
#policy_compliant ⇒ Boolean
(also: #policy_compliant?)
Whether the device is compliant with its policy.
-
#policy_name ⇒ String
The name of the policy applied to the device, in the form enterprises/
enterpriseId/policies/policyId. -
#power_management_events ⇒ Array<Google::Apis::AndroidmanagementV1::PowerManagementEvent>
Power management events on the device in chronological order.
-
#previous_device_names ⇒ Array<String>
If the same physical device has been enrolled multiple times, this field contains its previous device names.
-
#security_posture ⇒ Google::Apis::AndroidmanagementV1::SecurityPosture
The security posture of the device, as determined by the current device state and the policies applied.
-
#software_info ⇒ Google::Apis::AndroidmanagementV1::SoftwareInfo
Information about device software.
-
#state ⇒ String
The state to be applied to the device.
-
#system_properties ⇒ Hash<String,String>
Map of selected system properties name and value related to the device.
-
#user ⇒ Google::Apis::AndroidmanagementV1::User
A user belonging to an enterprise.
-
#user_name ⇒ String
The resource name of the user that owns this device in the form enterprises/
enterpriseId/users/userId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Device
constructor
A new instance of Device.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Device
Returns a new instance of Device.
2354 2355 2356 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_level ⇒ Fixnum
The API level of the Android platform version running on the device.
Corresponds to the JSON property apiLevel
2123 2124 2125 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2123 def api_level @api_level end |
#application_reports ⇒ Array<Google::Apis::AndroidmanagementV1::ApplicationReport>
Reports for apps installed on the device. This information is only available
when application_reports_enabled is true in the device's policy.
Corresponds to the JSON property applicationReports
2129 2130 2131 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2129 def application_reports @application_reports end |
#applied_password_policies ⇒ Array<Google::Apis::AndroidmanagementV1::PasswordRequirements>
The password requirements currently applied to the device. This field exists
because the applied requirements may be slightly different from those
specified in passwordPolicies in some cases. Note that this field does not
provide information about password compliance. For non-compliance information,
see nonComplianceDetails. NonComplianceDetail.fieldPath, is set based on
passwordPolicies, not based on this field.
Corresponds to the JSON property appliedPasswordPolicies
2139 2140 2141 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2139 def applied_password_policies @applied_password_policies end |
#applied_policy_name ⇒ String
The name of the policy currently applied to the device.
Corresponds to the JSON property appliedPolicyName
2144 2145 2146 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2144 def applied_policy_name @applied_policy_name end |
#applied_policy_version ⇒ Fixnum
The version of the policy currently applied to the device.
Corresponds to the JSON property appliedPolicyVersion
2149 2150 2151 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2149 def applied_policy_version @applied_policy_version end |
#applied_state ⇒ String
The state currently applied to the device.
Corresponds to the JSON property appliedState
2154 2155 2156 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2154 def applied_state @applied_state end |
#common_criteria_mode_info ⇒ Google::Apis::AndroidmanagementV1::CommonCriteriaModeInfo
Information about Common Criteria Mode—security standards defined in the
Common Criteria for Information Technology Security Evaluation (https://www.
commoncriteriaportal.org/) (CC).This information is only available if
statusReportingSettings.commonCriteriaModeEnabled is true in the device's
policy.
Corresponds to the JSON property commonCriteriaModeInfo
2163 2164 2165 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2163 def common_criteria_mode_info @common_criteria_mode_info end |
#default_application_info ⇒ Array<Google::Apis::AndroidmanagementV1::DefaultApplicationInfo>
Output only. The default application information for the
DefaultApplicationType. This information is only available if
defaultApplicationInfoReportingEnabled is true in the device's policy.
Available on Android 16 and above.All app types are reported on fully managed
devices. DEFAULT_BROWSER, DEFAULT_CALL_REDIRECTION, DEFAULT_CALL_SCREENING and
DEFAULT_DIALER types are reported for the work profiles on company-owned
devices with a work profile and personally-owned devices. DEFAULT_WALLET is
also reported for company-owned devices with a work profile, but will only
include work profile information.
Corresponds to the JSON property defaultApplicationInfo
2176 2177 2178 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2176 def default_application_info @default_application_info end |
#device_settings ⇒ Google::Apis::AndroidmanagementV1::DeviceSettings
Information about security related device settings on device.
Corresponds to the JSON property deviceSettings
2181 2182 2183 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2181 def device_settings @device_settings end |
#disabled_reason ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property disabledReason
2187 2188 2189 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2187 def disabled_reason @disabled_reason end |
#displays ⇒ Array<Google::Apis::AndroidmanagementV1::DisplayProp>
Detailed information about displays on the device. This information is only
available if displayInfoEnabled is true in the device's policy.
Corresponds to the JSON property displays
2193 2194 2195 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2193 def displays @displays end |
#dpc_migration_info ⇒ Google::Apis::AndroidmanagementV1::DpcMigrationInfo
Information related to whether this device was migrated from being managed by
another Device Policy Controller (DPC).
Corresponds to the JSON property dpcMigrationInfo
2199 2200 2201 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2199 def dpc_migration_info @dpc_migration_info end |
#enrollment_time ⇒ String
The time of device enrollment.
Corresponds to the JSON property enrollmentTime
2204 2205 2206 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2204 def enrollment_time @enrollment_time end |
#enrollment_token_data ⇒ String
If the device was enrolled with an enrollment token with additional data
provided, this field contains that data.
Corresponds to the JSON property enrollmentTokenData
2210 2211 2212 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2210 def enrollment_token_data @enrollment_token_data end |
#enrollment_token_name ⇒ String
If the device was enrolled with an enrollment token, this field contains the
name of the token.
Corresponds to the JSON property enrollmentTokenName
2216 2217 2218 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2216 def enrollment_token_name @enrollment_token_name end |
#hardware_info ⇒ Google::Apis::AndroidmanagementV1::HardwareInfo
Information about device hardware. The fields related to temperature
thresholds are only available if hardwareStatusEnabled is true in the device's
policy.
Corresponds to the JSON property hardwareInfo
2223 2224 2225 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2223 def hardware_info @hardware_info end |
#hardware_status_samples ⇒ Array<Google::Apis::AndroidmanagementV1::HardwareStatus>
Hardware status samples in chronological order. This information is only
available if hardwareStatusEnabled is true in the device's policy.
Corresponds to the JSON property hardwareStatusSamples
2229 2230 2231 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2229 def hardware_status_samples @hardware_status_samples end |
#last_policy_compliance_report_time ⇒ String
Deprecated.
Corresponds to the JSON property lastPolicyComplianceReportTime
2234 2235 2236 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2234 def last_policy_compliance_report_time @last_policy_compliance_report_time end |
#last_policy_sync_time ⇒ String
The last time the device fetched its policy.
Corresponds to the JSON property lastPolicySyncTime
2239 2240 2241 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2239 def last_policy_sync_time @last_policy_sync_time end |
#last_status_report_time ⇒ String
The last time the device sent a status report.
Corresponds to the JSON property lastStatusReportTime
2244 2245 2246 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2244 def last_status_report_time @last_status_report_time end |
#management_mode ⇒ String
The type of management mode Android Device Policy takes on the device. This
influences which policy settings are supported.
Corresponds to the JSON property managementMode
2250 2251 2252 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2250 def management_mode @management_mode end |
#memory_events ⇒ Array<Google::Apis::AndroidmanagementV1::MemoryEvent>
Events related to memory and storage measurements in chronological order. This
information is only available if memoryInfoEnabled is true in the device's
policy.Events are retained for a certain period of time and old events are
deleted.
Corresponds to the JSON property memoryEvents
2258 2259 2260 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2258 def memory_events @memory_events end |
#memory_info ⇒ Google::Apis::AndroidmanagementV1::MemoryInfo
Information about device memory and storage.
Corresponds to the JSON property memoryInfo
2263 2264 2265 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2263 def memory_info @memory_info end |
#name ⇒ String
The name of the device in the form enterprises/enterpriseId/devices/
deviceId.
Corresponds to the JSON property name
2269 2270 2271 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2269 def name @name end |
#network_info ⇒ Google::Apis::AndroidmanagementV1::NetworkInfo
Device network info.
Corresponds to the JSON property networkInfo
2274 2275 2276 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2274 def network_info @network_info end |
#non_compliance_details ⇒ Array<Google::Apis::AndroidmanagementV1::NonComplianceDetail>
Details about policy settings that the device is not compliant with.
Corresponds to the JSON property nonComplianceDetails
2279 2280 2281 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2279 def non_compliance_details @non_compliance_details end |
#ownership ⇒ String
Ownership of the managed device.
Corresponds to the JSON property ownership
2284 2285 2286 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2284 def ownership @ownership end |
#policy_compliant ⇒ Boolean Also known as: policy_compliant?
Whether the device is compliant with its policy.
Corresponds to the JSON property policyCompliant
2289 2290 2291 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2289 def policy_compliant @policy_compliant end |
#policy_name ⇒ String
The name of the policy applied to the device, in the form enterprises/
enterpriseId/policies/policyId. If not specified, the policy_name for the
device's user is applied. This field can be modified by a patch request. You
can specify only the policyId when calling enterprises.devices.patch, as long
as the policyId doesn’t contain any slashes. The rest of the policy name is
inferred.
Corresponds to the JSON property policyName
2300 2301 2302 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2300 def policy_name @policy_name end |
#power_management_events ⇒ Array<Google::Apis::AndroidmanagementV1::PowerManagementEvent>
Power management events on the device in chronological order. This information
is only available if powerManagementEventsEnabled is true in the device's
policy.
Corresponds to the JSON property powerManagementEvents
2307 2308 2309 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2307 def power_management_events @power_management_events end |
#previous_device_names ⇒ Array<String>
If the same physical device has been enrolled multiple times, this field
contains its previous device names. The serial number is used as the unique
identifier to determine if the same physical device has enrolled previously.
The names are in chronological order.
Corresponds to the JSON property previousDeviceNames
2315 2316 2317 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2315 def previous_device_names @previous_device_names end |
#security_posture ⇒ Google::Apis::AndroidmanagementV1::SecurityPosture
The security posture of the device, as determined by the current device state
and the policies applied.
Corresponds to the JSON property securityPosture
2321 2322 2323 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2321 def security_posture @security_posture end |
#software_info ⇒ Google::Apis::AndroidmanagementV1::SoftwareInfo
Information about device software.
Corresponds to the JSON property softwareInfo
2326 2327 2328 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2326 def software_info @software_info end |
#state ⇒ String
The state to be applied to the device. This field can be modified by a patch
request. Note that when calling enterprises.devices.patch, ACTIVE and DISABLED
are the only allowable values. To enter the device into a DELETED state, call
enterprises.devices.delete.
Corresponds to the JSON property state
2334 2335 2336 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2334 def state @state end |
#system_properties ⇒ Hash<String,String>
Map of selected system properties name and value related to the device. This
information is only available if systemPropertiesEnabled is true in the device'
s policy.
Corresponds to the JSON property systemProperties
2341 2342 2343 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2341 def system_properties @system_properties end |
#user ⇒ Google::Apis::AndroidmanagementV1::User
A user belonging to an enterprise.
Corresponds to the JSON property user
2346 2347 2348 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2346 def user @user end |
#user_name ⇒ String
The resource name of the user that owns this device in the form enterprises/
enterpriseId/users/userId.
Corresponds to the JSON property userName
2352 2353 2354 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2352 def user_name @user_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2359 def update!(**args) @api_level = args[:api_level] if args.key?(:api_level) @application_reports = args[:application_reports] if args.key?(:application_reports) @applied_password_policies = args[:applied_password_policies] if args.key?(:applied_password_policies) @applied_policy_name = args[:applied_policy_name] if args.key?(:applied_policy_name) @applied_policy_version = args[:applied_policy_version] if args.key?(:applied_policy_version) @applied_state = args[:applied_state] if args.key?(:applied_state) @common_criteria_mode_info = args[:common_criteria_mode_info] if args.key?(:common_criteria_mode_info) @default_application_info = args[:default_application_info] if args.key?(:default_application_info) @device_settings = args[:device_settings] if args.key?(:device_settings) @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason) @displays = args[:displays] if args.key?(:displays) @dpc_migration_info = args[:dpc_migration_info] if args.key?(:dpc_migration_info) @enrollment_time = args[:enrollment_time] if args.key?(:enrollment_time) @enrollment_token_data = args[:enrollment_token_data] if args.key?(:enrollment_token_data) @enrollment_token_name = args[:enrollment_token_name] if args.key?(:enrollment_token_name) @hardware_info = args[:hardware_info] if args.key?(:hardware_info) @hardware_status_samples = args[:hardware_status_samples] if args.key?(:hardware_status_samples) @last_policy_compliance_report_time = args[:last_policy_compliance_report_time] if args.key?(:last_policy_compliance_report_time) @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time) @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time) @management_mode = args[:management_mode] if args.key?(:management_mode) @memory_events = args[:memory_events] if args.key?(:memory_events) @memory_info = args[:memory_info] if args.key?(:memory_info) @name = args[:name] if args.key?(:name) @network_info = args[:network_info] if args.key?(:network_info) @non_compliance_details = args[:non_compliance_details] if args.key?(:non_compliance_details) @ownership = args[:ownership] if args.key?(:ownership) @policy_compliant = args[:policy_compliant] if args.key?(:policy_compliant) @policy_name = args[:policy_name] if args.key?(:policy_name) @power_management_events = args[:power_management_events] if args.key?(:power_management_events) @previous_device_names = args[:previous_device_names] if args.key?(:previous_device_names) @security_posture = args[:security_posture] if args.key?(:security_posture) @software_info = args[:software_info] if args.key?(:software_info) @state = args[:state] if args.key?(:state) @system_properties = args[:system_properties] if args.key?(:system_properties) @user = args[:user] if args.key?(:user) @user_name = args[:user_name] if args.key?(:user_name) end |