Class: Google::Apis::AndroidmanagementV1::DeviceConnectivityManagement
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::DeviceConnectivityManagement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Covers controls for device connectivity such as Wi-Fi, USB data access, keyboard/mouse connections, and more.
Instance Attribute Summary collapse
-
#apn_policy ⇒ Google::Apis::AndroidmanagementV1::ApnPolicy
Access Point Name (APN) policy.
-
#bluetooth_sharing ⇒ String
Optional.
-
#configure_wifi ⇒ String
Controls Wi-Fi configuring privileges.
-
#preferential_network_service_settings ⇒ Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceSettings
Preferential network service settings.
-
#private_dns_settings ⇒ Google::Apis::AndroidmanagementV1::PrivateDnsSettings
Controls the device's private DNS settings.
-
#tethering_settings ⇒ String
Controls tethering settings.
-
#usb_data_access ⇒ String
Controls what files and/or data can be transferred via USB.
-
#wifi_direct_settings ⇒ String
Controls configuring and using Wi-Fi direct settings.
-
#wifi_roaming_policy ⇒ Google::Apis::AndroidmanagementV1::WifiRoamingPolicy
Wi-Fi roaming policy.
-
#wifi_ssid_policy ⇒ Google::Apis::AndroidmanagementV1::WifiSsidPolicy
Restrictions on which Wi-Fi SSIDs the device can connect to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceConnectivityManagement
constructor
A new instance of DeviceConnectivityManagement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceConnectivityManagement
Returns a new instance of DeviceConnectivityManagement.
2469 2470 2471 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apn_policy ⇒ Google::Apis::AndroidmanagementV1::ApnPolicy
Access Point Name (APN) policy. Configuration for Access Point Names (APNs)
which may override any other APNs on the device. See OVERRIDE_APNS_ENABLED and
overrideApns for details.
Corresponds to the JSON property apnPolicy
2416 2417 2418 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2416 def apn_policy @apn_policy end |
#bluetooth_sharing ⇒ String
Optional. Controls whether Bluetooth sharing is allowed.
Corresponds to the JSON property bluetoothSharing
2421 2422 2423 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2421 def bluetooth_sharing @bluetooth_sharing end |
#configure_wifi ⇒ String
Controls Wi-Fi configuring privileges. Based on the option set, user will have
either full or limited or no control in configuring Wi-Fi networks.
Corresponds to the JSON property configureWifi
2427 2428 2429 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2427 def configure_wifi @configure_wifi end |
#preferential_network_service_settings ⇒ Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceSettings
Preferential network service settings.
Corresponds to the JSON property preferentialNetworkServiceSettings
2432 2433 2434 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2432 def preferential_network_service_settings @preferential_network_service_settings end |
#private_dns_settings ⇒ Google::Apis::AndroidmanagementV1::PrivateDnsSettings
Controls the device's private DNS settings.
Corresponds to the JSON property privateDnsSettings
2437 2438 2439 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2437 def private_dns_settings @private_dns_settings end |
#tethering_settings ⇒ String
Controls tethering settings. Based on the value set, the user is partially or
fully disallowed from using different forms of tethering.
Corresponds to the JSON property tetheringSettings
2443 2444 2445 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2443 def tethering_settings @tethering_settings end |
#usb_data_access ⇒ String
Controls what files and/or data can be transferred via USB. Supported only on
company-owned devices.
Corresponds to the JSON property usbDataAccess
2449 2450 2451 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2449 def usb_data_access @usb_data_access end |
#wifi_direct_settings ⇒ String
Controls configuring and using Wi-Fi direct settings. Supported on company-
owned devices running Android 13 and above.
Corresponds to the JSON property wifiDirectSettings
2455 2456 2457 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2455 def wifi_direct_settings @wifi_direct_settings end |
#wifi_roaming_policy ⇒ Google::Apis::AndroidmanagementV1::WifiRoamingPolicy
Wi-Fi roaming policy.
Corresponds to the JSON property wifiRoamingPolicy
2460 2461 2462 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2460 def wifi_roaming_policy @wifi_roaming_policy end |
#wifi_ssid_policy ⇒ Google::Apis::AndroidmanagementV1::WifiSsidPolicy
Restrictions on which Wi-Fi SSIDs the device can connect to. Note that this
does not affect which networks can be configured on the device. Supported on
company-owned devices running Android 13 and above.
Corresponds to the JSON property wifiSsidPolicy
2467 2468 2469 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2467 def wifi_ssid_policy @wifi_ssid_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2474 def update!(**args) @apn_policy = args[:apn_policy] if args.key?(:apn_policy) @bluetooth_sharing = args[:bluetooth_sharing] if args.key?(:bluetooth_sharing) @configure_wifi = args[:configure_wifi] if args.key?(:configure_wifi) @preferential_network_service_settings = args[:preferential_network_service_settings] if args.key?(:preferential_network_service_settings) @private_dns_settings = args[:private_dns_settings] if args.key?(:private_dns_settings) @tethering_settings = args[:tethering_settings] if args.key?(:tethering_settings) @usb_data_access = args[:usb_data_access] if args.key?(:usb_data_access) @wifi_direct_settings = args[:wifi_direct_settings] if args.key?(:wifi_direct_settings) @wifi_roaming_policy = args[:wifi_roaming_policy] if args.key?(:wifi_roaming_policy) @wifi_ssid_policy = args[:wifi_ssid_policy] if args.key?(:wifi_ssid_policy) end |