Class: Google::Apis::AndroidmanagementV1::DeviceConnectivityManagement

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Covers controls for device connectivity such as Wi-Fi, USB data access, keyboard/mouse connections, and more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceConnectivityManagement

Returns a new instance of DeviceConnectivityManagement.



2458
2459
2460
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apn_policyGoogle::Apis::AndroidmanagementV1::ApnPolicy

Access Point Name (APN) policy. Configuration for Access Point Names (APNs) which may override any other APNs on the device. See OVERRIDE_APNS_ENABLED and overrideApns for details. Corresponds to the JSON property apnPolicy



2410
2411
2412
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2410

def apn_policy
  @apn_policy
end

#bluetooth_sharingString

Optional. Controls whether Bluetooth sharing is allowed. Corresponds to the JSON property bluetoothSharing

Returns:

  • (String)


2415
2416
2417
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2415

def bluetooth_sharing
  @bluetooth_sharing
end

#configure_wifiString

Controls Wi-Fi configuring privileges. Based on the option set, user will have either full or limited or no control in configuring Wi-Fi networks. Corresponds to the JSON property configureWifi

Returns:

  • (String)


2421
2422
2423
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2421

def configure_wifi
  @configure_wifi
end

#preferential_network_service_settingsGoogle::Apis::AndroidmanagementV1::PreferentialNetworkServiceSettings

Preferential network service settings. Corresponds to the JSON property preferentialNetworkServiceSettings



2426
2427
2428
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2426

def preferential_network_service_settings
  @preferential_network_service_settings
end

#tethering_settingsString

Controls tethering settings. Based on the value set, the user is partially or fully disallowed from using different forms of tethering. Corresponds to the JSON property tetheringSettings

Returns:

  • (String)


2432
2433
2434
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2432

def tethering_settings
  @tethering_settings
end

#usb_data_accessString

Controls what files and/or data can be transferred via USB. Supported only on company-owned devices. Corresponds to the JSON property usbDataAccess

Returns:

  • (String)


2438
2439
2440
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2438

def usb_data_access
  @usb_data_access
end

#wifi_direct_settingsString

Controls configuring and using Wi-Fi direct settings. Supported on company- owned devices running Android 13 and above. Corresponds to the JSON property wifiDirectSettings

Returns:

  • (String)


2444
2445
2446
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2444

def wifi_direct_settings
  @wifi_direct_settings
end

#wifi_roaming_policyGoogle::Apis::AndroidmanagementV1::WifiRoamingPolicy

Wi-Fi roaming policy. Corresponds to the JSON property wifiRoamingPolicy



2449
2450
2451
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2449

def wifi_roaming_policy
  @wifi_roaming_policy
end

#wifi_ssid_policyGoogle::Apis::AndroidmanagementV1::WifiSsidPolicy

Restrictions on which Wi-Fi SSIDs the device can connect to. Note that this does not affect which networks can be configured on the device. Supported on company-owned devices running Android 13 and above. Corresponds to the JSON property wifiSsidPolicy



2456
2457
2458
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2456

def wifi_ssid_policy
  @wifi_ssid_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2463

def update!(**args)
  @apn_policy = args[:apn_policy] if args.key?(:apn_policy)
  @bluetooth_sharing = args[:bluetooth_sharing] if args.key?(:bluetooth_sharing)
  @configure_wifi = args[:configure_wifi] if args.key?(:configure_wifi)
  @preferential_network_service_settings = args[:preferential_network_service_settings] if args.key?(:preferential_network_service_settings)
  @tethering_settings = args[:tethering_settings] if args.key?(:tethering_settings)
  @usb_data_access = args[:usb_data_access] if args.key?(:usb_data_access)
  @wifi_direct_settings = args[:wifi_direct_settings] if args.key?(:wifi_direct_settings)
  @wifi_roaming_policy = args[:wifi_roaming_policy] if args.key?(:wifi_roaming_policy)
  @wifi_ssid_policy = args[:wifi_ssid_policy] if args.key?(:wifi_ssid_policy)
end