Class: Google::Apis::AndroidmanagementV1::DeviceRadioState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls for device radio settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceRadioState

Returns a new instance of DeviceRadioState.



2512
2513
2514
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#airplane_mode_stateString

Controls whether airplane mode can be toggled by the user or not. Corresponds to the JSON property airplaneModeState

Returns:

  • (String)


2483
2484
2485
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2483

def airplane_mode_state
  @airplane_mode_state
end

#cellular_two_g_stateString

Controls whether cellular 2G setting can be toggled by the user or not. Corresponds to the JSON property cellularTwoGState

Returns:

  • (String)


2488
2489
2490
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2488

def cellular_two_g_state
  @cellular_two_g_state
end

#minimum_wifi_security_levelString

The minimum required security level of Wi-Fi networks that the device can connect to. Corresponds to the JSON property minimumWifiSecurityLevel

Returns:

  • (String)


2494
2495
2496
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2494

def minimum_wifi_security_level
  @minimum_wifi_security_level
end

#ultra_wideband_stateString

Controls the state of the ultra wideband setting and whether the user can toggle it on or off. Corresponds to the JSON property ultraWidebandState

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2500

def ultra_wideband_state
  @ultra_wideband_state
end

#user_initiated_add_esim_settingsString

Optional. Controls whether the user is allowed to add eSIM profiles. Corresponds to the JSON property userInitiatedAddEsimSettings

Returns:

  • (String)


2505
2506
2507
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2505

def user_initiated_add_esim_settings
  @user_initiated_add_esim_settings
end

#wifi_stateString

Controls current state of Wi-Fi and if user can change its state. Corresponds to the JSON property wifiState

Returns:

  • (String)


2510
2511
2512
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2510

def wifi_state
  @wifi_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2517
2518
2519
2520
2521
2522
2523
2524
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2517

def update!(**args)
  @airplane_mode_state = args[:airplane_mode_state] if args.key?(:airplane_mode_state)
  @cellular_two_g_state = args[:cellular_two_g_state] if args.key?(:cellular_two_g_state)
  @minimum_wifi_security_level = args[:minimum_wifi_security_level] if args.key?(:minimum_wifi_security_level)
  @ultra_wideband_state = args[:ultra_wideband_state] if args.key?(:ultra_wideband_state)
  @user_initiated_add_esim_settings = args[:user_initiated_add_esim_settings] if args.key?(:user_initiated_add_esim_settings)
  @wifi_state = args[:wifi_state] if args.key?(:wifi_state)
end