Class: Google::Apis::AndroidmanagementV1::EnrollmentCompleteEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::EnrollmentCompleteEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Represents that the device has completed enrollment. User should be in the launcher at this point, device at this point will be compliant and all setup steps have been completed. Intentionally empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnrollmentCompleteEvent
constructor
A new instance of EnrollmentCompleteEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnrollmentCompleteEvent
Returns a new instance of EnrollmentCompleteEvent.
2797 2798 2799 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2797 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2802 2803 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2802 def update!(**args) end |