Class: Google::Apis::AndroidmanagementV1::EnrollmentToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

An enrollment token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnrollmentToken

Returns a new instance of EnrollmentToken.



2892
2893
2894
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_dataString

Optional, arbitrary data associated with the enrollment token. This could contain, for example, the ID of an org unit the device is assigned to after enrollment. After a device enrolls with the token, this data will be exposed in the enrollment_token_data field of the Device resource. The data must be 1024 characters or less; otherwise, the creation request will fail. Corresponds to the JSON property additionalData

Returns:

  • (String)


2817
2818
2819
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2817

def additional_data
  @additional_data
end

#allow_personal_usageString

Controls whether personal usage is allowed on a device provisioned with this enrollment token.For company-owned devices: Enabling personal usage allows the user to set up a work profile on the device. Disabling personal usage requires the user provision the device as a fully managed device.For personally-owned devices: Enabling personal usage allows the user to set up a work profile on the device. Disabling personal usage will prevent the device from provisioning. Personal usage cannot be disabled on personally-owned device. Corresponds to the JSON property allowPersonalUsage

Returns:

  • (String)


2828
2829
2830
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2828

def allow_personal_usage
  @allow_personal_usage
end

#durationString

The length of time the enrollment token is valid, ranging from 1 minute to Durations.MAX_VALUE (https://developers.google.com/protocol-buffers/docs/ reference/java/com/google/protobuf/util/Durations.html#MAX_VALUE), approximately 10,000 years. If not specified, the default duration is 1 hour. Please note that if requested duration causes the resulting expiration_timestamp to exceed Timestamps.MAX_VALUE (https://developers.google. com/protocol-buffers/docs/reference/java/com/google/protobuf/util/Timestamps. html#MAX_VALUE), then expiration_timestamp is coerced to Timestamps.MAX_VALUE. Corresponds to the JSON property duration

Returns:

  • (String)


2840
2841
2842
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2840

def duration
  @duration
end

#expiration_timestampString

The expiration time of the token. This is a read-only field generated by the server. Corresponds to the JSON property expirationTimestamp

Returns:

  • (String)


2846
2847
2848
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2846

def expiration_timestamp
  @expiration_timestamp
end

#nameString

The name of the enrollment token, which is generated by the server during creation, in the form enterprises/enterpriseId/enrollmentTokens/ enrollmentTokenId. Corresponds to the JSON property name

Returns:

  • (String)


2853
2854
2855
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2853

def name
  @name
end

#one_time_onlyBoolean Also known as: one_time_only?

Whether the enrollment token is for one time use only. If the flag is set to true, only one device can use it for registration. Corresponds to the JSON property oneTimeOnly

Returns:

  • (Boolean)


2859
2860
2861
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2859

def one_time_only
  @one_time_only
end

#policy_nameString

The name of the policy initially applied to the enrolled device, in the form enterprises/enterpriseId/policies/policyId. If not specified, the policy_name for the device’s user is applied. If user_name is also not specified, enterprises/enterpriseId/policies/default is applied by default. When updating this field, you can specify only the policyId as long as the policyId doesn’t contain any slashes. The rest of the policy name will be inferred. Corresponds to the JSON property policyName

Returns:

  • (String)


2871
2872
2873
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2871

def policy_name
  @policy_name
end

#qr_codeString

A JSON string whose UTF-8 representation can be used to generate a QR code to enroll a device with this enrollment token. To enroll a device using NFC, the NFC record must contain a serialized java.util.Properties representation of the properties in the JSON. Corresponds to the JSON property qrCode

Returns:

  • (String)


2879
2880
2881
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2879

def qr_code
  @qr_code
end

#userGoogle::Apis::AndroidmanagementV1::User

A user belonging to an enterprise. Corresponds to the JSON property user



2884
2885
2886
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2884

def user
  @user
end

#valueString

The token value that's passed to the device and authorizes the device to enroll. This is a read-only field generated by the server. Corresponds to the JSON property value

Returns:

  • (String)


2890
2891
2892
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2890

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2897

def update!(**args)
  @additional_data = args[:additional_data] if args.key?(:additional_data)
  @allow_personal_usage = args[:allow_personal_usage] if args.key?(:allow_personal_usage)
  @duration = args[:duration] if args.key?(:duration)
  @expiration_timestamp = args[:expiration_timestamp] if args.key?(:expiration_timestamp)
  @name = args[:name] if args.key?(:name)
  @one_time_only = args[:one_time_only] if args.key?(:one_time_only)
  @policy_name = args[:policy_name] if args.key?(:policy_name)
  @qr_code = args[:qr_code] if args.key?(:qr_code)
  @user = args[:user] if args.key?(:user)
  @value = args[:value] if args.key?(:value)
end