Class: Google::Apis::AndroidmanagementV1::Enterprise

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

The configuration applied to an enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enterprise

Returns a new instance of Enterprise.



3007
3008
3009
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_auto_approval_enabledBoolean Also known as: app_auto_approval_enabled?

Deprecated and unused. Corresponds to the JSON property appAutoApprovalEnabled

Returns:

  • (Boolean)


2930
2931
2932
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2930

def app_auto_approval_enabled
  @app_auto_approval_enabled
end

#contact_infoGoogle::Apis::AndroidmanagementV1::ContactInfo

Contact details for managed Google Play enterprises. Corresponds to the JSON property contactInfo



2936
2937
2938
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2936

def contact_info
  @contact_info
end

#enabled_notification_typesArray<String>

The types of Google Pub/Sub notifications enabled for the enterprise. Corresponds to the JSON property enabledNotificationTypes

Returns:

  • (Array<String>)


2941
2942
2943
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2941

def enabled_notification_types
  @enabled_notification_types
end

#enterprise_display_nameString

The name of the enterprise displayed to users. This field has a maximum length of 100 characters. Corresponds to the JSON property enterpriseDisplayName

Returns:

  • (String)


2947
2948
2949
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2947

def enterprise_display_name
  @enterprise_display_name
end

#enterprise_typeString

Output only. The type of the enterprise. Corresponds to the JSON property enterpriseType

Returns:

  • (String)


2952
2953
2954
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2952

def enterprise_type
  @enterprise_type
end

#google_authentication_settingsGoogle::Apis::AndroidmanagementV1::GoogleAuthenticationSettings

Contains settings for Google-provided user authentication. Corresponds to the JSON property googleAuthenticationSettings



2957
2958
2959
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2957

def google_authentication_settings
  @google_authentication_settings
end

#logoGoogle::Apis::AndroidmanagementV1::ExternalData

Data hosted at an external location. The data is to be downloaded by Android Device Policy and verified against the hash. Corresponds to the JSON property logo



2963
2964
2965
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2963

def 
  @logo
end

#managed_google_domain_typeString

Output only. The type of managed Google domain. Corresponds to the JSON property managedGoogleDomainType

Returns:

  • (String)


2968
2969
2970
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2968

def managed_google_domain_type
  @managed_google_domain_type
end

#managed_google_play_accounts_enterprise_typeString

Output only. The type of a managed Google Play Accounts enterprise. Corresponds to the JSON property managedGooglePlayAccountsEnterpriseType

Returns:

  • (String)


2973
2974
2975
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2973

def managed_google_play_accounts_enterprise_type
  @managed_google_play_accounts_enterprise_type
end

#nameString

The name of the enterprise which is generated by the server during creation, in the form enterprises/enterpriseId. Corresponds to the JSON property name

Returns:

  • (String)


2979
2980
2981
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2979

def name
  @name
end

#primary_colorFixnum

A color in RGB format that indicates the predominant color to display in the device management app UI. The color components are stored as follows: (red << 16) | (green << 8) | blue, where the value of each component is between 0 and 255, inclusive. Corresponds to the JSON property primaryColor

Returns:

  • (Fixnum)


2987
2988
2989
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2987

def primary_color
  @primary_color
end

#pubsub_topicString

The topic which Pub/Sub notifications are published to, in the form projects/ project/topics/topic. This field is only required if Pub/Sub notifications are enabled. Corresponds to the JSON property pubsubTopic

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2994

def pubsub_topic
  @pubsub_topic
end

#signin_detailsArray<Google::Apis::AndroidmanagementV1::SigninDetail>

Sign-in details of the enterprise. Corresponds to the JSON property signinDetails



2999
3000
3001
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2999

def 
  @signin_details
end

#terms_and_conditionsArray<Google::Apis::AndroidmanagementV1::TermsAndConditions>

Terms and conditions that must be accepted when provisioning a device for this enterprise. A page of terms is generated for each value in this list. Corresponds to the JSON property termsAndConditions



3005
3006
3007
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3005

def terms_and_conditions
  @terms_and_conditions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3012

def update!(**args)
  @app_auto_approval_enabled = args[:app_auto_approval_enabled] if args.key?(:app_auto_approval_enabled)
  @contact_info = args[:contact_info] if args.key?(:contact_info)
  @enabled_notification_types = args[:enabled_notification_types] if args.key?(:enabled_notification_types)
  @enterprise_display_name = args[:enterprise_display_name] if args.key?(:enterprise_display_name)
  @enterprise_type = args[:enterprise_type] if args.key?(:enterprise_type)
  @google_authentication_settings = args[:google_authentication_settings] if args.key?(:google_authentication_settings)
  @logo = args[:logo] if args.key?(:logo)
  @managed_google_domain_type = args[:managed_google_domain_type] if args.key?(:managed_google_domain_type)
  @managed_google_play_accounts_enterprise_type = args[:managed_google_play_accounts_enterprise_type] if args.key?(:managed_google_play_accounts_enterprise_type)
  @name = args[:name] if args.key?(:name)
  @primary_color = args[:primary_color] if args.key?(:primary_color)
  @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic)
  @signin_details = args[:signin_details] if args.key?(:signin_details)
  @terms_and_conditions = args[:terms_and_conditions] if args.key?(:terms_and_conditions)
end