Class: Google::Apis::AndroidmanagementV1::Enterprise
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::Enterprise
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
The configuration applied to an enterprise.
Instance Attribute Summary collapse
-
#app_auto_approval_enabled ⇒ Boolean
(also: #app_auto_approval_enabled?)
Deprecated and unused.
-
#contact_info ⇒ Google::Apis::AndroidmanagementV1::ContactInfo
Contact details for managed Google Play enterprises.
-
#enabled_notification_types ⇒ Array<String>
The types of Google Pub/Sub notifications enabled for the enterprise.
-
#enterprise_display_name ⇒ String
The name of the enterprise displayed to users.
-
#enterprise_type ⇒ String
Output only.
-
#google_authentication_settings ⇒ Google::Apis::AndroidmanagementV1::GoogleAuthenticationSettings
Contains settings for Google-provided user authentication.
-
#logo ⇒ Google::Apis::AndroidmanagementV1::ExternalData
Data hosted at an external location.
-
#managed_google_domain_type ⇒ String
Output only.
-
#managed_google_play_accounts_enterprise_type ⇒ String
Output only.
-
#name ⇒ String
The name of the enterprise which is generated by the server during creation, in the form enterprises/
enterpriseId. -
#primary_color ⇒ Fixnum
A color in RGB format that indicates the predominant color to display in the device management app UI.
-
#pubsub_topic ⇒ String
The topic which Pub/Sub notifications are published to, in the form projects/
project/topics/topic. -
#signin_details ⇒ Array<Google::Apis::AndroidmanagementV1::SigninDetail>
Sign-in details of the enterprise.
-
#terms_and_conditions ⇒ Array<Google::Apis::AndroidmanagementV1::TermsAndConditions>
Terms and conditions that must be accepted when provisioning a device for this enterprise.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enterprise
constructor
A new instance of Enterprise.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enterprise
Returns a new instance of Enterprise.
2995 2996 2997 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_auto_approval_enabled ⇒ Boolean Also known as: app_auto_approval_enabled?
Deprecated and unused.
Corresponds to the JSON property appAutoApprovalEnabled
2918 2919 2920 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2918 def app_auto_approval_enabled @app_auto_approval_enabled end |
#contact_info ⇒ Google::Apis::AndroidmanagementV1::ContactInfo
Contact details for managed Google Play enterprises.
Corresponds to the JSON property contactInfo
2924 2925 2926 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2924 def contact_info @contact_info end |
#enabled_notification_types ⇒ Array<String>
The types of Google Pub/Sub notifications enabled for the enterprise.
Corresponds to the JSON property enabledNotificationTypes
2929 2930 2931 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2929 def enabled_notification_types @enabled_notification_types end |
#enterprise_display_name ⇒ String
The name of the enterprise displayed to users. This field has a maximum length
of 100 characters.
Corresponds to the JSON property enterpriseDisplayName
2935 2936 2937 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2935 def enterprise_display_name @enterprise_display_name end |
#enterprise_type ⇒ String
Output only. The type of the enterprise.
Corresponds to the JSON property enterpriseType
2940 2941 2942 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2940 def enterprise_type @enterprise_type end |
#google_authentication_settings ⇒ Google::Apis::AndroidmanagementV1::GoogleAuthenticationSettings
Contains settings for Google-provided user authentication.
Corresponds to the JSON property googleAuthenticationSettings
2945 2946 2947 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2945 def google_authentication_settings @google_authentication_settings end |
#logo ⇒ Google::Apis::AndroidmanagementV1::ExternalData
Data hosted at an external location. The data is to be downloaded by Android
Device Policy and verified against the hash.
Corresponds to the JSON property logo
2951 2952 2953 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2951 def logo @logo end |
#managed_google_domain_type ⇒ String
Output only. The type of managed Google domain.
Corresponds to the JSON property managedGoogleDomainType
2956 2957 2958 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2956 def managed_google_domain_type @managed_google_domain_type end |
#managed_google_play_accounts_enterprise_type ⇒ String
Output only. The type of a managed Google Play Accounts enterprise.
Corresponds to the JSON property managedGooglePlayAccountsEnterpriseType
2961 2962 2963 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2961 def managed_google_play_accounts_enterprise_type @managed_google_play_accounts_enterprise_type end |
#name ⇒ String
The name of the enterprise which is generated by the server during creation,
in the form enterprises/enterpriseId.
Corresponds to the JSON property name
2967 2968 2969 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2967 def name @name end |
#primary_color ⇒ Fixnum
A color in RGB format that indicates the predominant color to display in the
device management app UI. The color components are stored as follows: (red <<
16) | (green << 8) | blue, where the value of each component is between 0 and
255, inclusive.
Corresponds to the JSON property primaryColor
2975 2976 2977 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2975 def primary_color @primary_color end |
#pubsub_topic ⇒ String
The topic which Pub/Sub notifications are published to, in the form projects/
project/topics/topic. This field is only required if Pub/Sub notifications
are enabled.
Corresponds to the JSON property pubsubTopic
2982 2983 2984 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2982 def pubsub_topic @pubsub_topic end |
#signin_details ⇒ Array<Google::Apis::AndroidmanagementV1::SigninDetail>
Sign-in details of the enterprise.
Corresponds to the JSON property signinDetails
2987 2988 2989 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2987 def signin_details @signin_details end |
#terms_and_conditions ⇒ Array<Google::Apis::AndroidmanagementV1::TermsAndConditions>
Terms and conditions that must be accepted when provisioning a device for this
enterprise. A page of terms is generated for each value in this list.
Corresponds to the JSON property termsAndConditions
2993 2994 2995 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 2993 def terms_and_conditions @terms_and_conditions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3000 def update!(**args) @app_auto_approval_enabled = args[:app_auto_approval_enabled] if args.key?(:app_auto_approval_enabled) @contact_info = args[:contact_info] if args.key?(:contact_info) @enabled_notification_types = args[:enabled_notification_types] if args.key?(:enabled_notification_types) @enterprise_display_name = args[:enterprise_display_name] if args.key?(:enterprise_display_name) @enterprise_type = args[:enterprise_type] if args.key?(:enterprise_type) @google_authentication_settings = args[:google_authentication_settings] if args.key?(:google_authentication_settings) @logo = args[:logo] if args.key?(:logo) @managed_google_domain_type = args[:managed_google_domain_type] if args.key?(:managed_google_domain_type) @managed_google_play_accounts_enterprise_type = args[:managed_google_play_accounts_enterprise_type] if args.key?(:managed_google_play_accounts_enterprise_type) @name = args[:name] if args.key?(:name) @primary_color = args[:primary_color] if args.key?(:primary_color) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @signin_details = args[:signin_details] if args.key?(:signin_details) @terms_and_conditions = args[:terms_and_conditions] if args.key?(:terms_and_conditions) end |