Class: Google::Apis::AndroidmanagementV1::ExtensionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ExtensionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Configuration to enable an app as an extension app, with the capability of interacting with Android Device Policy offline. For Android versions 11 and above, extension apps are exempt from battery restrictions so will not be placed into the restricted App Standby Bucket (https://developer.android.com/ topic/performance/appstandby#restricted-bucket). Extensions apps are also protected against users clearing their data or force-closing the application, although admins can continue to use the clear app data command on extension apps if needed for Android 11 and above.
Instance Attribute Summary collapse
-
#notification_receiver ⇒ String
Fully qualified class name of the receiver service class for Android Device Policy to notify the extension app of any local command status updates.
-
#signing_key_fingerprints_sha256 ⇒ Array<String>
Hex-encoded SHA-256 hashes of the signing key certificates of the extension app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionConfig
constructor
A new instance of ExtensionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionConfig
Returns a new instance of ExtensionConfig.
3155 3156 3157 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#notification_receiver ⇒ String
Fully qualified class name of the receiver service class for Android Device
Policy to notify the extension app of any local command status updates. The
service must be exported in the extension app's AndroidManifest.xml and extend
NotificationReceiverService (https://developers.google.com/android/management/
reference/amapi/com/google/android/managementapi/notification/
NotificationReceiverService) (see Integrate with the AMAPI SDK (https://
developers.google.com/android/management/sdk-integration) guide for more
details).
Corresponds to the JSON property notificationReceiver
3137 3138 3139 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3137 def notification_receiver @notification_receiver end |
#signing_key_fingerprints_sha256 ⇒ Array<String>
Hex-encoded SHA-256 hashes of the signing key certificates of the extension
app. Only hexadecimal string representations of 64 characters are valid.The
signing key certificate fingerprints are always obtained from the Play Store
and this field is used to provide additional signing key certificate
fingerprints. However, if the application is not available on the Play Store,
this field needs to be set. A NonComplianceDetail with INVALID_VALUE is
reported if this field is not set when the application is not available on the
Play Store.The signing key certificate fingerprint of the extension app on the
device must match one of the signing key certificate fingerprints obtained
from the Play Store or the ones provided in this field for the app to be able
to communicate with Android Device Policy.In production use cases, it is
recommended to leave this empty.
Corresponds to the JSON property signingKeyFingerprintsSha256
3153 3154 3155 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3153 def signing_key_fingerprints_sha256 @signing_key_fingerprints_sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3160 3161 3162 3163 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3160 def update!(**args) @notification_receiver = args[:notification_receiver] if args.key?(:notification_receiver) @signing_key_fingerprints_sha256 = args[:signing_key_fingerprints_sha256] if args.key?(:signing_key_fingerprints_sha256) end |