Class: Google::Apis::AndroidmanagementV1::ExternalData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Data hosted at an external location. The data is to be downloaded by Android Device Policy and verified against the hash.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalData

Returns a new instance of ExternalData.



3185
3186
3187
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sha256_hashString

The base-64 encoded SHA-256 hash of the content hosted at url. If the content doesn't match this hash, Android Device Policy won't use the data. Corresponds to the JSON property sha256Hash

Returns:

  • (String)


3175
3176
3177
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3175

def sha256_hash
  @sha256_hash
end

#urlString

The absolute URL to the data, which must use either the http or https scheme. Android Device Policy doesn't provide any credentials in the GET request, so the URL must be publicly accessible. Including a long, random component in the URL may be used to prevent attackers from discovering the URL. Corresponds to the JSON property url

Returns:

  • (String)


3183
3184
3185
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3183

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3190
3191
3192
3193
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3190

def update!(**args)
  @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash)
  @url = args[:url] if args.key?(:url)
end