Class: Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlRequest
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::GenerateEnterpriseUpgradeUrlRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Request message for generating a URL to upgrade an existing managed Google Play Accounts enterprise to a managed Google domain.Note: This feature is not generally available.
Instance Attribute Summary collapse
-
#admin_email ⇒ String
Optional.
-
#allowed_domains ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateEnterpriseUpgradeUrlRequest
constructor
A new instance of GenerateEnterpriseUpgradeUrlRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateEnterpriseUpgradeUrlRequest
Returns a new instance of GenerateEnterpriseUpgradeUrlRequest.
3314 3315 3316 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_email ⇒ String
Optional. Email address used to prefill the admin field of the enterprise
signup form as part of the upgrade process. This value is a hint only and can
be altered by the user. Personal email addresses are not allowed. If
allowedDomains is non-empty then this must belong to one of the allowedDomains.
Corresponds to the JSON property adminEmail
3302 3303 3304 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3302 def admin_email @admin_email end |
#allowed_domains ⇒ Array<String>
Optional. A list of domains that are permitted for the admin email. The IT
admin cannot enter an email address with a domain name that is not in this
list. Subdomains of domains in this list are not allowed but can be allowed by
adding a second entry which has *. prefixed to the domain name (e.g. *.example.
com). If the field is not present or is an empty list then the IT admin is
free to use any valid domain name. Personal email domains are not allowed.
Corresponds to the JSON property allowedDomains
3312 3313 3314 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3312 def allowed_domains @allowed_domains end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3319 3320 3321 3322 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3319 def update!(**args) @admin_email = args[:admin_email] if args.key?(:admin_email) @allowed_domains = args[:allowed_domains] if args.key?(:allowed_domains) end |