Class: Google::Apis::AndroidmanagementV1::GoogleAuthenticationOptions
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::GoogleAuthenticationOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Options for Google authentication during the enrollment.When triggering the enrollment with a SigninDetail, these options are enforced after the user completes third-party sign-in and an EnrollmentToken is created. If this token' s authentication_requirement is set to REQUIRED, these options interact with the SigninDetail.googleAuthenticationOptions that initiated the flow in the following ways: - If the user skipped Google sign-in earlier (permitted by SigninDetail.googleAuthenticationOptions), an error will occur and the user will be prompted to sign in again. - If required_account_email is set on this token and the user signed in with a different email earlier, an error will occur and the user will be asked to sign in again with the correct account.
Instance Attribute Summary collapse
-
#authentication_requirement ⇒ String
Optional.
-
#required_account_email ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAuthenticationOptions
constructor
A new instance of GoogleAuthenticationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAuthenticationOptions
Returns a new instance of GoogleAuthenticationOptions.
3425 3426 3427 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_requirement ⇒ String
Optional. Specifies whether user should authenticate with Google during
enrollment. If this is set to any value other than
AUTHENTICATION_REQUIREMENT_UNSPECIFIED, the enterprise-level setting
googleAuthenticationSettings is ignored for devices enrolled with this token.
Corresponds to the JSON property authenticationRequirement
3416 3417 3418 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3416 def authentication_requirement @authentication_requirement end |
#required_account_email ⇒ String
Optional. Specifies the managed Google account that the user must use during
enrollment. This field can only be set if AuthenticationRequirement is set to
REQUIRED.
Corresponds to the JSON property requiredAccountEmail
3423 3424 3425 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3423 def required_account_email @required_account_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3430 3431 3432 3433 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3430 def update!(**args) @authentication_requirement = args[:authentication_requirement] if args.key?(:authentication_requirement) @required_account_email = args[:required_account_email] if args.key?(:required_account_email) end |