Class: Google::Apis::AndroidmanagementV1::GoogleAuthenticationOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Options for Google authentication during the enrollment.When triggering the enrollment with a SigninDetail, these options are enforced after the user completes third-party sign-in and an EnrollmentToken is created. If this token' s authentication_requirement is set to REQUIRED, these options interact with the SigninDetail.googleAuthenticationOptions that initiated the flow in the following ways: - If the user skipped Google sign-in earlier (permitted by SigninDetail.googleAuthenticationOptions), an error will occur and the user will be prompted to sign in again. - If required_account_email is set on this token and the user signed in with a different email earlier, an error will occur and the user will be asked to sign in again with the correct account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAuthenticationOptions

Returns a new instance of GoogleAuthenticationOptions.



3396
3397
3398
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_requirementString

Optional. Specifies whether user should authenticate with Google during enrollment. If this is set to any value other than AUTHENTICATION_REQUIREMENT_UNSPECIFIED, the enterprise-level setting googleAuthenticationSettings is ignored for devices enrolled with this token. Corresponds to the JSON property authenticationRequirement

Returns:

  • (String)


3387
3388
3389
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3387

def authentication_requirement
  @authentication_requirement
end

#required_account_emailString

Optional. Specifies the managed Google account that the user must use during enrollment. This field can only be set if AuthenticationRequirement is set to REQUIRED. Corresponds to the JSON property requiredAccountEmail

Returns:

  • (String)


3394
3395
3396
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3394

def 
  @required_account_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3401
3402
3403
3404
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3401

def update!(**args)
  @authentication_requirement = args[:authentication_requirement] if args.key?(:authentication_requirement)
  @required_account_email = args[:required_account_email] if args.key?(:required_account_email)
end