Class: Google::Apis::AndroidmanagementV1::GoogleAuthenticationSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::GoogleAuthenticationSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Contains settings for Google-provided user authentication.
Instance Attribute Summary collapse
-
#google_authentication_required ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleAuthenticationSettings
constructor
A new instance of GoogleAuthenticationSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleAuthenticationSettings
Returns a new instance of GoogleAuthenticationSettings.
3453 3454 3455 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_authentication_required ⇒ String
Output only. Whether users need to be authenticated by Google during the
enrollment process. IT admin can specify if Google authentication is enabled
for the enterprise for knowledge worker devices. This value can be set only
via the Google Admin Console. Google authentication can be used with
signin_url In the case where Google authentication is required and a
signin_url is specified, Google authentication will be launched before
signin_url. This value is overridden by EnrollmentToken.
googleAuthenticationOptions and SigninDetail.googleAuthenticationOptions, if
they are set.
Corresponds to the JSON property googleAuthenticationRequired
3451 3452 3453 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3451 def google_authentication_required @google_authentication_required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3458 3459 3460 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3458 def update!(**args) @google_authentication_required = args[:google_authentication_required] if args.key?(:google_authentication_required) end |