Class: Google::Apis::AndroidmanagementV1::GoogleAuthenticationSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Contains settings for Google-provided user authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAuthenticationSettings

Returns a new instance of GoogleAuthenticationSettings.



3370
3371
3372
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_authentication_requiredString

Output only. Whether users need to be authenticated by Google during the enrollment process. IT admin can specify if Google authentication is enabled for the enterprise for knowledge worker devices. This value can be set only via the Google Admin Console. Google authentication can be used with signin_url In the case where Google authentication is required and a signin_url is specified, Google authentication will be launched before signin_url. This value is overridden by EnrollmentToken. googleAuthenticationOptions and SigninDetail.googleAuthenticationOptions, if they are set. Corresponds to the JSON property googleAuthenticationRequired

Returns:

  • (String)


3368
3369
3370
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3368

def google_authentication_required
  @google_authentication_required
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3375
3376
3377
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3375

def update!(**args)
  @google_authentication_required = args[:google_authentication_required] if args.key?(:google_authentication_required)
end