Class: Google::Apis::AndroidmanagementV1::HardwareInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information about device hardware. The fields related to temperature thresholds are only available if hardwareStatusEnabled is true in the device's policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HardwareInfo

Returns a new instance of HardwareInfo.



3527
3528
3529
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#battery_shutdown_temperaturesArray<Float>

Battery shutdown temperature thresholds in Celsius for each battery on the device. Corresponds to the JSON property batteryShutdownTemperatures

Returns:

  • (Array<Float>)


3444
3445
3446
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3444

def battery_shutdown_temperatures
  @battery_shutdown_temperatures
end

#battery_throttling_temperaturesArray<Float>

Battery throttling temperature thresholds in Celsius for each battery on the device. Corresponds to the JSON property batteryThrottlingTemperatures

Returns:

  • (Array<Float>)


3450
3451
3452
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3450

def battery_throttling_temperatures
  @battery_throttling_temperatures
end

#brandString

Brand of the device. For example, Google. Corresponds to the JSON property brand

Returns:

  • (String)


3455
3456
3457
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3455

def brand
  @brand
end

#cpu_shutdown_temperaturesArray<Float>

CPU shutdown temperature thresholds in Celsius for each CPU on the device. Corresponds to the JSON property cpuShutdownTemperatures

Returns:

  • (Array<Float>)


3460
3461
3462
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3460

def cpu_shutdown_temperatures
  @cpu_shutdown_temperatures
end

#cpu_throttling_temperaturesArray<Float>

CPU throttling temperature thresholds in Celsius for each CPU on the device. Corresponds to the JSON property cpuThrottlingTemperatures

Returns:

  • (Array<Float>)


3465
3466
3467
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3465

def cpu_throttling_temperatures
  @cpu_throttling_temperatures
end

#device_baseband_versionString

Baseband version. For example, MDM9625_104662.22.05.34p. Corresponds to the JSON property deviceBasebandVersion

Returns:

  • (String)


3470
3471
3472
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3470

def device_baseband_version
  @device_baseband_version
end

#enterprise_specific_idString

Output only. ID that uniquely identifies a personally-owned device in a particular organization. On the same physical device when enrolled with the same organization, this ID persists across setups and even factory resets. This ID is available on personally-owned devices with a work profile on devices running Android 12 and above. Corresponds to the JSON property enterpriseSpecificId

Returns:

  • (String)


3479
3480
3481
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3479

def enterprise_specific_id
  @enterprise_specific_id
end

#euicc_chip_infoArray<Google::Apis::AndroidmanagementV1::EuiccChipInfo>

Output only. Information related to the eUICC chip. Corresponds to the JSON property euiccChipInfo



3484
3485
3486
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3484

def euicc_chip_info
  @euicc_chip_info
end

#gpu_shutdown_temperaturesArray<Float>

GPU shutdown temperature thresholds in Celsius for each GPU on the device. Corresponds to the JSON property gpuShutdownTemperatures

Returns:

  • (Array<Float>)


3489
3490
3491
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3489

def gpu_shutdown_temperatures
  @gpu_shutdown_temperatures
end

#gpu_throttling_temperaturesArray<Float>

GPU throttling temperature thresholds in Celsius for each GPU on the device. Corresponds to the JSON property gpuThrottlingTemperatures

Returns:

  • (Array<Float>)


3494
3495
3496
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3494

def gpu_throttling_temperatures
  @gpu_throttling_temperatures
end

#hardwareString

Name of the hardware. For example, Angler. Corresponds to the JSON property hardware

Returns:

  • (String)


3499
3500
3501
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3499

def hardware
  @hardware
end

#manufacturerString

Manufacturer. For example, Motorola. Corresponds to the JSON property manufacturer

Returns:

  • (String)


3504
3505
3506
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3504

def manufacturer
  @manufacturer
end

#modelString

The model of the device. For example, Asus Nexus 7. Corresponds to the JSON property model

Returns:

  • (String)


3509
3510
3511
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3509

def model
  @model
end

#serial_numberString

The device serial number. However, for personally-owned devices running Android 12 and above, this is the same as the enterpriseSpecificId. Corresponds to the JSON property serialNumber

Returns:

  • (String)


3515
3516
3517
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3515

def serial_number
  @serial_number
end

#skin_shutdown_temperaturesArray<Float>

Device skin shutdown temperature thresholds in Celsius. Corresponds to the JSON property skinShutdownTemperatures

Returns:

  • (Array<Float>)


3520
3521
3522
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3520

def skin_shutdown_temperatures
  @skin_shutdown_temperatures
end

#skin_throttling_temperaturesArray<Float>

Device skin throttling temperature thresholds in Celsius. Corresponds to the JSON property skinThrottlingTemperatures

Returns:

  • (Array<Float>)


3525
3526
3527
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3525

def skin_throttling_temperatures
  @skin_throttling_temperatures
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3532

def update!(**args)
  @battery_shutdown_temperatures = args[:battery_shutdown_temperatures] if args.key?(:battery_shutdown_temperatures)
  @battery_throttling_temperatures = args[:battery_throttling_temperatures] if args.key?(:battery_throttling_temperatures)
  @brand = args[:brand] if args.key?(:brand)
  @cpu_shutdown_temperatures = args[:cpu_shutdown_temperatures] if args.key?(:cpu_shutdown_temperatures)
  @cpu_throttling_temperatures = args[:cpu_throttling_temperatures] if args.key?(:cpu_throttling_temperatures)
  @device_baseband_version = args[:device_baseband_version] if args.key?(:device_baseband_version)
  @enterprise_specific_id = args[:enterprise_specific_id] if args.key?(:enterprise_specific_id)
  @euicc_chip_info = args[:euicc_chip_info] if args.key?(:euicc_chip_info)
  @gpu_shutdown_temperatures = args[:gpu_shutdown_temperatures] if args.key?(:gpu_shutdown_temperatures)
  @gpu_throttling_temperatures = args[:gpu_throttling_temperatures] if args.key?(:gpu_throttling_temperatures)
  @hardware = args[:hardware] if args.key?(:hardware)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @model = args[:model] if args.key?(:model)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @skin_shutdown_temperatures = args[:skin_shutdown_temperatures] if args.key?(:skin_shutdown_temperatures)
  @skin_throttling_temperatures = args[:skin_throttling_temperatures] if args.key?(:skin_throttling_temperatures)
end