Class: Google::Apis::AndroidmanagementV1::HardwareInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information about device hardware. The fields related to temperature thresholds are only available if hardwareStatusEnabled is true in the device's policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HardwareInfo

Returns a new instance of HardwareInfo.



3467
3468
3469
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#battery_shutdown_temperaturesArray<Float>

Battery shutdown temperature thresholds in Celsius for each battery on the device. Corresponds to the JSON property batteryShutdownTemperatures

Returns:

  • (Array<Float>)


3384
3385
3386
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3384

def battery_shutdown_temperatures
  @battery_shutdown_temperatures
end

#battery_throttling_temperaturesArray<Float>

Battery throttling temperature thresholds in Celsius for each battery on the device. Corresponds to the JSON property batteryThrottlingTemperatures

Returns:

  • (Array<Float>)


3390
3391
3392
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3390

def battery_throttling_temperatures
  @battery_throttling_temperatures
end

#brandString

Brand of the device. For example, Google. Corresponds to the JSON property brand

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3395

def brand
  @brand
end

#cpu_shutdown_temperaturesArray<Float>

CPU shutdown temperature thresholds in Celsius for each CPU on the device. Corresponds to the JSON property cpuShutdownTemperatures

Returns:

  • (Array<Float>)


3400
3401
3402
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3400

def cpu_shutdown_temperatures
  @cpu_shutdown_temperatures
end

#cpu_throttling_temperaturesArray<Float>

CPU throttling temperature thresholds in Celsius for each CPU on the device. Corresponds to the JSON property cpuThrottlingTemperatures

Returns:

  • (Array<Float>)


3405
3406
3407
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3405

def cpu_throttling_temperatures
  @cpu_throttling_temperatures
end

#device_baseband_versionString

Baseband version. For example, MDM9625_104662.22.05.34p. Corresponds to the JSON property deviceBasebandVersion

Returns:

  • (String)


3410
3411
3412
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3410

def device_baseband_version
  @device_baseband_version
end

#enterprise_specific_idString

Output only. ID that uniquely identifies a personally-owned device in a particular organization. On the same physical device when enrolled with the same organization, this ID persists across setups and even factory resets. This ID is available on personally-owned devices with a work profile on devices running Android 12 and above. Corresponds to the JSON property enterpriseSpecificId

Returns:

  • (String)


3419
3420
3421
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3419

def enterprise_specific_id
  @enterprise_specific_id
end

#euicc_chip_infoArray<Google::Apis::AndroidmanagementV1::EuiccChipInfo>

Output only. Information related to the eUICC chip. Corresponds to the JSON property euiccChipInfo



3424
3425
3426
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3424

def euicc_chip_info
  @euicc_chip_info
end

#gpu_shutdown_temperaturesArray<Float>

GPU shutdown temperature thresholds in Celsius for each GPU on the device. Corresponds to the JSON property gpuShutdownTemperatures

Returns:

  • (Array<Float>)


3429
3430
3431
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3429

def gpu_shutdown_temperatures
  @gpu_shutdown_temperatures
end

#gpu_throttling_temperaturesArray<Float>

GPU throttling temperature thresholds in Celsius for each GPU on the device. Corresponds to the JSON property gpuThrottlingTemperatures

Returns:

  • (Array<Float>)


3434
3435
3436
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3434

def gpu_throttling_temperatures
  @gpu_throttling_temperatures
end

#hardwareString

Name of the hardware. For example, Angler. Corresponds to the JSON property hardware

Returns:

  • (String)


3439
3440
3441
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3439

def hardware
  @hardware
end

#manufacturerString

Manufacturer. For example, Motorola. Corresponds to the JSON property manufacturer

Returns:

  • (String)


3444
3445
3446
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3444

def manufacturer
  @manufacturer
end

#modelString

The model of the device. For example, Asus Nexus 7. Corresponds to the JSON property model

Returns:

  • (String)


3449
3450
3451
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3449

def model
  @model
end

#serial_numberString

The device serial number. However, for personally-owned devices running Android 12 and above, this is the same as the enterpriseSpecificId. Corresponds to the JSON property serialNumber

Returns:

  • (String)


3455
3456
3457
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3455

def serial_number
  @serial_number
end

#skin_shutdown_temperaturesArray<Float>

Device skin shutdown temperature thresholds in Celsius. Corresponds to the JSON property skinShutdownTemperatures

Returns:

  • (Array<Float>)


3460
3461
3462
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3460

def skin_shutdown_temperatures
  @skin_shutdown_temperatures
end

#skin_throttling_temperaturesArray<Float>

Device skin throttling temperature thresholds in Celsius. Corresponds to the JSON property skinThrottlingTemperatures

Returns:

  • (Array<Float>)


3465
3466
3467
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3465

def skin_throttling_temperatures
  @skin_throttling_temperatures
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
3485
3486
3487
3488
3489
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3472

def update!(**args)
  @battery_shutdown_temperatures = args[:battery_shutdown_temperatures] if args.key?(:battery_shutdown_temperatures)
  @battery_throttling_temperatures = args[:battery_throttling_temperatures] if args.key?(:battery_throttling_temperatures)
  @brand = args[:brand] if args.key?(:brand)
  @cpu_shutdown_temperatures = args[:cpu_shutdown_temperatures] if args.key?(:cpu_shutdown_temperatures)
  @cpu_throttling_temperatures = args[:cpu_throttling_temperatures] if args.key?(:cpu_throttling_temperatures)
  @device_baseband_version = args[:device_baseband_version] if args.key?(:device_baseband_version)
  @enterprise_specific_id = args[:enterprise_specific_id] if args.key?(:enterprise_specific_id)
  @euicc_chip_info = args[:euicc_chip_info] if args.key?(:euicc_chip_info)
  @gpu_shutdown_temperatures = args[:gpu_shutdown_temperatures] if args.key?(:gpu_shutdown_temperatures)
  @gpu_throttling_temperatures = args[:gpu_throttling_temperatures] if args.key?(:gpu_throttling_temperatures)
  @hardware = args[:hardware] if args.key?(:hardware)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @model = args[:model] if args.key?(:model)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @skin_shutdown_temperatures = args[:skin_shutdown_temperatures] if args.key?(:skin_shutdown_temperatures)
  @skin_throttling_temperatures = args[:skin_throttling_temperatures] if args.key?(:skin_throttling_temperatures)
end