Class: Google::Apis::AndroidmanagementV1::HardwareInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::HardwareInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Information about device hardware. The fields related to temperature thresholds are only available if hardwareStatusEnabled is true in the device's policy.
Instance Attribute Summary collapse
-
#battery_shutdown_temperatures ⇒ Array<Float>
Battery shutdown temperature thresholds in Celsius for each battery on the device.
-
#battery_throttling_temperatures ⇒ Array<Float>
Battery throttling temperature thresholds in Celsius for each battery on the device.
-
#brand ⇒ String
Brand of the device.
-
#cpu_shutdown_temperatures ⇒ Array<Float>
CPU shutdown temperature thresholds in Celsius for each CPU on the device.
-
#cpu_throttling_temperatures ⇒ Array<Float>
CPU throttling temperature thresholds in Celsius for each CPU on the device.
-
#device_baseband_version ⇒ String
Baseband version.
-
#enterprise_specific_id ⇒ String
Output only.
-
#euicc_chip_info ⇒ Array<Google::Apis::AndroidmanagementV1::EuiccChipInfo>
Output only.
-
#gpu_shutdown_temperatures ⇒ Array<Float>
GPU shutdown temperature thresholds in Celsius for each GPU on the device.
-
#gpu_throttling_temperatures ⇒ Array<Float>
GPU throttling temperature thresholds in Celsius for each GPU on the device.
-
#hardware ⇒ String
Name of the hardware.
-
#manufacturer ⇒ String
Manufacturer.
-
#model ⇒ String
The model of the device.
-
#serial_number ⇒ String
The device serial number.
-
#skin_shutdown_temperatures ⇒ Array<Float>
Device skin shutdown temperature thresholds in Celsius.
-
#skin_throttling_temperatures ⇒ Array<Float>
Device skin throttling temperature thresholds in Celsius.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HardwareInfo
constructor
A new instance of HardwareInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HardwareInfo
Returns a new instance of HardwareInfo.
3461 3462 3463 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#battery_shutdown_temperatures ⇒ Array<Float>
Battery shutdown temperature thresholds in Celsius for each battery on the
device.
Corresponds to the JSON property batteryShutdownTemperatures
3378 3379 3380 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3378 def battery_shutdown_temperatures @battery_shutdown_temperatures end |
#battery_throttling_temperatures ⇒ Array<Float>
Battery throttling temperature thresholds in Celsius for each battery on the
device.
Corresponds to the JSON property batteryThrottlingTemperatures
3384 3385 3386 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3384 def battery_throttling_temperatures @battery_throttling_temperatures end |
#brand ⇒ String
Brand of the device. For example, Google.
Corresponds to the JSON property brand
3389 3390 3391 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3389 def brand @brand end |
#cpu_shutdown_temperatures ⇒ Array<Float>
CPU shutdown temperature thresholds in Celsius for each CPU on the device.
Corresponds to the JSON property cpuShutdownTemperatures
3394 3395 3396 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3394 def cpu_shutdown_temperatures @cpu_shutdown_temperatures end |
#cpu_throttling_temperatures ⇒ Array<Float>
CPU throttling temperature thresholds in Celsius for each CPU on the device.
Corresponds to the JSON property cpuThrottlingTemperatures
3399 3400 3401 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3399 def cpu_throttling_temperatures @cpu_throttling_temperatures end |
#device_baseband_version ⇒ String
Baseband version. For example, MDM9625_104662.22.05.34p.
Corresponds to the JSON property deviceBasebandVersion
3404 3405 3406 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3404 def device_baseband_version @device_baseband_version end |
#enterprise_specific_id ⇒ String
Output only. ID that uniquely identifies a personally-owned device in a
particular organization. On the same physical device when enrolled with the
same organization, this ID persists across setups and even factory resets.
This ID is available on personally-owned devices with a work profile on
devices running Android 12 and above.
Corresponds to the JSON property enterpriseSpecificId
3413 3414 3415 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3413 def enterprise_specific_id @enterprise_specific_id end |
#euicc_chip_info ⇒ Array<Google::Apis::AndroidmanagementV1::EuiccChipInfo>
Output only. Information related to the eUICC chip.
Corresponds to the JSON property euiccChipInfo
3418 3419 3420 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3418 def euicc_chip_info @euicc_chip_info end |
#gpu_shutdown_temperatures ⇒ Array<Float>
GPU shutdown temperature thresholds in Celsius for each GPU on the device.
Corresponds to the JSON property gpuShutdownTemperatures
3423 3424 3425 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3423 def gpu_shutdown_temperatures @gpu_shutdown_temperatures end |
#gpu_throttling_temperatures ⇒ Array<Float>
GPU throttling temperature thresholds in Celsius for each GPU on the device.
Corresponds to the JSON property gpuThrottlingTemperatures
3428 3429 3430 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3428 def gpu_throttling_temperatures @gpu_throttling_temperatures end |
#hardware ⇒ String
Name of the hardware. For example, Angler.
Corresponds to the JSON property hardware
3433 3434 3435 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3433 def hardware @hardware end |
#manufacturer ⇒ String
Manufacturer. For example, Motorola.
Corresponds to the JSON property manufacturer
3438 3439 3440 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3438 def manufacturer @manufacturer end |
#model ⇒ String
The model of the device. For example, Asus Nexus 7.
Corresponds to the JSON property model
3443 3444 3445 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3443 def model @model end |
#serial_number ⇒ String
The device serial number. However, for personally-owned devices running
Android 12 and above, this is the same as the enterpriseSpecificId.
Corresponds to the JSON property serialNumber
3449 3450 3451 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3449 def serial_number @serial_number end |
#skin_shutdown_temperatures ⇒ Array<Float>
Device skin shutdown temperature thresholds in Celsius.
Corresponds to the JSON property skinShutdownTemperatures
3454 3455 3456 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3454 def skin_shutdown_temperatures @skin_shutdown_temperatures end |
#skin_throttling_temperatures ⇒ Array<Float>
Device skin throttling temperature thresholds in Celsius.
Corresponds to the JSON property skinThrottlingTemperatures
3459 3460 3461 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3459 def skin_throttling_temperatures @skin_throttling_temperatures end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3466 def update!(**args) @battery_shutdown_temperatures = args[:battery_shutdown_temperatures] if args.key?(:battery_shutdown_temperatures) @battery_throttling_temperatures = args[:battery_throttling_temperatures] if args.key?(:battery_throttling_temperatures) @brand = args[:brand] if args.key?(:brand) @cpu_shutdown_temperatures = args[:cpu_shutdown_temperatures] if args.key?(:cpu_shutdown_temperatures) @cpu_throttling_temperatures = args[:cpu_throttling_temperatures] if args.key?(:cpu_throttling_temperatures) @device_baseband_version = args[:device_baseband_version] if args.key?(:device_baseband_version) @enterprise_specific_id = args[:enterprise_specific_id] if args.key?(:enterprise_specific_id) @euicc_chip_info = args[:euicc_chip_info] if args.key?(:euicc_chip_info) @gpu_shutdown_temperatures = args[:gpu_shutdown_temperatures] if args.key?(:gpu_shutdown_temperatures) @gpu_throttling_temperatures = args[:gpu_throttling_temperatures] if args.key?(:gpu_throttling_temperatures) @hardware = args[:hardware] if args.key?(:hardware) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @model = args[:model] if args.key?(:model) @serial_number = args[:serial_number] if args.key?(:serial_number) @skin_shutdown_temperatures = args[:skin_shutdown_temperatures] if args.key?(:skin_shutdown_temperatures) @skin_throttling_temperatures = args[:skin_throttling_temperatures] if args.key?(:skin_throttling_temperatures) end |