Class: Google::Apis::AndroidmanagementV1::HardwareStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Hardware status. Temperatures may be compared to the temperature thresholds available in hardwareInfo to determine hardware health.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HardwareStatus

Returns a new instance of HardwareStatus.



3595
3596
3597
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#battery_temperaturesArray<Float>

Current battery temperatures in Celsius for each battery on the device. Corresponds to the JSON property batteryTemperatures

Returns:

  • (Array<Float>)


3560
3561
3562
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3560

def battery_temperatures
  @battery_temperatures
end

#cpu_temperaturesArray<Float>

Current CPU temperatures in Celsius for each CPU on the device. Corresponds to the JSON property cpuTemperatures

Returns:

  • (Array<Float>)


3565
3566
3567
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3565

def cpu_temperatures
  @cpu_temperatures
end

#cpu_usagesArray<Float>

CPU usages in percentage for each core available on the device. Usage is 0 for each unplugged core. Empty array implies that CPU usage is not supported in the system. Corresponds to the JSON property cpuUsages

Returns:

  • (Array<Float>)


3572
3573
3574
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3572

def cpu_usages
  @cpu_usages
end

#create_timeString

The time the measurements were taken. Corresponds to the JSON property createTime

Returns:

  • (String)


3577
3578
3579
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3577

def create_time
  @create_time
end

#fan_speedsArray<Float>

Fan speeds in RPM for each fan on the device. Empty array means that there are no fans or fan speed is not supported on the system. Corresponds to the JSON property fanSpeeds

Returns:

  • (Array<Float>)


3583
3584
3585
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3583

def fan_speeds
  @fan_speeds
end

#gpu_temperaturesArray<Float>

Current GPU temperatures in Celsius for each GPU on the device. Corresponds to the JSON property gpuTemperatures

Returns:

  • (Array<Float>)


3588
3589
3590
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3588

def gpu_temperatures
  @gpu_temperatures
end

#skin_temperaturesArray<Float>

Current device skin temperatures in Celsius. Corresponds to the JSON property skinTemperatures

Returns:

  • (Array<Float>)


3593
3594
3595
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3593

def skin_temperatures
  @skin_temperatures
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3600
3601
3602
3603
3604
3605
3606
3607
3608
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3600

def update!(**args)
  @battery_temperatures = args[:battery_temperatures] if args.key?(:battery_temperatures)
  @cpu_temperatures = args[:cpu_temperatures] if args.key?(:cpu_temperatures)
  @cpu_usages = args[:cpu_usages] if args.key?(:cpu_usages)
  @create_time = args[:create_time] if args.key?(:create_time)
  @fan_speeds = args[:fan_speeds] if args.key?(:fan_speeds)
  @gpu_temperatures = args[:gpu_temperatures] if args.key?(:gpu_temperatures)
  @skin_temperatures = args[:skin_temperatures] if args.key?(:skin_temperatures)
end