Class: Google::Apis::AndroidmanagementV1::HardwareStatus
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::HardwareStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Hardware status. Temperatures may be compared to the temperature thresholds available in hardwareInfo to determine hardware health.
Instance Attribute Summary collapse
-
#battery_temperatures ⇒ Array<Float>
Current battery temperatures in Celsius for each battery on the device.
-
#cpu_temperatures ⇒ Array<Float>
Current CPU temperatures in Celsius for each CPU on the device.
-
#cpu_usages ⇒ Array<Float>
CPU usages in percentage for each core available on the device.
-
#create_time ⇒ String
The time the measurements were taken.
-
#fan_speeds ⇒ Array<Float>
Fan speeds in RPM for each fan on the device.
-
#gpu_temperatures ⇒ Array<Float>
Current GPU temperatures in Celsius for each GPU on the device.
-
#skin_temperatures ⇒ Array<Float>
Current device skin temperatures in Celsius.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HardwareStatus
constructor
A new instance of HardwareStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HardwareStatus
Returns a new instance of HardwareStatus.
3529 3530 3531 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#battery_temperatures ⇒ Array<Float>
Current battery temperatures in Celsius for each battery on the device.
Corresponds to the JSON property batteryTemperatures
3494 3495 3496 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3494 def battery_temperatures @battery_temperatures end |
#cpu_temperatures ⇒ Array<Float>
Current CPU temperatures in Celsius for each CPU on the device.
Corresponds to the JSON property cpuTemperatures
3499 3500 3501 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3499 def cpu_temperatures @cpu_temperatures end |
#cpu_usages ⇒ Array<Float>
CPU usages in percentage for each core available on the device. Usage is 0 for
each unplugged core. Empty array implies that CPU usage is not supported in
the system.
Corresponds to the JSON property cpuUsages
3506 3507 3508 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3506 def cpu_usages @cpu_usages end |
#create_time ⇒ String
The time the measurements were taken.
Corresponds to the JSON property createTime
3511 3512 3513 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3511 def create_time @create_time end |
#fan_speeds ⇒ Array<Float>
Fan speeds in RPM for each fan on the device. Empty array means that there are
no fans or fan speed is not supported on the system.
Corresponds to the JSON property fanSpeeds
3517 3518 3519 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3517 def fan_speeds @fan_speeds end |
#gpu_temperatures ⇒ Array<Float>
Current GPU temperatures in Celsius for each GPU on the device.
Corresponds to the JSON property gpuTemperatures
3522 3523 3524 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3522 def gpu_temperatures @gpu_temperatures end |
#skin_temperatures ⇒ Array<Float>
Current device skin temperatures in Celsius.
Corresponds to the JSON property skinTemperatures
3527 3528 3529 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3527 def skin_temperatures @skin_temperatures end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3534 3535 3536 3537 3538 3539 3540 3541 3542 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3534 def update!(**args) @battery_temperatures = args[:battery_temperatures] if args.key?(:battery_temperatures) @cpu_temperatures = args[:cpu_temperatures] if args.key?(:cpu_temperatures) @cpu_usages = args[:cpu_usages] if args.key?(:cpu_usages) @create_time = args[:create_time] if args.key?(:create_time) @fan_speeds = args[:fan_speeds] if args.key?(:fan_speeds) @gpu_temperatures = args[:gpu_temperatures] if args.key?(:gpu_temperatures) @skin_temperatures = args[:skin_temperatures] if args.key?(:skin_temperatures) end |