Class: Google::Apis::AndroidmanagementV1::InstallConstraint
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::InstallConstraint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Amongst apps with InstallType set to: FORCE_INSTALLED PREINSTALLEDthis defines a set of restrictions for the app installation. At least one of the fields must be set. When multiple fields are set, then all the constraints need to be satisfied for the app to be installed.
Instance Attribute Summary collapse
-
#charging_constraint ⇒ String
Optional.
-
#device_idle_constraint ⇒ String
Optional.
-
#network_type_constraint ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstallConstraint
constructor
A new instance of InstallConstraint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstallConstraint
Returns a new instance of InstallConstraint.
3633 3634 3635 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#charging_constraint ⇒ String
Optional. Charging constraint.
Corresponds to the JSON property chargingConstraint
3621 3622 3623 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3621 def charging_constraint @charging_constraint end |
#device_idle_constraint ⇒ String
Optional. Device idle constraint.
Corresponds to the JSON property deviceIdleConstraint
3626 3627 3628 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3626 def device_idle_constraint @device_idle_constraint end |
#network_type_constraint ⇒ String
Optional. Network type constraint.
Corresponds to the JSON property networkTypeConstraint
3631 3632 3633 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3631 def network_type_constraint @network_type_constraint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3638 3639 3640 3641 3642 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3638 def update!(**args) @charging_constraint = args[:charging_constraint] if args.key?(:charging_constraint) @device_idle_constraint = args[:device_idle_constraint] if args.key?(:device_idle_constraint) @network_type_constraint = args[:network_type_constraint] if args.key?(:network_type_constraint) end |