Class: Google::Apis::AndroidmanagementV1::InstallConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Amongst apps with InstallType set to: FORCE_INSTALLED PREINSTALLEDthis defines a set of restrictions for the app installation. At least one of the fields must be set. When multiple fields are set, then all the constraints need to be satisfied for the app to be installed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstallConstraint

Returns a new instance of InstallConstraint.



3573
3574
3575
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#charging_constraintString

Optional. Charging constraint. Corresponds to the JSON property chargingConstraint

Returns:

  • (String)


3561
3562
3563
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3561

def charging_constraint
  @charging_constraint
end

#device_idle_constraintString

Optional. Device idle constraint. Corresponds to the JSON property deviceIdleConstraint

Returns:

  • (String)


3566
3567
3568
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3566

def device_idle_constraint
  @device_idle_constraint
end

#network_type_constraintString

Optional. Network type constraint. Corresponds to the JSON property networkTypeConstraint

Returns:

  • (String)


3571
3572
3573
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3571

def network_type_constraint
  @network_type_constraint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3578
3579
3580
3581
3582
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3578

def update!(**args)
  @charging_constraint = args[:charging_constraint] if args.key?(:charging_constraint)
  @device_idle_constraint = args[:device_idle_constraint] if args.key?(:device_idle_constraint)
  @network_type_constraint = args[:network_type_constraint] if args.key?(:network_type_constraint)
end