Class: Google::Apis::AndroidmanagementV1::InternalErrorDetails
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::InternalErrorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Internal error details if present for the ADD_ESIM or REMOVE_ESIM command.
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Output only.
-
#error_code_detail ⇒ String
Output only.
-
#operation_code ⇒ Fixnum
Output only.
-
#operation_code_detail ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InternalErrorDetails
constructor
A new instance of InternalErrorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InternalErrorDetails
Returns a new instance of InternalErrorDetails.
3609 3610 3611 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Output only. Integer representation of the error code as specified here (https:
//developer.android.com/reference/android/telephony/euicc/EuiccManager#
EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE). See also,
OPERATION_SMDX_SUBJECT_REASON_CODE. See error_code_detail for more details.
Corresponds to the JSON property errorCode
3589 3590 3591 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3589 def error_code @error_code end |
#error_code_detail ⇒ String
Output only. The error code detail corresponding to the error_code.
Corresponds to the JSON property errorCodeDetail
3594 3595 3596 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3594 def error_code_detail @error_code_detail end |
#operation_code ⇒ Fixnum
Output only. Integer representation of the operation code as specified here (
https://developer.android.com/reference/android/telephony/euicc/EuiccManager#
EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE). See operation_code_detail for more
details.
Corresponds to the JSON property operationCode
3602 3603 3604 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3602 def operation_code @operation_code end |
#operation_code_detail ⇒ String
Output only. The operation code detail corresponding to the operation_code.
Corresponds to the JSON property operationCodeDetail
3607 3608 3609 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3607 def operation_code_detail @operation_code_detail end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3614 3615 3616 3617 3618 3619 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3614 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @error_code_detail = args[:error_code_detail] if args.key?(:error_code_detail) @operation_code = args[:operation_code] if args.key?(:operation_code) @operation_code_detail = args[:operation_code_detail] if args.key?(:operation_code_detail) end |