Class: Google::Apis::AndroidmanagementV1::KeyDestructionEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::KeyDestructionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A cryptographic key including user installed, admin installed and system maintained private key is removed from the device either by the user or management. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.
Instance Attribute Summary collapse
-
#application_uid ⇒ Fixnum
UID of the application which owns the key.
-
#key_alias ⇒ String
Alias of the key.
-
#success ⇒ Boolean
(also: #success?)
Whether the operation was successful.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyDestructionEvent
constructor
A new instance of KeyDestructionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyDestructionEvent
Returns a new instance of KeyDestructionEvent.
3658 3659 3660 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_uid ⇒ Fixnum
UID of the application which owns the key.
Corresponds to the JSON property applicationUid
3645 3646 3647 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3645 def application_uid @application_uid end |
#key_alias ⇒ String
Alias of the key.
Corresponds to the JSON property keyAlias
3650 3651 3652 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3650 def key_alias @key_alias end |
#success ⇒ Boolean Also known as: success?
Whether the operation was successful.
Corresponds to the JSON property success
3655 3656 3657 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3655 def success @success end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3663 3664 3665 3666 3667 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3663 def update!(**args) @application_uid = args[:application_uid] if args.key?(:application_uid) @key_alias = args[:key_alias] if args.key?(:key_alias) @success = args[:success] if args.key?(:success) end |