Class: Google::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A cryptographic key including user installed, admin installed and system maintained private key is determined to be corrupted due to storage corruption, hardware failure or some OS issue. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyIntegrityViolationEvent

Returns a new instance of KeyIntegrityViolationEvent.



3824
3825
3826
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_uidFixnum

UID of the application which owns the key Corresponds to the JSON property applicationUid

Returns:

  • (Fixnum)


3817
3818
3819
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3817

def application_uid
  @application_uid
end

#key_aliasString

Alias of the key. Corresponds to the JSON property keyAlias

Returns:

  • (String)


3822
3823
3824
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3822

def key_alias
  @key_alias
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3829
3830
3831
3832
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3829

def update!(**args)
  @application_uid = args[:application_uid] if args.key?(:application_uid)
  @key_alias = args[:key_alias] if args.key?(:key_alias)
end