Class: Google::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A cryptographic key including user installed, admin installed and system maintained private key is determined to be corrupted due to storage corruption, hardware failure or some OS issue. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyIntegrityViolationEvent

Returns a new instance of KeyIntegrityViolationEvent.



3764
3765
3766
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_uidFixnum

UID of the application which owns the key Corresponds to the JSON property applicationUid

Returns:

  • (Fixnum)


3757
3758
3759
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3757

def application_uid
  @application_uid
end

#key_aliasString

Alias of the key. Corresponds to the JSON property keyAlias

Returns:

  • (String)


3762
3763
3764
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3762

def key_alias
  @key_alias
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3769
3770
3771
3772
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3769

def update!(**args)
  @application_uid = args[:application_uid] if args.key?(:application_uid)
  @key_alias = args[:key_alias] if args.key?(:key_alias)
end