Class: Google::Apis::AndroidmanagementV1::KeyedAppState
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::KeyedAppState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Keyed app state reported by the app.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time of the app state on the device.
-
#data ⇒ String
Optionally, a machine-readable value to be read by the EMM.
-
#key ⇒ String
The key for the app state.
-
#last_update_time ⇒ String
The time the app state was most recently updated.
-
#message ⇒ String
Optionally, a free-form message string to explain the app state.
-
#severity ⇒ String
The severity of the app state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyedAppState
constructor
A new instance of KeyedAppState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyedAppState
Returns a new instance of KeyedAppState.
3875 3876 3877 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time of the app state on the device.
Corresponds to the JSON property createTime
3842 3843 3844 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3842 def create_time @create_time end |
#data ⇒ String
Optionally, a machine-readable value to be read by the EMM. For example,
setting values that the admin can choose to query against in the EMM console (
e.g. “notify me if the battery_warning data < 10”).
Corresponds to the JSON property data
3849 3850 3851 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3849 def data @data end |
#key ⇒ String
The key for the app state. Acts as a point of reference for what the app is
providing state for. For example, when providing managed configuration
feedback, this key could be the managed configuration key.
Corresponds to the JSON property key
3856 3857 3858 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3856 def key @key end |
#last_update_time ⇒ String
The time the app state was most recently updated.
Corresponds to the JSON property lastUpdateTime
3861 3862 3863 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3861 def last_update_time @last_update_time end |
#message ⇒ String
Optionally, a free-form message string to explain the app state. If the state
was triggered by a particular value (e.g. a managed configuration value), it
should be included in the message.
Corresponds to the JSON property message
3868 3869 3870 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3868 def @message end |
#severity ⇒ String
The severity of the app state.
Corresponds to the JSON property severity
3873 3874 3875 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3873 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3880 3881 3882 3883 3884 3885 3886 3887 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3880 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data = args[:data] if args.key?(:data) @key = args[:key] if args.key?(:key) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @message = args[:message] if args.key?(:message) @severity = args[:severity] if args.key?(:severity) end |