Class: Google::Apis::AndroidmanagementV1::KeyedAppState
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::KeyedAppState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Keyed app state reported by the app.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time of the app state on the device.
-
#data ⇒ String
Optionally, a machine-readable value to be read by the EMM.
-
#key ⇒ String
The key for the app state.
-
#last_update_time ⇒ String
The time the app state was most recently updated.
-
#message ⇒ String
Optionally, a free-form message string to explain the app state.
-
#severity ⇒ String
The severity of the app state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyedAppState
constructor
A new instance of KeyedAppState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyedAppState
Returns a new instance of KeyedAppState.
3815 3816 3817 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time of the app state on the device.
Corresponds to the JSON property createTime
3782 3783 3784 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3782 def create_time @create_time end |
#data ⇒ String
Optionally, a machine-readable value to be read by the EMM. For example,
setting values that the admin can choose to query against in the EMM console (
e.g. “notify me if the battery_warning data < 10”).
Corresponds to the JSON property data
3789 3790 3791 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3789 def data @data end |
#key ⇒ String
The key for the app state. Acts as a point of reference for what the app is
providing state for. For example, when providing managed configuration
feedback, this key could be the managed configuration key.
Corresponds to the JSON property key
3796 3797 3798 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3796 def key @key end |
#last_update_time ⇒ String
The time the app state was most recently updated.
Corresponds to the JSON property lastUpdateTime
3801 3802 3803 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3801 def last_update_time @last_update_time end |
#message ⇒ String
Optionally, a free-form message string to explain the app state. If the state
was triggered by a particular value (e.g. a managed configuration value), it
should be included in the message.
Corresponds to the JSON property message
3808 3809 3810 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3808 def @message end |
#severity ⇒ String
The severity of the app state.
Corresponds to the JSON property severity
3813 3814 3815 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3813 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3820 3821 3822 3823 3824 3825 3826 3827 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3820 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data = args[:data] if args.key?(:data) @key = args[:key] if args.key?(:key) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @message = args[:message] if args.key?(:message) @severity = args[:severity] if args.key?(:severity) end |