Class: Google::Apis::AndroidmanagementV1::KioskCustomization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Settings controlling the behavior of a device in kiosk mode. To enable kiosk mode, set kioskCustomLauncherEnabled to true or specify an app in the policy with installType KIOSK.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KioskCustomization

Returns a new instance of KioskCustomization.



3919
3920
3921
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_settingsString

Specifies whether the Settings app is allowed in kiosk mode. Corresponds to the JSON property deviceSettings

Returns:

  • (String)


3893
3894
3895
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3893

def device_settings
  @device_settings
end

#power_button_actionsString

Sets the behavior of a device in kiosk mode when a user presses and holds ( long-presses) the Power button. Corresponds to the JSON property powerButtonActions

Returns:

  • (String)


3899
3900
3901
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3899

def power_button_actions
  @power_button_actions
end

#status_barString

Specifies whether system info and notifications are disabled in kiosk mode. Corresponds to the JSON property statusBar

Returns:

  • (String)


3904
3905
3906
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3904

def status_bar
  @status_bar
end

#system_error_warningsString

Specifies whether system error dialogs for crashed or unresponsive apps are blocked in kiosk mode. When blocked, the system will force-stop the app as if the user chooses the "close app" option on the UI. Corresponds to the JSON property systemErrorWarnings

Returns:

  • (String)


3911
3912
3913
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3911

def system_error_warnings
  @system_error_warnings
end

#system_navigationString

Specifies which navigation features are enabled (e.g. Home, Overview buttons) in kiosk mode. Corresponds to the JSON property systemNavigation

Returns:

  • (String)


3917
3918
3919
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3917

def system_navigation
  @system_navigation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3924
3925
3926
3927
3928
3929
3930
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 3924

def update!(**args)
  @device_settings = args[:device_settings] if args.key?(:device_settings)
  @power_button_actions = args[:power_button_actions] if args.key?(:power_button_actions)
  @status_bar = args[:status_bar] if args.key?(:status_bar)
  @system_error_warnings = args[:system_error_warnings] if args.key?(:system_error_warnings)
  @system_navigation = args[:system_navigation] if args.key?(:system_navigation)
end