Class: Google::Apis::AndroidmanagementV1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

The device location containing the latitude and longitude.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



4144
4145
4146
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude position of the location Corresponds to the JSON property latitude

Returns:

  • (Float)


4137
4138
4139
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4137

def latitude
  @latitude
end

#longitudeFloat

The longitude position of the location Corresponds to the JSON property longitude

Returns:

  • (Float)


4142
4143
4144
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4142

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4149
4150
4151
4152
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4149

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end