Class: Google::Apis::AndroidmanagementV1::ManagedProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Managed property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedProperty

Returns a new instance of ManagedProperty.



4311
4312
4313
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4311

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueObject

The default value of the property. BUNDLE_ARRAY properties don't have a default value. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


4276
4277
4278
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4276

def default_value
  @default_value
end

#descriptionString

A longer description of the property, providing more detail of what it affects. Localized. Corresponds to the JSON property description

Returns:

  • (String)


4282
4283
4284
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4282

def description
  @description
end

#entriesArray<Google::Apis::AndroidmanagementV1::ManagedPropertyEntry>

For CHOICE or MULTISELECT properties, the list of possible entries. Corresponds to the JSON property entries



4287
4288
4289
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4287

def entries
  @entries
end

#keyString

The unique key that the app uses to identify the property, e.g. "com.google. android.gm.fieldname". Corresponds to the JSON property key

Returns:

  • (String)


4293
4294
4295
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4293

def key
  @key
end

#nested_propertiesArray<Google::Apis::AndroidmanagementV1::ManagedProperty>

For BUNDLE_ARRAY properties, the list of nested properties. A BUNDLE_ARRAY property is at most two levels deep. Corresponds to the JSON property nestedProperties



4299
4300
4301
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4299

def nested_properties
  @nested_properties
end

#titleString

The name of the property. Localized. Corresponds to the JSON property title

Returns:

  • (String)


4304
4305
4306
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4304

def title
  @title
end

#typeString

The type of the property. Corresponds to the JSON property type

Returns:

  • (String)


4309
4310
4311
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4309

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4316
4317
4318
4319
4320
4321
4322
4323
4324
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4316

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @entries = args[:entries] if args.key?(:entries)
  @key = args[:key] if args.key?(:key)
  @nested_properties = args[:nested_properties] if args.key?(:nested_properties)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end