Class: Google::Apis::AndroidmanagementV1::MemoryEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

An event related to memory and storage measurements.To distinguish between new and old events, we recommend using the createTime field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemoryEvent

Returns a new instance of MemoryEvent.



4487
4488
4489
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_countFixnum

The number of free bytes in the medium, or for EXTERNAL_STORAGE_DETECTED, the total capacity in bytes of the storage medium. Corresponds to the JSON property byteCount

Returns:

  • (Fixnum)


4475
4476
4477
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4475

def byte_count
  @byte_count
end

#create_timeString

The creation time of the event. Corresponds to the JSON property createTime

Returns:

  • (String)


4480
4481
4482
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4480

def create_time
  @create_time
end

#event_typeString

Event type. Corresponds to the JSON property eventType

Returns:

  • (String)


4485
4486
4487
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4485

def event_type
  @event_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4492
4493
4494
4495
4496
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4492

def update!(**args)
  @byte_count = args[:byte_count] if args.key?(:byte_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @event_type = args[:event_type] if args.key?(:event_type)
end