Class: Google::Apis::AndroidmanagementV1::MemoryEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

An event related to memory and storage measurements.To distinguish between new and old events, we recommend using the createTime field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemoryEvent

Returns a new instance of MemoryEvent.



4432
4433
4434
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_countFixnum

The number of free bytes in the medium, or for EXTERNAL_STORAGE_DETECTED, the total capacity in bytes of the storage medium. Corresponds to the JSON property byteCount

Returns:

  • (Fixnum)


4420
4421
4422
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4420

def byte_count
  @byte_count
end

#create_timeString

The creation time of the event. Corresponds to the JSON property createTime

Returns:

  • (String)


4425
4426
4427
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4425

def create_time
  @create_time
end

#event_typeString

Event type. Corresponds to the JSON property eventType

Returns:

  • (String)


4430
4431
4432
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4430

def event_type
  @event_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4437
4438
4439
4440
4441
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4437

def update!(**args)
  @byte_count = args[:byte_count] if args.key?(:byte_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @event_type = args[:event_type] if args.key?(:event_type)
end