Class: Google::Apis::AndroidmanagementV1::MemoryEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::MemoryEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An event related to memory and storage measurements.To distinguish between new and old events, we recommend using the createTime field.
Instance Attribute Summary collapse
-
#byte_count ⇒ Fixnum
The number of free bytes in the medium, or for EXTERNAL_STORAGE_DETECTED, the total capacity in bytes of the storage medium.
-
#create_time ⇒ String
The creation time of the event.
-
#event_type ⇒ String
Event type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemoryEvent
constructor
A new instance of MemoryEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemoryEvent
Returns a new instance of MemoryEvent.
4420 4421 4422 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#byte_count ⇒ Fixnum
The number of free bytes in the medium, or for EXTERNAL_STORAGE_DETECTED, the
total capacity in bytes of the storage medium.
Corresponds to the JSON property byteCount
4408 4409 4410 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4408 def byte_count @byte_count end |
#create_time ⇒ String
The creation time of the event.
Corresponds to the JSON property createTime
4413 4414 4415 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4413 def create_time @create_time end |
#event_type ⇒ String
Event type.
Corresponds to the JSON property eventType
4418 4419 4420 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4418 def event_type @event_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4425 4426 4427 4428 4429 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4425 def update!(**args) @byte_count = args[:byte_count] if args.key?(:byte_count) @create_time = args[:create_time] if args.key?(:create_time) @event_type = args[:event_type] if args.key?(:event_type) end |