Class: Google::Apis::AndroidmanagementV1::MigrationToken
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::MigrationToken
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A token to initiate the migration of a device from being managed by a third- party DPC to being managed by Android Management API. A migration token is valid only for a single device. See the guide (https://developers.google.com/ android/management/dpc-migration) for more details.
Instance Attribute Summary collapse
-
#additional_data ⇒ String
Immutable.
-
#create_time ⇒ String
Output only.
-
#device ⇒ String
Output only.
-
#device_id ⇒ String
Required.
-
#expire_time ⇒ String
Immutable.
-
#management_mode ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#policy ⇒ String
Required.
-
#ttl ⇒ String
Input only.
-
#user_id ⇒ String
Required.
-
#value ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationToken
constructor
A new instance of MigrationToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationToken
Returns a new instance of MigrationToken.
4604 4605 4606 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_data ⇒ String
Immutable. Optional EMM-specified additional data. Once the device is migrated
this will be populated in the migrationAdditionalData field of the Device
resource. This must be at most 1024 characters.
Corresponds to the JSON property additionalData
4536 4537 4538 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4536 def additional_data @additional_data end |
#create_time ⇒ String
Output only. Time when this migration token was created.
Corresponds to the JSON property createTime
4541 4542 4543 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4541 def create_time @create_time end |
#device ⇒ String
Output only. Once this migration token is used to migrate a device, the name
of the resulting Device resource will be populated here, in the form
enterprises/enterprise/devices/device.
Corresponds to the JSON property device
4548 4549 4550 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4548 def device @device end |
#device_id ⇒ String
Required. Immutable. The id of the device, as in the Play EMM API. This
corresponds to the deviceId parameter in Play EMM API's Devices.get (https://
developers.google.com/android/work/play/emm-api/v1/devices/get#parameters)
call.
Corresponds to the JSON property deviceId
4556 4557 4558 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4556 def device_id @device_id end |
#expire_time ⇒ String
Immutable. The time when this migration token expires. This can be at most
seven days from the time of creation. The migration token is deleted seven
days after it expires.
Corresponds to the JSON property expireTime
4563 4564 4565 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4563 def expire_time @expire_time end |
#management_mode ⇒ String
Required. Immutable. The management mode of the device or profile being
migrated.
Corresponds to the JSON property managementMode
4569 4570 4571 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4569 def management_mode @management_mode end |
#name ⇒ String
Output only. The name of the migration token, which is generated by the server
during creation, in the form enterprises/enterprise/migrationTokens/
migration_token.
Corresponds to the JSON property name
4576 4577 4578 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4576 def name @name end |
#policy ⇒ String
Required. Immutable. The name of the policy initially applied to the enrolled
device, in the form enterprises/enterprise/policies/policy.
Corresponds to the JSON property policy
4582 4583 4584 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4582 def policy @policy end |
#ttl ⇒ String
Input only. The time that this migration token is valid for. This is input-
only, and for returning a migration token the server will populate the
expireTime field. This can be at most seven days. The default is seven days.
Corresponds to the JSON property ttl
4589 4590 4591 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4589 def ttl @ttl end |
#user_id ⇒ String
Required. Immutable. The user id of the Managed Google Play account on the
device, as in the Play EMM API. This corresponds to the userId parameter in
Play EMM API's Devices.get (https://developers.google.com/android/work/play/
emm-api/v1/devices/get#parameters) call.
Corresponds to the JSON property userId
4597 4598 4599 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4597 def user_id @user_id end |
#value ⇒ String
Output only. The value of the migration token.
Corresponds to the JSON property value
4602 4603 4604 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4602 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4609 def update!(**args) @additional_data = args[:additional_data] if args.key?(:additional_data) @create_time = args[:create_time] if args.key?(:create_time) @device = args[:device] if args.key?(:device) @device_id = args[:device_id] if args.key?(:device_id) @expire_time = args[:expire_time] if args.key?(:expire_time) @management_mode = args[:management_mode] if args.key?(:management_mode) @name = args[:name] if args.key?(:name) @policy = args[:policy] if args.key?(:policy) @ttl = args[:ttl] if args.key?(:ttl) @user_id = args[:user_id] if args.key?(:user_id) @value = args[:value] if args.key?(:value) end |