Class: Google::Apis::AndroidmanagementV1::NonComplianceDetail
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::NonComplianceDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Provides detail about non-compliance with a policy setting.
Instance Attribute Summary collapse
-
#current_value ⇒ Object
If the policy setting could not be applied, the current value of the setting on the device.
-
#field_path ⇒ String
For settings with nested fields, if a particular nested field is out of compliance, this specifies the full path to the offending field.
-
#installation_failure_reason ⇒ String
If package_name is set and the non-compliance reason is APP_NOT_INSTALLED or APP_NOT_UPDATED, the detailed reason the app can't be installed or updated.
-
#non_compliance_reason ⇒ String
The reason the device is not in compliance with the setting.
-
#package_name ⇒ String
The package name indicating which app is out of compliance, if applicable.
-
#setting_name ⇒ String
The name of the policy setting.
-
#specific_non_compliance_context ⇒ Google::Apis::AndroidmanagementV1::SpecificNonComplianceContext
Additional context for SpecificNonComplianceReason.
-
#specific_non_compliance_reason ⇒ String
The policy-specific reason the device is not in compliance with the setting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NonComplianceDetail
constructor
A new instance of NonComplianceDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NonComplianceDetail
Returns a new instance of NonComplianceDetail.
4763 4764 4765 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_value ⇒ Object
If the policy setting could not be applied, the current value of the setting
on the device.
Corresponds to the JSON property currentValue
4717 4718 4719 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4717 def current_value @current_value end |
#field_path ⇒ String
For settings with nested fields, if a particular nested field is out of
compliance, this specifies the full path to the offending field. The path is
formatted in the same way the policy JSON field would be referenced in
JavaScript, that is: 1) For object-typed fields, the field name is followed by
a dot then by a subfield name. 2) For array-typed fields, the field name is
followed by the array index enclosed in brackets. For example, to indicate a
problem with the url field in the externalData field in the 3rd application,
the path would be applications[2].externalData.url
Corresponds to the JSON property fieldPath
4729 4730 4731 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4729 def field_path @field_path end |
#installation_failure_reason ⇒ String
If package_name is set and the non-compliance reason is APP_NOT_INSTALLED or
APP_NOT_UPDATED, the detailed reason the app can't be installed or updated.
Corresponds to the JSON property installationFailureReason
4735 4736 4737 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4735 def installation_failure_reason @installation_failure_reason end |
#non_compliance_reason ⇒ String
The reason the device is not in compliance with the setting.
Corresponds to the JSON property nonComplianceReason
4740 4741 4742 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4740 def non_compliance_reason @non_compliance_reason end |
#package_name ⇒ String
The package name indicating which app is out of compliance, if applicable.
Corresponds to the JSON property packageName
4745 4746 4747 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4745 def package_name @package_name end |
#setting_name ⇒ String
The name of the policy setting. This is the JSON field name of a top-level
Policy field.
Corresponds to the JSON property settingName
4751 4752 4753 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4751 def setting_name @setting_name end |
#specific_non_compliance_context ⇒ Google::Apis::AndroidmanagementV1::SpecificNonComplianceContext
Additional context for SpecificNonComplianceReason.
Corresponds to the JSON property specificNonComplianceContext
4756 4757 4758 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4756 def specific_non_compliance_context @specific_non_compliance_context end |
#specific_non_compliance_reason ⇒ String
The policy-specific reason the device is not in compliance with the setting.
Corresponds to the JSON property specificNonComplianceReason
4761 4762 4763 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4761 def specific_non_compliance_reason @specific_non_compliance_reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 4768 def update!(**args) @current_value = args[:current_value] if args.key?(:current_value) @field_path = args[:field_path] if args.key?(:field_path) @installation_failure_reason = args[:installation_failure_reason] if args.key?(:installation_failure_reason) @non_compliance_reason = args[:non_compliance_reason] if args.key?(:non_compliance_reason) @package_name = args[:package_name] if args.key?(:package_name) @setting_name = args[:setting_name] if args.key?(:setting_name) @specific_non_compliance_context = args[:specific_non_compliance_context] if args.key?(:specific_non_compliance_context) @specific_non_compliance_reason = args[:specific_non_compliance_reason] if args.key?(:specific_non_compliance_reason) end |