Class: Google::Apis::AndroidmanagementV1::PasswordRequirements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Requirements for the password used to unlock a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PasswordRequirements

Returns a new instance of PasswordRequirements.



5094
5095
5096
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maximum_failed_passwords_for_wipeFixnum

Number of incorrect device-unlock passwords that can be entered before a device is wiped. A value of 0 means there is no restriction. Corresponds to the JSON property maximumFailedPasswordsForWipe

Returns:

  • (Fixnum)


5008
5009
5010
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5008

def maximum_failed_passwords_for_wipe
  @maximum_failed_passwords_for_wipe
end

#password_expiration_timeoutString

Password expiration timeout. Corresponds to the JSON property passwordExpirationTimeout

Returns:

  • (String)


5013
5014
5015
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5013

def password_expiration_timeout
  @password_expiration_timeout
end

#password_history_lengthFixnum

The length of the password history. After setting this field, the user won't be able to enter a new password that is the same as any password in the history. A value of 0 means there is no restriction. Corresponds to the JSON property passwordHistoryLength

Returns:

  • (Fixnum)


5020
5021
5022
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5020

def password_history_length
  @password_history_length
end

#password_minimum_lengthFixnum

The minimum allowed password length. A value of 0 means there is no restriction. Only enforced when password_quality is NUMERIC, NUMERIC_COMPLEX, ALPHABETIC, ALPHANUMERIC, or COMPLEX. Corresponds to the JSON property passwordMinimumLength

Returns:

  • (Fixnum)


5027
5028
5029
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5027

def password_minimum_length
  @password_minimum_length
end

#password_minimum_lettersFixnum

Minimum number of letters required in the password. Only enforced when password_quality is COMPLEX. Corresponds to the JSON property passwordMinimumLetters

Returns:

  • (Fixnum)


5033
5034
5035
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5033

def password_minimum_letters
  @password_minimum_letters
end

#password_minimum_lower_caseFixnum

Minimum number of lower case letters required in the password. Only enforced when password_quality is COMPLEX. Corresponds to the JSON property passwordMinimumLowerCase

Returns:

  • (Fixnum)


5039
5040
5041
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5039

def password_minimum_lower_case
  @password_minimum_lower_case
end

#password_minimum_non_letterFixnum

Minimum number of non-letter characters (numerical digits or symbols) required in the password. Only enforced when password_quality is COMPLEX. Corresponds to the JSON property passwordMinimumNonLetter

Returns:

  • (Fixnum)


5045
5046
5047
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5045

def password_minimum_non_letter
  @password_minimum_non_letter
end

#password_minimum_numericFixnum

Minimum number of numerical digits required in the password. Only enforced when password_quality is COMPLEX. Corresponds to the JSON property passwordMinimumNumeric

Returns:

  • (Fixnum)


5051
5052
5053
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5051

def password_minimum_numeric
  @password_minimum_numeric
end

#password_minimum_symbolsFixnum

Minimum number of symbols required in the password. Only enforced when password_quality is COMPLEX. Corresponds to the JSON property passwordMinimumSymbols

Returns:

  • (Fixnum)


5057
5058
5059
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5057

def password_minimum_symbols
  @password_minimum_symbols
end

#password_minimum_upper_caseFixnum

Minimum number of upper case letters required in the password. Only enforced when password_quality is COMPLEX. Corresponds to the JSON property passwordMinimumUpperCase

Returns:

  • (Fixnum)


5063
5064
5065
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5063

def password_minimum_upper_case
  @password_minimum_upper_case
end

#password_qualityString

The required password quality. Corresponds to the JSON property passwordQuality

Returns:

  • (String)


5068
5069
5070
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5068

def password_quality
  @password_quality
end

#password_scopeString

The scope that the password requirement applies to. Corresponds to the JSON property passwordScope

Returns:

  • (String)


5073
5074
5075
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5073

def password_scope
  @password_scope
end

#require_password_unlockString

The length of time after a device or work profile is unlocked using a strong form of authentication (password, PIN, pattern) that it can be unlocked using any other authentication method (e.g. fingerprint, trust agents, face). After the specified time period elapses, only strong forms of authentication can be used to unlock the device or work profile. Corresponds to the JSON property requirePasswordUnlock

Returns:

  • (String)


5082
5083
5084
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5082

def require_password_unlock
  @require_password_unlock
end

#unified_lock_settingsString

Controls whether a unified lock is allowed for the device and the work profile, on devices running Android 9 and above with a work profile. This can be set only if password_scope is set to SCOPE_PROFILE, the policy will be rejected otherwise. If user has not set a separate work lock and this field is set to REQUIRE_SEPARATE_WORK_LOCK, a NonComplianceDetail is reported with nonComplianceReason set to USER_ACTION. Corresponds to the JSON property unifiedLockSettings

Returns:

  • (String)


5092
5093
5094
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5092

def unified_lock_settings
  @unified_lock_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5099
5100
5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5099

def update!(**args)
  @maximum_failed_passwords_for_wipe = args[:maximum_failed_passwords_for_wipe] if args.key?(:maximum_failed_passwords_for_wipe)
  @password_expiration_timeout = args[:password_expiration_timeout] if args.key?(:password_expiration_timeout)
  @password_history_length = args[:password_history_length] if args.key?(:password_history_length)
  @password_minimum_length = args[:password_minimum_length] if args.key?(:password_minimum_length)
  @password_minimum_letters = args[:password_minimum_letters] if args.key?(:password_minimum_letters)
  @password_minimum_lower_case = args[:password_minimum_lower_case] if args.key?(:password_minimum_lower_case)
  @password_minimum_non_letter = args[:password_minimum_non_letter] if args.key?(:password_minimum_non_letter)
  @password_minimum_numeric = args[:password_minimum_numeric] if args.key?(:password_minimum_numeric)
  @password_minimum_symbols = args[:password_minimum_symbols] if args.key?(:password_minimum_symbols)
  @password_minimum_upper_case = args[:password_minimum_upper_case] if args.key?(:password_minimum_upper_case)
  @password_quality = args[:password_quality] if args.key?(:password_quality)
  @password_scope = args[:password_scope] if args.key?(:password_scope)
  @require_password_unlock = args[:require_password_unlock] if args.key?(:require_password_unlock)
  @unified_lock_settings = args[:unified_lock_settings] if args.key?(:unified_lock_settings)
end