Class: Google::Apis::AndroidmanagementV1::PasswordRequirements
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::PasswordRequirements
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Requirements for the password used to unlock a device.
Instance Attribute Summary collapse
-
#maximum_failed_passwords_for_wipe ⇒ Fixnum
Number of incorrect device-unlock passwords that can be entered before a device is wiped.
-
#password_expiration_timeout ⇒ String
Password expiration timeout.
-
#password_history_length ⇒ Fixnum
The length of the password history.
-
#password_minimum_length ⇒ Fixnum
The minimum allowed password length.
-
#password_minimum_letters ⇒ Fixnum
Minimum number of letters required in the password.
-
#password_minimum_lower_case ⇒ Fixnum
Minimum number of lower case letters required in the password.
-
#password_minimum_non_letter ⇒ Fixnum
Minimum number of non-letter characters (numerical digits or symbols) required in the password.
-
#password_minimum_numeric ⇒ Fixnum
Minimum number of numerical digits required in the password.
-
#password_minimum_symbols ⇒ Fixnum
Minimum number of symbols required in the password.
-
#password_minimum_upper_case ⇒ Fixnum
Minimum number of upper case letters required in the password.
-
#password_quality ⇒ String
The required password quality.
-
#password_scope ⇒ String
The scope that the password requirement applies to.
-
#require_password_unlock ⇒ String
The length of time after a device or work profile is unlocked using a strong form of authentication (password, PIN, pattern) that it can be unlocked using any other authentication method (e.g. fingerprint, trust agents, face).
-
#unified_lock_settings ⇒ String
Controls whether a unified lock is allowed for the device and the work profile, on devices running Android 9 and above with a work profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PasswordRequirements
constructor
A new instance of PasswordRequirements.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PasswordRequirements
Returns a new instance of PasswordRequirements.
5093 5094 5095 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maximum_failed_passwords_for_wipe ⇒ Fixnum
Number of incorrect device-unlock passwords that can be entered before a
device is wiped. A value of 0 means there is no restriction.
Corresponds to the JSON property maximumFailedPasswordsForWipe
5007 5008 5009 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5007 def maximum_failed_passwords_for_wipe @maximum_failed_passwords_for_wipe end |
#password_expiration_timeout ⇒ String
Password expiration timeout.
Corresponds to the JSON property passwordExpirationTimeout
5012 5013 5014 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5012 def password_expiration_timeout @password_expiration_timeout end |
#password_history_length ⇒ Fixnum
The length of the password history. After setting this field, the user won't
be able to enter a new password that is the same as any password in the
history. A value of 0 means there is no restriction.
Corresponds to the JSON property passwordHistoryLength
5019 5020 5021 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5019 def password_history_length @password_history_length end |
#password_minimum_length ⇒ Fixnum
The minimum allowed password length. A value of 0 means there is no
restriction. Only enforced when password_quality is NUMERIC, NUMERIC_COMPLEX,
ALPHABETIC, ALPHANUMERIC, or COMPLEX.
Corresponds to the JSON property passwordMinimumLength
5026 5027 5028 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5026 def password_minimum_length @password_minimum_length end |
#password_minimum_letters ⇒ Fixnum
Minimum number of letters required in the password. Only enforced when
password_quality is COMPLEX.
Corresponds to the JSON property passwordMinimumLetters
5032 5033 5034 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5032 def password_minimum_letters @password_minimum_letters end |
#password_minimum_lower_case ⇒ Fixnum
Minimum number of lower case letters required in the password. Only enforced
when password_quality is COMPLEX.
Corresponds to the JSON property passwordMinimumLowerCase
5038 5039 5040 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5038 def password_minimum_lower_case @password_minimum_lower_case end |
#password_minimum_non_letter ⇒ Fixnum
Minimum number of non-letter characters (numerical digits or symbols) required
in the password. Only enforced when password_quality is COMPLEX.
Corresponds to the JSON property passwordMinimumNonLetter
5044 5045 5046 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5044 def password_minimum_non_letter @password_minimum_non_letter end |
#password_minimum_numeric ⇒ Fixnum
Minimum number of numerical digits required in the password. Only enforced
when password_quality is COMPLEX.
Corresponds to the JSON property passwordMinimumNumeric
5050 5051 5052 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5050 def password_minimum_numeric @password_minimum_numeric end |
#password_minimum_symbols ⇒ Fixnum
Minimum number of symbols required in the password. Only enforced when
password_quality is COMPLEX.
Corresponds to the JSON property passwordMinimumSymbols
5056 5057 5058 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5056 def password_minimum_symbols @password_minimum_symbols end |
#password_minimum_upper_case ⇒ Fixnum
Minimum number of upper case letters required in the password. Only enforced
when password_quality is COMPLEX.
Corresponds to the JSON property passwordMinimumUpperCase
5062 5063 5064 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5062 def password_minimum_upper_case @password_minimum_upper_case end |
#password_quality ⇒ String
The required password quality.
Corresponds to the JSON property passwordQuality
5067 5068 5069 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5067 def password_quality @password_quality end |
#password_scope ⇒ String
The scope that the password requirement applies to.
Corresponds to the JSON property passwordScope
5072 5073 5074 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5072 def password_scope @password_scope end |
#require_password_unlock ⇒ String
The length of time after a device or work profile is unlocked using a strong
form of authentication (password, PIN, pattern) that it can be unlocked using
any other authentication method (e.g. fingerprint, trust agents, face). After
the specified time period elapses, only strong forms of authentication can be
used to unlock the device or work profile.
Corresponds to the JSON property requirePasswordUnlock
5081 5082 5083 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5081 def require_password_unlock @require_password_unlock end |
#unified_lock_settings ⇒ String
Controls whether a unified lock is allowed for the device and the work profile,
on devices running Android 9 and above with a work profile. This can be set
only if password_scope is set to SCOPE_PROFILE, the policy will be rejected
otherwise. If user has not set a separate work lock and this field is set to
REQUIRE_SEPARATE_WORK_LOCK, a NonComplianceDetail is reported with
nonComplianceReason set to USER_ACTION.
Corresponds to the JSON property unifiedLockSettings
5091 5092 5093 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5091 def unified_lock_settings @unified_lock_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5098 5099 5100 5101 5102 5103 5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5098 def update!(**args) @maximum_failed_passwords_for_wipe = args[:maximum_failed_passwords_for_wipe] if args.key?(:maximum_failed_passwords_for_wipe) @password_expiration_timeout = args[:password_expiration_timeout] if args.key?(:password_expiration_timeout) @password_history_length = args[:password_history_length] if args.key?(:password_history_length) @password_minimum_length = args[:password_minimum_length] if args.key?(:password_minimum_length) @password_minimum_letters = args[:password_minimum_letters] if args.key?(:password_minimum_letters) @password_minimum_lower_case = args[:password_minimum_lower_case] if args.key?(:password_minimum_lower_case) @password_minimum_non_letter = args[:password_minimum_non_letter] if args.key?(:password_minimum_non_letter) @password_minimum_numeric = args[:password_minimum_numeric] if args.key?(:password_minimum_numeric) @password_minimum_symbols = args[:password_minimum_symbols] if args.key?(:password_minimum_symbols) @password_minimum_upper_case = args[:password_minimum_upper_case] if args.key?(:password_minimum_upper_case) @password_quality = args[:password_quality] if args.key?(:password_quality) @password_scope = args[:password_scope] if args.key?(:password_scope) @require_password_unlock = args[:require_password_unlock] if args.key?(:require_password_unlock) @unified_lock_settings = args[:unified_lock_settings] if args.key?(:unified_lock_settings) end |