Class: Google::Apis::AndroidmanagementV1::PersistentPreferredActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A default activity for handling intents that match a particular intent filter. Note: To set up a kiosk, use InstallType to KIOSK rather than use persistent preferred activities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PersistentPreferredActivity

Returns a new instance of PersistentPreferredActivity.



5191
5192
5193
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<String>

The intent actions to match in the filter. If any actions are included in the filter, then an intent's action must be one of those values for it to match. If no actions are included, the intent action is ignored. Corresponds to the JSON property actions

Returns:

  • (Array<String>)


5172
5173
5174
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5172

def actions
  @actions
end

#categoriesArray<String>

The intent categories to match in the filter. An intent includes the categories that it requires, all of which must be included in the filter in order to match. In other words, adding a category to the filter has no impact on matching unless that category is specified in the intent. Corresponds to the JSON property categories

Returns:

  • (Array<String>)


5180
5181
5182
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5180

def categories
  @categories
end

#receiver_activityString

The activity that should be the default intent handler. This should be an Android component name, e.g. com.android.enterprise.app/.MainActivity. Alternatively, the value may be the package name of an app, which causes Android Device Policy to choose an appropriate activity from the app to handle the intent. Corresponds to the JSON property receiverActivity

Returns:

  • (String)


5189
5190
5191
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5189

def receiver_activity
  @receiver_activity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5196
5197
5198
5199
5200
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5196

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @categories = args[:categories] if args.key?(:categories)
  @receiver_activity = args[:receiver_activity] if args.key?(:receiver_activity)
end