Class: Google::Apis::AndroidmanagementV1::PersistentPreferredActivity
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::PersistentPreferredActivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A default activity for handling intents that match a particular intent filter. Note: To set up a kiosk, use InstallType to KIOSK rather than use persistent preferred activities.
Instance Attribute Summary collapse
-
#actions ⇒ Array<String>
The intent actions to match in the filter.
-
#categories ⇒ Array<String>
The intent categories to match in the filter.
-
#receiver_activity ⇒ String
The activity that should be the default intent handler.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PersistentPreferredActivity
constructor
A new instance of PersistentPreferredActivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PersistentPreferredActivity
Returns a new instance of PersistentPreferredActivity.
5137 5138 5139 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<String>
The intent actions to match in the filter. If any actions are included in the
filter, then an intent's action must be one of those values for it to match.
If no actions are included, the intent action is ignored.
Corresponds to the JSON property actions
5118 5119 5120 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5118 def actions @actions end |
#categories ⇒ Array<String>
The intent categories to match in the filter. An intent includes the
categories that it requires, all of which must be included in the filter in
order to match. In other words, adding a category to the filter has no impact
on matching unless that category is specified in the intent.
Corresponds to the JSON property categories
5126 5127 5128 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5126 def categories @categories end |
#receiver_activity ⇒ String
The activity that should be the default intent handler. This should be an
Android component name, e.g. com.android.enterprise.app/.MainActivity.
Alternatively, the value may be the package name of an app, which causes
Android Device Policy to choose an appropriate activity from the app to handle
the intent.
Corresponds to the JSON property receiverActivity
5135 5136 5137 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5135 def receiver_activity @receiver_activity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5142 5143 5144 5145 5146 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5142 def update!(**args) @actions = args[:actions] if args.key?(:actions) @categories = args[:categories] if args.key?(:categories) @receiver_activity = args[:receiver_activity] if args.key?(:receiver_activity) end |