Class: Google::Apis::AndroidmanagementV1::Policy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A policy resource represents a group of settings that govern the behavior of a managed device and the apps installed on it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Policy

Returns a new instance of Policy.



5976
5977
5978
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_types_with_management_disabledArray<String>

Account types that can't be managed by the user. Corresponds to the JSON property accountTypesWithManagementDisabled

Returns:

  • (Array<String>)


5308
5309
5310
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5308

def 
  @account_types_with_management_disabled
end

#add_user_disabledBoolean Also known as: add_user_disabled?

Whether adding new users and profiles is disabled. For devices where managementMode is DEVICE_OWNER this field is ignored and the user is never allowed to add or remove users. Corresponds to the JSON property addUserDisabled

Returns:

  • (Boolean)


5315
5316
5317
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5315

def add_user_disabled
  @add_user_disabled
end

#adjust_volume_disabledBoolean Also known as: adjust_volume_disabled?

Whether adjusting the master volume is disabled. Also mutes the device. The setting has effect only on fully managed devices. Corresponds to the JSON property adjustVolumeDisabled

Returns:

  • (Boolean)


5322
5323
5324
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5322

def adjust_volume_disabled
  @adjust_volume_disabled
end

#advanced_security_overridesGoogle::Apis::AndroidmanagementV1::AdvancedSecurityOverrides

Advanced security settings. In most cases, setting these is not needed. Corresponds to the JSON property advancedSecurityOverrides



5328
5329
5330
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5328

def advanced_security_overrides
  @advanced_security_overrides
end

#always_on_vpn_packageGoogle::Apis::AndroidmanagementV1::AlwaysOnVpnPackage

Configuration for an always-on VPN connection. Corresponds to the JSON property alwaysOnVpnPackage



5333
5334
5335
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5333

def always_on_vpn_package
  @always_on_vpn_package
end

#android_device_policy_tracksArray<String>

This setting is not supported. Any value is ignored. Corresponds to the JSON property androidDevicePolicyTracks

Returns:

  • (Array<String>)


5338
5339
5340
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5338

def android_device_policy_tracks
  @android_device_policy_tracks
end

#app_auto_update_policyString

Recommended alternative: autoUpdateMode which is set per app, provides greater flexibility around update frequency.When autoUpdateMode is set to AUTO_UPDATE_POSTPONED or AUTO_UPDATE_HIGH_PRIORITY, this field has no effect. The app auto update policy, which controls when automatic app updates can be applied. Corresponds to the JSON property appAutoUpdatePolicy

Returns:

  • (String)


5347
5348
5349
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5347

def app_auto_update_policy
  @app_auto_update_policy
end

#app_functionsString

Optional. Controls whether apps on the device for fully managed devices or in the work profile for devices with work profiles are allowed to expose app functions. Corresponds to the JSON property appFunctions

Returns:

  • (String)


5354
5355
5356
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5354

def app_functions
  @app_functions
end

#applicationsArray<Google::Apis::AndroidmanagementV1::ApplicationPolicy>

Policy applied to apps. This can have at most 3,000 elements. Corresponds to the JSON property applications



5359
5360
5361
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5359

def applications
  @applications
end

#assist_content_policyString

Optional. Controls whether AssistContent (https://developer.android.com/ reference/android/app/assist/AssistContent) is allowed to be sent to a privileged app such as an assistant app. AssistContent includes screenshots and information about an app, such as package name. This is supported on Android 15 and above. Corresponds to the JSON property assistContentPolicy

Returns:

  • (String)


5368
5369
5370
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5368

def assist_content_policy
  @assist_content_policy
end

#auto_date_and_time_zoneString

Whether auto date, time, and time zone are enabled on a company-owned device. If this is set, then autoTimeRequired is ignored. Corresponds to the JSON property autoDateAndTimeZone

Returns:

  • (String)


5374
5375
5376
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5374

def auto_date_and_time_zone
  @auto_date_and_time_zone
end

#auto_time_requiredBoolean Also known as: auto_time_required?

Whether auto time is required, which prevents the user from manually setting the date and time. If autoDateAndTimeZone is set, this field is ignored. Corresponds to the JSON property autoTimeRequired

Returns:

  • (Boolean)


5380
5381
5382
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5380

def auto_time_required
  @auto_time_required
end

#autofill_policyString

Optional. The policy for the autofill service. Corresponds to the JSON property autofillPolicy

Returns:

  • (String)


5386
5387
5388
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5386

def autofill_policy
  @autofill_policy
end

#block_applications_enabledBoolean Also known as: block_applications_enabled?

This field has no effect. Corresponds to the JSON property blockApplicationsEnabled

Returns:

  • (Boolean)


5391
5392
5393
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5391

def block_applications_enabled
  @block_applications_enabled
end

#bluetooth_config_disabledBoolean Also known as: bluetooth_config_disabled?

Whether configuring bluetooth is disabled. Corresponds to the JSON property bluetoothConfigDisabled

Returns:

  • (Boolean)


5397
5398
5399
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5397

def bluetooth_config_disabled
  @bluetooth_config_disabled
end

#bluetooth_contact_sharing_disabledBoolean Also known as: bluetooth_contact_sharing_disabled?

Whether bluetooth contact sharing is disabled. Corresponds to the JSON property bluetoothContactSharingDisabled

Returns:

  • (Boolean)


5403
5404
5405
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5403

def bluetooth_contact_sharing_disabled
  @bluetooth_contact_sharing_disabled
end

#bluetooth_disabledBoolean Also known as: bluetooth_disabled?

Whether bluetooth is disabled. Prefer this setting over bluetooth_config_disabled because bluetooth_config_disabled can be bypassed by the user. Corresponds to the JSON property bluetoothDisabled

Returns:

  • (Boolean)


5411
5412
5413
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5411

def bluetooth_disabled
  @bluetooth_disabled
end

#camera_accessString

Controls the use of the camera and whether the user has access to the camera access toggle. Corresponds to the JSON property cameraAccess

Returns:

  • (String)


5418
5419
5420
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5418

def camera_access
  @camera_access
end

#camera_disabledBoolean Also known as: camera_disabled?

If camera_access is set to any value other than CAMERA_ACCESS_UNSPECIFIED, this has no effect. Otherwise this field controls whether cameras are disabled: If true, all cameras are disabled, otherwise they are available. For fully managed devices this field applies for all apps on the device. For work profiles, this field applies only to apps in the work profile, and the camera access of apps outside the work profile is unaffected. Corresponds to the JSON property cameraDisabled

Returns:

  • (Boolean)


5428
5429
5430
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5428

def camera_disabled
  @camera_disabled
end

#cell_broadcasts_config_disabledBoolean Also known as: cell_broadcasts_config_disabled?

Whether configuring cell broadcast is disabled. Corresponds to the JSON property cellBroadcastsConfigDisabled

Returns:

  • (Boolean)


5434
5435
5436
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5434

def cell_broadcasts_config_disabled
  @cell_broadcasts_config_disabled
end

#choose_private_key_rulesArray<Google::Apis::AndroidmanagementV1::ChoosePrivateKeyRule>

Rules for determining apps' access to private keys. See ChoosePrivateKeyRule for details. This must be empty if any application has CERT_SELECTION delegation scope. Corresponds to the JSON property choosePrivateKeyRules



5442
5443
5444
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5442

def choose_private_key_rules
  @choose_private_key_rules
end

#compliance_rulesArray<Google::Apis::AndroidmanagementV1::ComplianceRule>

Rules declaring which mitigating actions to take when a device is not compliant with its policy. When the conditions for multiple rules are satisfied, all of the mitigating actions for the rules are taken. There is a maximum limit of 100 rules. Use policy enforcement rules instead. Corresponds to the JSON property complianceRules



5450
5451
5452
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5450

def compliance_rules
  @compliance_rules
end

#create_windows_disabledBoolean Also known as: create_windows_disabled?

Whether creating windows besides app windows is disabled. Corresponds to the JSON property createWindowsDisabled

Returns:

  • (Boolean)


5455
5456
5457
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5455

def create_windows_disabled
  @create_windows_disabled
end

#credential_provider_policy_defaultString

Optional. Controls which apps are allowed to act as credential providers on Android 14 and above. These apps store credentials, see this (https:// developer.android.com/training/sign-in/passkeys) and this (https://developer. android.com/reference/androidx/credentials/CredentialManager) for details. See also credentialProviderPolicy. Corresponds to the JSON property credentialProviderPolicyDefault

Returns:

  • (String)


5465
5466
5467
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5465

def credential_provider_policy_default
  @credential_provider_policy_default
end

#credentials_config_disabledBoolean Also known as: credentials_config_disabled?

Whether configuring user credentials is disabled. Corresponds to the JSON property credentialsConfigDisabled

Returns:

  • (Boolean)


5470
5471
5472
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5470

def credentials_config_disabled
  @credentials_config_disabled
end

#cross_profile_policiesGoogle::Apis::AndroidmanagementV1::CrossProfilePolicies

Controls the data from the work profile that can be accessed from the personal profile and vice versa. A NonComplianceDetail with MANAGEMENT_MODE is reported if the device does not have a work profile. Corresponds to the JSON property crossProfilePolicies



5478
5479
5480
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5478

def cross_profile_policies
  @cross_profile_policies
end

#data_roaming_disabledBoolean Also known as: data_roaming_disabled?

Whether roaming data services are disabled. Corresponds to the JSON property dataRoamingDisabled

Returns:

  • (Boolean)


5483
5484
5485
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5483

def data_roaming_disabled
  @data_roaming_disabled
end

#debugging_features_allowedBoolean Also known as: debugging_features_allowed?

Whether the user is allowed to enable debugging features. Corresponds to the JSON property debuggingFeaturesAllowed

Returns:

  • (Boolean)


5489
5490
5491
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5489

def debugging_features_allowed
  @debugging_features_allowed
end

#default_application_settingsArray<Google::Apis::AndroidmanagementV1::DefaultApplicationSetting>

Optional. The default application setting for supported types. If the default application is successfully set for at least one app type on a profile, users are prevented from changing any default applications on that profile.Only one DefaultApplicationSetting is allowed for each DefaultApplicationType.See Default application settings (https://developers.google.com/android/management/ default-application-settings) guide for more details. Corresponds to the JSON property defaultApplicationSettings



5500
5501
5502
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5500

def default_application_settings
  @default_application_settings
end

#default_permission_policyString

The default permission policy for runtime permission requests. Corresponds to the JSON property defaultPermissionPolicy

Returns:

  • (String)


5505
5506
5507
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5505

def default_permission_policy
  @default_permission_policy
end

#device_connectivity_managementGoogle::Apis::AndroidmanagementV1::DeviceConnectivityManagement

Covers controls for device connectivity such as Wi-Fi, USB data access, keyboard/mouse connections, and more. Corresponds to the JSON property deviceConnectivityManagement



5511
5512
5513
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5511

def device_connectivity_management
  @device_connectivity_management
end

#device_owner_lock_screen_infoGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property deviceOwnerLockScreenInfo



5517
5518
5519
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5517

def device_owner_lock_screen_info
  @device_owner_lock_screen_info
end

#device_radio_stateGoogle::Apis::AndroidmanagementV1::DeviceRadioState

Controls for device radio settings. Corresponds to the JSON property deviceRadioState



5522
5523
5524
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5522

def device_radio_state
  @device_radio_state
end

#display_settingsGoogle::Apis::AndroidmanagementV1::DisplaySettings

Controls for the display settings. Corresponds to the JSON property displaySettings



5527
5528
5529
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5527

def display_settings
  @display_settings
end

#encryption_policyString

Whether encryption is enabled Corresponds to the JSON property encryptionPolicy

Returns:

  • (String)


5532
5533
5534
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5532

def encryption_policy
  @encryption_policy
end

#ensure_verify_apps_enabledBoolean Also known as: ensure_verify_apps_enabled?

Whether app verification is force-enabled. Corresponds to the JSON property ensureVerifyAppsEnabled

Returns:

  • (Boolean)


5537
5538
5539
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5537

def ensure_verify_apps_enabled
  @ensure_verify_apps_enabled
end

#enterprise_display_name_visibilityString

Optional. Controls whether the enterpriseDisplayName is visible on the device ( e.g. lock screen message on company-owned devices). Corresponds to the JSON property enterpriseDisplayNameVisibility

Returns:

  • (String)


5544
5545
5546
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5544

def enterprise_display_name_visibility
  @enterprise_display_name_visibility
end

#factory_reset_disabledBoolean Also known as: factory_reset_disabled?

Whether factory resetting from settings is disabled. Corresponds to the JSON property factoryResetDisabled

Returns:

  • (Boolean)


5549
5550
5551
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5549

def factory_reset_disabled
  @factory_reset_disabled
end

#frp_admin_emailsArray<String>

Email addresses of device administrators for factory reset protection. When the device is factory reset, it will require one of these admins to log in with the Google account email and password to unlock the device. If no admins are specified, the device won't provide factory reset protection. Corresponds to the JSON property frpAdminEmails

Returns:

  • (Array<String>)


5558
5559
5560
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5558

def frp_admin_emails
  @frp_admin_emails
end

#fun_disabledBoolean Also known as: fun_disabled?

Whether the user is allowed to have fun. Controls whether the Easter egg game in Settings is disabled. Corresponds to the JSON property funDisabled

Returns:

  • (Boolean)


5564
5565
5566
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5564

def fun_disabled
  @fun_disabled
end

#install_apps_disabledBoolean Also known as: install_apps_disabled?

Whether user installation of apps is disabled. Corresponds to the JSON property installAppsDisabled

Returns:

  • (Boolean)


5570
5571
5572
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5570

def install_apps_disabled
  @install_apps_disabled
end

#install_unknown_sources_allowedBoolean Also known as: install_unknown_sources_allowed?

This field has no effect. Corresponds to the JSON property installUnknownSourcesAllowed

Returns:

  • (Boolean)


5576
5577
5578
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5576

def install_unknown_sources_allowed
  @install_unknown_sources_allowed
end

#keyguard_disabledBoolean Also known as: keyguard_disabled?

If true, this disables the Lock Screen (https://source.android.com/docs/core/ display/multi_display/lock-screen) for primary and/or secondary displays. This policy is supported only in dedicated device management mode. Corresponds to the JSON property keyguardDisabled

Returns:

  • (Boolean)


5584
5585
5586
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5584

def keyguard_disabled
  @keyguard_disabled
end

#keyguard_disabled_featuresArray<String>

Disabled keyguard customizations, such as widgets. Corresponds to the JSON property keyguardDisabledFeatures

Returns:

  • (Array<String>)


5590
5591
5592
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5590

def keyguard_disabled_features
  @keyguard_disabled_features
end

#kiosk_custom_launcher_enabledBoolean Also known as: kiosk_custom_launcher_enabled?

Whether the kiosk custom launcher is enabled. This replaces the home screen with a launcher that locks down the device to the apps installed via the applications setting. Apps appear on a single page in alphabetical order. Use kioskCustomization to further configure the kiosk device behavior. Corresponds to the JSON property kioskCustomLauncherEnabled

Returns:

  • (Boolean)


5598
5599
5600
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5598

def kiosk_custom_launcher_enabled
  @kiosk_custom_launcher_enabled
end

#kiosk_customizationGoogle::Apis::AndroidmanagementV1::KioskCustomization

Settings controlling the behavior of a device in kiosk mode. To enable kiosk mode, set kioskCustomLauncherEnabled to true or specify an app in the policy with installType KIOSK. Corresponds to the JSON property kioskCustomization



5606
5607
5608
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5606

def kiosk_customization
  @kiosk_customization
end

#location_modeString

The degree of location detection enabled. Corresponds to the JSON property locationMode

Returns:

  • (String)


5611
5612
5613
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5611

def location_mode
  @location_mode
end

#long_support_messageGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property longSupportMessage



5617
5618
5619
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5617

def long_support_message
  @long_support_message
end

#maximum_time_to_lockFixnum

Maximum time in milliseconds for user activity until the device locks. A value of 0 means there is no restriction. Corresponds to the JSON property maximumTimeToLock

Returns:

  • (Fixnum)


5623
5624
5625
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5623

def maximum_time_to_lock
  @maximum_time_to_lock
end

#microphone_accessString

Controls the use of the microphone and whether the user has access to the microphone access toggle. This applies only on fully managed devices. Corresponds to the JSON property microphoneAccess

Returns:

  • (String)


5629
5630
5631
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5629

def microphone_access
  @microphone_access
end

#minimum_api_levelFixnum

The minimum allowed Android API level. Corresponds to the JSON property minimumApiLevel

Returns:

  • (Fixnum)


5634
5635
5636
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5634

def minimum_api_level
  @minimum_api_level
end

#mobile_networks_config_disabledBoolean Also known as: mobile_networks_config_disabled?

Whether configuring mobile networks is disabled. Corresponds to the JSON property mobileNetworksConfigDisabled

Returns:

  • (Boolean)


5639
5640
5641
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5639

def mobile_networks_config_disabled
  @mobile_networks_config_disabled
end

#modify_accounts_disabledBoolean Also known as: modify_accounts_disabled?

Whether adding or removing accounts is disabled. Corresponds to the JSON property modifyAccountsDisabled

Returns:

  • (Boolean)


5645
5646
5647
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5645

def modify_accounts_disabled
  @modify_accounts_disabled
end

#mount_physical_media_disabledBoolean Also known as: mount_physical_media_disabled?

Whether the user mounting physical external media is disabled. Corresponds to the JSON property mountPhysicalMediaDisabled

Returns:

  • (Boolean)


5651
5652
5653
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5651

def mount_physical_media_disabled
  @mount_physical_media_disabled
end

#nameString

The name of the policy in the form enterprises/enterpriseId/policies/ policyId. Corresponds to the JSON property name

Returns:

  • (String)


5658
5659
5660
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5658

def name
  @name
end

#network_escape_hatch_enabledBoolean Also known as: network_escape_hatch_enabled?

Whether the network escape hatch is enabled. If a network connection can't be made at boot time, the escape hatch prompts the user to temporarily connect to a network in order to refresh the device policy. After applying policy, the temporary network will be forgotten and the device will continue booting. This prevents being unable to connect to a network if there is no suitable network in the last policy and the device boots into an app in lock task mode, or the user is otherwise unable to reach device settings.Note: Setting wifiConfigDisabled to true will override this setting under specific circumstances. Please see wifiConfigDisabled for further details. Setting configureWifi to DISALLOW_CONFIGURING_WIFI will override this setting under specific circumstances. Please see DISALLOW_CONFIGURING_WIFI for further details. Corresponds to the JSON property networkEscapeHatchEnabled

Returns:

  • (Boolean)


5674
5675
5676
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5674

def network_escape_hatch_enabled
  @network_escape_hatch_enabled
end

#network_reset_disabledBoolean Also known as: network_reset_disabled?

Whether resetting network settings is disabled. This applies only on fully managed devices. A NonComplianceDetail with MANAGEMENT_MODE is reported for other management modes. Corresponds to the JSON property networkResetDisabled

Returns:

  • (Boolean)


5682
5683
5684
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5682

def network_reset_disabled
  @network_reset_disabled
end

#onc_certificate_providersArray<Google::Apis::AndroidmanagementV1::OncCertificateProvider>

This feature is not generally available. Corresponds to the JSON property oncCertificateProviders



5688
5689
5690
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5688

def onc_certificate_providers
  @onc_certificate_providers
end

#open_network_configurationHash<String,Object>

Network configuration for the device. See configure networks for more information. Corresponds to the JSON property openNetworkConfiguration

Returns:

  • (Hash<String,Object>)


5694
5695
5696
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5694

def open_network_configuration
  @open_network_configuration
end

#outgoing_beam_disabledBoolean Also known as: outgoing_beam_disabled?

Whether using NFC to beam data from apps is disabled. Corresponds to the JSON property outgoingBeamDisabled

Returns:

  • (Boolean)


5699
5700
5701
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5699

def outgoing_beam_disabled
  @outgoing_beam_disabled
end

#outgoing_calls_disabledBoolean Also known as: outgoing_calls_disabled?

Whether outgoing calls are disabled. Corresponds to the JSON property outgoingCallsDisabled

Returns:

  • (Boolean)


5705
5706
5707
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5705

def outgoing_calls_disabled
  @outgoing_calls_disabled
end

#password_policiesArray<Google::Apis::AndroidmanagementV1::PasswordRequirements>

Password requirement policies. Different policies can be set for work profile or fully managed devices by setting the password_scope field in the policy. Corresponds to the JSON property passwordPolicies



5712
5713
5714
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5712

def password_policies
  @password_policies
end

#password_requirementsGoogle::Apis::AndroidmanagementV1::PasswordRequirements

Requirements for the password used to unlock a device. Corresponds to the JSON property passwordRequirements



5717
5718
5719
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5717

def password_requirements
  @password_requirements
end

#permission_grantsArray<Google::Apis::AndroidmanagementV1::PermissionGrant>

Explicit permission or group grants or denials for all apps. These values override the default_permission_policy. Corresponds to the JSON property permissionGrants



5723
5724
5725
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5723

def permission_grants
  @permission_grants
end

#permitted_accessibility_servicesGoogle::Apis::AndroidmanagementV1::PackageNameList

A list of package names. Corresponds to the JSON property permittedAccessibilityServices



5728
5729
5730
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5728

def permitted_accessibility_services
  @permitted_accessibility_services
end

#permitted_input_methodsGoogle::Apis::AndroidmanagementV1::PackageNameList

A list of package names. Corresponds to the JSON property permittedInputMethods



5733
5734
5735
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5733

def permitted_input_methods
  @permitted_input_methods
end

#persistent_preferred_activitiesArray<Google::Apis::AndroidmanagementV1::PersistentPreferredActivity>

Default intent handler activities. Corresponds to the JSON property persistentPreferredActivities



5738
5739
5740
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5738

def persistent_preferred_activities
  @persistent_preferred_activities
end

#personal_usage_policiesGoogle::Apis::AndroidmanagementV1::PersonalUsagePolicies

Policies controlling personal usage on a company-owned device with a work profile. Corresponds to the JSON property personalUsagePolicies



5744
5745
5746
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5744

def personal_usage_policies
  @personal_usage_policies
end

#play_store_modeString

This mode controls which apps are available to the user in the Play Store and the behavior on the device when apps are removed from the policy. Corresponds to the JSON property playStoreMode

Returns:

  • (String)


5750
5751
5752
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5750

def play_store_mode
  @play_store_mode
end

#policy_enforcement_rulesArray<Google::Apis::AndroidmanagementV1::PolicyEnforcementRule>

Rules that define the behavior when a particular policy can not be applied on device Corresponds to the JSON property policyEnforcementRules



5756
5757
5758
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5756

def policy_enforcement_rules
  @policy_enforcement_rules
end

#preferential_network_serviceString

Controls whether preferential network service is enabled on the work profile or on fully managed devices. For example, an organization may have an agreement with a carrier that all of the work data from its employees' devices will be sent via a network service dedicated for enterprise use. An example of a supported preferential network service is the enterprise slice on 5G networks. This policy has no effect if preferentialNetworkServiceSettings or ApplicationPolicy.preferentialNetworkId is set on devices running Android 13 or above. Corresponds to the JSON property preferentialNetworkService

Returns:

  • (String)


5768
5769
5770
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5768

def preferential_network_service
  @preferential_network_service
end

#printing_policyString

Optional. Controls whether printing is allowed. This is supported on devices running Android 9 and above. . Corresponds to the JSON property printingPolicy

Returns:

  • (String)


5774
5775
5776
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5774

def printing_policy
  @printing_policy
end

#private_key_selection_enabledBoolean Also known as: private_key_selection_enabled?

Allows showing UI on a device for a user to choose a private key alias if there are no matching rules in ChoosePrivateKeyRules. For devices below Android P, setting this may leave enterprise keys vulnerable. This value will have no effect if any application has CERT_SELECTION delegation scope. Corresponds to the JSON property privateKeySelectionEnabled

Returns:

  • (Boolean)


5782
5783
5784
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5782

def private_key_selection_enabled
  @private_key_selection_enabled
end

Configuration info for an HTTP proxy. For a direct proxy, set the host, port, and excluded_hosts fields. For a PAC script proxy, set the pac_uri field. Corresponds to the JSON property recommendedGlobalProxy



5789
5790
5791
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5789

def recommended_global_proxy
  @recommended_global_proxy
end

#remove_user_disabledBoolean Also known as: remove_user_disabled?

Whether removing other users is disabled. Corresponds to the JSON property removeUserDisabled

Returns:

  • (Boolean)


5794
5795
5796
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5794

def remove_user_disabled
  @remove_user_disabled
end

#safe_boot_disabledBoolean Also known as: safe_boot_disabled?

Whether rebooting the device into safe boot is disabled. Corresponds to the JSON property safeBootDisabled

Returns:

  • (Boolean)


5800
5801
5802
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5800

def safe_boot_disabled
  @safe_boot_disabled
end

#screen_capture_disabledBoolean Also known as: screen_capture_disabled?

Whether screen capture is disabled. This also blocks Circle to Search (https:// support.google.com/android/answer/14508957). Corresponds to the JSON property screenCaptureDisabled

Returns:

  • (Boolean)


5807
5808
5809
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5807

def screen_capture_disabled
  @screen_capture_disabled
end

#set_user_icon_disabledBoolean Also known as: set_user_icon_disabled?

Whether changing the user icon is disabled. This applies only on devices running Android 7 and above. Corresponds to the JSON property setUserIconDisabled

Returns:

  • (Boolean)


5814
5815
5816
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5814

def set_user_icon_disabled
  @set_user_icon_disabled
end

#set_wallpaper_disabledBoolean Also known as: set_wallpaper_disabled?

Whether changing the wallpaper is disabled. Corresponds to the JSON property setWallpaperDisabled

Returns:

  • (Boolean)


5820
5821
5822
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5820

def set_wallpaper_disabled
  @set_wallpaper_disabled
end

#setup_actionsArray<Google::Apis::AndroidmanagementV1::SetupAction>

Action to take during the setup process. At most one action may be specified. Corresponds to the JSON property setupActions



5826
5827
5828
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5826

def setup_actions
  @setup_actions
end

#share_location_disabledBoolean Also known as: share_location_disabled?

Whether location sharing is disabled. Corresponds to the JSON property shareLocationDisabled

Returns:

  • (Boolean)


5831
5832
5833
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5831

def share_location_disabled
  @share_location_disabled
end

#short_support_messageGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property shortSupportMessage



5838
5839
5840
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5838

def short_support_message
  @short_support_message
end

#skip_first_use_hints_enabledBoolean Also known as: skip_first_use_hints_enabled?

Flag to skip hints on the first use. Enterprise admin can enable the system recommendation for apps to skip their user tutorial and other introductory hints on first start-up. Corresponds to the JSON property skipFirstUseHintsEnabled

Returns:

  • (Boolean)


5845
5846
5847
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5845

def skip_first_use_hints_enabled
  @skip_first_use_hints_enabled
end

#sms_disabledBoolean Also known as: sms_disabled?

Whether sending and receiving SMS messages is disabled. Corresponds to the JSON property smsDisabled

Returns:

  • (Boolean)


5851
5852
5853
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5851

def sms_disabled
  @sms_disabled
end

#status_bar_disabledBoolean Also known as: status_bar_disabled?

Whether the status bar is disabled. This disables notifications, quick settings, and other screen overlays that allow escape from full-screen mode. DEPRECATED. To disable the status bar on a kiosk device, use InstallType KIOSK or kioskCustomLauncherEnabled. Corresponds to the JSON property statusBarDisabled

Returns:

  • (Boolean)


5860
5861
5862
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5860

def status_bar_disabled
  @status_bar_disabled
end

#status_reporting_settingsGoogle::Apis::AndroidmanagementV1::StatusReportingSettings

Settings controlling the behavior of status reports. Corresponds to the JSON property statusReportingSettings



5866
5867
5868
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5866

def status_reporting_settings
  @status_reporting_settings
end

#stay_on_plugged_modesArray<String>

The battery plugged in modes for which the device stays on. When using this setting, it is recommended to clear maximum_time_to_lock so that the device doesn't lock itself while it stays on. Corresponds to the JSON property stayOnPluggedModes

Returns:

  • (Array<String>)


5873
5874
5875
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5873

def stay_on_plugged_modes
  @stay_on_plugged_modes
end

#system_updateGoogle::Apis::AndroidmanagementV1::SystemUpdate

Configuration for managing system updatesNote: Google Play system updates ( https://source.android.com/docs/core/ota/modular-system) (also called Mainline updates) are automatically downloaded but require a device reboot to be installed. Refer to the mainline section in Manage system updates (https:// developer.android.com/work/dpc/system-updates#mainline) for further details. Corresponds to the JSON property systemUpdate



5882
5883
5884
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5882

def system_update
  @system_update
end

#tethering_config_disabledBoolean Also known as: tethering_config_disabled?

Whether configuring tethering and portable hotspots is disabled. If tetheringSettings is set to anything other than TETHERING_SETTINGS_UNSPECIFIED, this setting is ignored. Corresponds to the JSON property tetheringConfigDisabled

Returns:

  • (Boolean)


5889
5890
5891
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5889

def tethering_config_disabled
  @tethering_config_disabled
end

#uninstall_apps_disabledBoolean Also known as: uninstall_apps_disabled?

Whether user uninstallation of applications is disabled. This prevents apps from being uninstalled, even those removed using applications Corresponds to the JSON property uninstallAppsDisabled

Returns:

  • (Boolean)


5896
5897
5898
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5896

def uninstall_apps_disabled
  @uninstall_apps_disabled
end

#unmute_microphone_disabledBoolean Also known as: unmute_microphone_disabled?

If microphone_access is set to any value other than MICROPHONE_ACCESS_UNSPECIFIED, this has no effect. Otherwise this field controls whether microphones are disabled: If true, all microphones are disabled, otherwise they are available. This is available only on fully managed devices. Corresponds to the JSON property unmuteMicrophoneDisabled

Returns:

  • (Boolean)


5906
5907
5908
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5906

def unmute_microphone_disabled
  @unmute_microphone_disabled
end

#usage_logGoogle::Apis::AndroidmanagementV1::UsageLog

Controls types of device activity logs collected from the device and reported via Pub/Sub notification (https://developers.google.com/android/management/ notifications). Corresponds to the JSON property usageLog



5914
5915
5916
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5914

def usage_log
  @usage_log
end

#usb_file_transfer_disabledBoolean Also known as: usb_file_transfer_disabled?

Whether transferring files over USB is disabled. This is supported only on company-owned devices. Corresponds to the JSON property usbFileTransferDisabled

Returns:

  • (Boolean)


5920
5921
5922
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5920

def usb_file_transfer_disabled
  @usb_file_transfer_disabled
end

#usb_mass_storage_enabledBoolean Also known as: usb_mass_storage_enabled?

Whether USB storage is enabled. Deprecated. Corresponds to the JSON property usbMassStorageEnabled

Returns:

  • (Boolean)


5926
5927
5928
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5926

def usb_mass_storage_enabled
  @usb_mass_storage_enabled
end

#versionFixnum

The version of the policy. This is a read-only field. The version is incremented each time the policy is updated. Corresponds to the JSON property version

Returns:

  • (Fixnum)


5933
5934
5935
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5933

def version
  @version
end

#vpn_config_disabledBoolean Also known as: vpn_config_disabled?

Whether configuring VPN is disabled. Corresponds to the JSON property vpnConfigDisabled

Returns:

  • (Boolean)


5938
5939
5940
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5938

def vpn_config_disabled
  @vpn_config_disabled
end

#wifi_config_disabledBoolean Also known as: wifi_config_disabled?

Whether configuring Wi-Fi networks is disabled. Supported on fully managed devices and work profiles on company-owned devices. For fully managed devices, setting this to true removes all configured networks and retains only the networks configured using openNetworkConfiguration. For work profiles on company-owned devices, existing configured networks are not affected and the user is not allowed to add, remove, or modify Wi-Fi networks. If configureWifi is set to anything other than CONFIGURE_WIFI_UNSPECIFIED, this setting is ignored. Note: If a network connection can't be made at boot time and configuring Wi-Fi is disabled then network escape hatch will be shown in order to refresh the device policy (see networkEscapeHatchEnabled). Corresponds to the JSON property wifiConfigDisabled

Returns:

  • (Boolean)


5953
5954
5955
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5953

def wifi_config_disabled
  @wifi_config_disabled
end

#wifi_configs_lockdown_enabledBoolean Also known as: wifi_configs_lockdown_enabled?

This is deprecated. Corresponds to the JSON property wifiConfigsLockdownEnabled

Returns:

  • (Boolean)


5959
5960
5961
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5959

def wifi_configs_lockdown_enabled
  @wifi_configs_lockdown_enabled
end

#wipe_data_flagsArray<String>

Optional. Wipe flags to indicate what data is wiped when a device or profile wipe is triggered due to any reason (for example, non-compliance). This does not apply to the enterprises.devices.delete method. . This list must not have duplicates. Corresponds to the JSON property wipeDataFlags

Returns:

  • (Array<String>)


5968
5969
5970
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5968

def wipe_data_flags
  @wipe_data_flags
end

#work_account_setup_configGoogle::Apis::AndroidmanagementV1::WorkAccountSetupConfig

Controls the work account setup configuration, such as details of whether a Google authenticated account is required. Corresponds to the JSON property workAccountSetupConfig



5974
5975
5976
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5974

def 
  @work_account_setup_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
5996
5997
5998
5999
6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
6027
6028
6029
6030
6031
6032
6033
6034
6035
6036
6037
6038
6039
6040
6041
6042
6043
6044
6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
6073
6074
6075
6076
6077
6078
6079
6080
6081
6082
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 5981

def update!(**args)
  @account_types_with_management_disabled = args[:account_types_with_management_disabled] if args.key?(:account_types_with_management_disabled)
  @add_user_disabled = args[:add_user_disabled] if args.key?(:add_user_disabled)
  @adjust_volume_disabled = args[:adjust_volume_disabled] if args.key?(:adjust_volume_disabled)
  @advanced_security_overrides = args[:advanced_security_overrides] if args.key?(:advanced_security_overrides)
  @always_on_vpn_package = args[:always_on_vpn_package] if args.key?(:always_on_vpn_package)
  @android_device_policy_tracks = args[:android_device_policy_tracks] if args.key?(:android_device_policy_tracks)
  @app_auto_update_policy = args[:app_auto_update_policy] if args.key?(:app_auto_update_policy)
  @app_functions = args[:app_functions] if args.key?(:app_functions)
  @applications = args[:applications] if args.key?(:applications)
  @assist_content_policy = args[:assist_content_policy] if args.key?(:assist_content_policy)
  @auto_date_and_time_zone = args[:auto_date_and_time_zone] if args.key?(:auto_date_and_time_zone)
  @auto_time_required = args[:auto_time_required] if args.key?(:auto_time_required)
  @autofill_policy = args[:autofill_policy] if args.key?(:autofill_policy)
  @block_applications_enabled = args[:block_applications_enabled] if args.key?(:block_applications_enabled)
  @bluetooth_config_disabled = args[:bluetooth_config_disabled] if args.key?(:bluetooth_config_disabled)
  @bluetooth_contact_sharing_disabled = args[:bluetooth_contact_sharing_disabled] if args.key?(:bluetooth_contact_sharing_disabled)
  @bluetooth_disabled = args[:bluetooth_disabled] if args.key?(:bluetooth_disabled)
  @camera_access = args[:camera_access] if args.key?(:camera_access)
  @camera_disabled = args[:camera_disabled] if args.key?(:camera_disabled)
  @cell_broadcasts_config_disabled = args[:cell_broadcasts_config_disabled] if args.key?(:cell_broadcasts_config_disabled)
  @choose_private_key_rules = args[:choose_private_key_rules] if args.key?(:choose_private_key_rules)
  @compliance_rules = args[:compliance_rules] if args.key?(:compliance_rules)
  @create_windows_disabled = args[:create_windows_disabled] if args.key?(:create_windows_disabled)
  @credential_provider_policy_default = args[:credential_provider_policy_default] if args.key?(:credential_provider_policy_default)
  @credentials_config_disabled = args[:credentials_config_disabled] if args.key?(:credentials_config_disabled)
  @cross_profile_policies = args[:cross_profile_policies] if args.key?(:cross_profile_policies)
  @data_roaming_disabled = args[:data_roaming_disabled] if args.key?(:data_roaming_disabled)
  @debugging_features_allowed = args[:debugging_features_allowed] if args.key?(:debugging_features_allowed)
  @default_application_settings = args[:default_application_settings] if args.key?(:default_application_settings)
  @default_permission_policy = args[:default_permission_policy] if args.key?(:default_permission_policy)
  @device_connectivity_management = args[:device_connectivity_management] if args.key?(:device_connectivity_management)
  @device_owner_lock_screen_info = args[:device_owner_lock_screen_info] if args.key?(:device_owner_lock_screen_info)
  @device_radio_state = args[:device_radio_state] if args.key?(:device_radio_state)
  @display_settings = args[:display_settings] if args.key?(:display_settings)
  @encryption_policy = args[:encryption_policy] if args.key?(:encryption_policy)
  @ensure_verify_apps_enabled = args[:ensure_verify_apps_enabled] if args.key?(:ensure_verify_apps_enabled)
  @enterprise_display_name_visibility = args[:enterprise_display_name_visibility] if args.key?(:enterprise_display_name_visibility)
  @factory_reset_disabled = args[:factory_reset_disabled] if args.key?(:factory_reset_disabled)
  @frp_admin_emails = args[:frp_admin_emails] if args.key?(:frp_admin_emails)
  @fun_disabled = args[:fun_disabled] if args.key?(:fun_disabled)
  @install_apps_disabled = args[:install_apps_disabled] if args.key?(:install_apps_disabled)
  @install_unknown_sources_allowed = args[:install_unknown_sources_allowed] if args.key?(:install_unknown_sources_allowed)
  @keyguard_disabled = args[:keyguard_disabled] if args.key?(:keyguard_disabled)
  @keyguard_disabled_features = args[:keyguard_disabled_features] if args.key?(:keyguard_disabled_features)
  @kiosk_custom_launcher_enabled = args[:kiosk_custom_launcher_enabled] if args.key?(:kiosk_custom_launcher_enabled)
  @kiosk_customization = args[:kiosk_customization] if args.key?(:kiosk_customization)
  @location_mode = args[:location_mode] if args.key?(:location_mode)
  @long_support_message = args[:long_support_message] if args.key?(:long_support_message)
  @maximum_time_to_lock = args[:maximum_time_to_lock] if args.key?(:maximum_time_to_lock)
  @microphone_access = args[:microphone_access] if args.key?(:microphone_access)
  @minimum_api_level = args[:minimum_api_level] if args.key?(:minimum_api_level)
  @mobile_networks_config_disabled = args[:mobile_networks_config_disabled] if args.key?(:mobile_networks_config_disabled)
  @modify_accounts_disabled = args[:modify_accounts_disabled] if args.key?(:modify_accounts_disabled)
  @mount_physical_media_disabled = args[:mount_physical_media_disabled] if args.key?(:mount_physical_media_disabled)
  @name = args[:name] if args.key?(:name)
  @network_escape_hatch_enabled = args[:network_escape_hatch_enabled] if args.key?(:network_escape_hatch_enabled)
  @network_reset_disabled = args[:network_reset_disabled] if args.key?(:network_reset_disabled)
  @onc_certificate_providers = args[:onc_certificate_providers] if args.key?(:onc_certificate_providers)
  @open_network_configuration = args[:open_network_configuration] if args.key?(:open_network_configuration)
  @outgoing_beam_disabled = args[:outgoing_beam_disabled] if args.key?(:outgoing_beam_disabled)
  @outgoing_calls_disabled = args[:outgoing_calls_disabled] if args.key?(:outgoing_calls_disabled)
  @password_policies = args[:password_policies] if args.key?(:password_policies)
  @password_requirements = args[:password_requirements] if args.key?(:password_requirements)
  @permission_grants = args[:permission_grants] if args.key?(:permission_grants)
  @permitted_accessibility_services = args[:permitted_accessibility_services] if args.key?(:permitted_accessibility_services)
  @permitted_input_methods = args[:permitted_input_methods] if args.key?(:permitted_input_methods)
  @persistent_preferred_activities = args[:persistent_preferred_activities] if args.key?(:persistent_preferred_activities)
  @personal_usage_policies = args[:personal_usage_policies] if args.key?(:personal_usage_policies)
  @play_store_mode = args[:play_store_mode] if args.key?(:play_store_mode)
  @policy_enforcement_rules = args[:policy_enforcement_rules] if args.key?(:policy_enforcement_rules)
  @preferential_network_service = args[:preferential_network_service] if args.key?(:preferential_network_service)
  @printing_policy = args[:printing_policy] if args.key?(:printing_policy)
  @private_key_selection_enabled = args[:private_key_selection_enabled] if args.key?(:private_key_selection_enabled)
  @recommended_global_proxy = args[:recommended_global_proxy] if args.key?(:recommended_global_proxy)
  @remove_user_disabled = args[:remove_user_disabled] if args.key?(:remove_user_disabled)
  @safe_boot_disabled = args[:safe_boot_disabled] if args.key?(:safe_boot_disabled)
  @screen_capture_disabled = args[:screen_capture_disabled] if args.key?(:screen_capture_disabled)
  @set_user_icon_disabled = args[:set_user_icon_disabled] if args.key?(:set_user_icon_disabled)
  @set_wallpaper_disabled = args[:set_wallpaper_disabled] if args.key?(:set_wallpaper_disabled)
  @setup_actions = args[:setup_actions] if args.key?(:setup_actions)
  @share_location_disabled = args[:share_location_disabled] if args.key?(:share_location_disabled)
  @short_support_message = args[:short_support_message] if args.key?(:short_support_message)
  @skip_first_use_hints_enabled = args[:skip_first_use_hints_enabled] if args.key?(:skip_first_use_hints_enabled)
  @sms_disabled = args[:sms_disabled] if args.key?(:sms_disabled)
  @status_bar_disabled = args[:status_bar_disabled] if args.key?(:status_bar_disabled)
  @status_reporting_settings = args[:status_reporting_settings] if args.key?(:status_reporting_settings)
  @stay_on_plugged_modes = args[:stay_on_plugged_modes] if args.key?(:stay_on_plugged_modes)
  @system_update = args[:system_update] if args.key?(:system_update)
  @tethering_config_disabled = args[:tethering_config_disabled] if args.key?(:tethering_config_disabled)
  @uninstall_apps_disabled = args[:uninstall_apps_disabled] if args.key?(:uninstall_apps_disabled)
  @unmute_microphone_disabled = args[:unmute_microphone_disabled] if args.key?(:unmute_microphone_disabled)
  @usage_log = args[:usage_log] if args.key?(:usage_log)
  @usb_file_transfer_disabled = args[:usb_file_transfer_disabled] if args.key?(:usb_file_transfer_disabled)
  @usb_mass_storage_enabled = args[:usb_mass_storage_enabled] if args.key?(:usb_mass_storage_enabled)
  @version = args[:version] if args.key?(:version)
  @vpn_config_disabled = args[:vpn_config_disabled] if args.key?(:vpn_config_disabled)
  @wifi_config_disabled = args[:wifi_config_disabled] if args.key?(:wifi_config_disabled)
  @wifi_configs_lockdown_enabled = args[:wifi_configs_lockdown_enabled] if args.key?(:wifi_configs_lockdown_enabled)
  @wipe_data_flags = args[:wipe_data_flags] if args.key?(:wipe_data_flags)
  @work_account_setup_config = args[:work_account_setup_config] if args.key?(:work_account_setup_config)
end