Class: Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Individual preferential network service configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreferentialNetworkServiceConfig

Returns a new instance of PreferentialNetworkServiceConfig.



6140
6141
6142
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fallback_to_default_connectionString

Optional. Whether fallback to the device-wide default network is allowed. If this is set to FALLBACK_TO_DEFAULT_CONNECTION_ALLOWED, then nonMatchingNetworks must not be set to NON_MATCHING_NETWORKS_DISALLOWED, the policy will be rejected otherwise. Note: If this is set to FALLBACK_TO_DEFAULT_CONNECTION_DISALLOWED, applications are not able to access the internet if the 5G slice is not available. Corresponds to the JSON property fallbackToDefaultConnection

Returns:

  • (String)


6123
6124
6125
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6123

def fallback_to_default_connection
  @fallback_to_default_connection
end

#non_matching_networksString

Optional. Whether apps this configuration applies to are blocked from using networks other than the preferential service. If this is set to NON_MATCHING_NETWORKS_DISALLOWED, then fallbackToDefaultConnection must be set to FALLBACK_TO_DEFAULT_CONNECTION_DISALLOWED. Corresponds to the JSON property nonMatchingNetworks

Returns:

  • (String)


6131
6132
6133
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6131

def non_matching_networks
  @non_matching_networks
end

#preferential_network_idString

Required. Preferential network identifier. This must not be set to NO_PREFERENTIAL_NETWORK or PREFERENTIAL_NETWORK_ID_UNSPECIFIED, the policy will be rejected otherwise. Corresponds to the JSON property preferentialNetworkId

Returns:

  • (String)


6138
6139
6140
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6138

def preferential_network_id
  @preferential_network_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6145
6146
6147
6148
6149
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6145

def update!(**args)
  @fallback_to_default_connection = args[:fallback_to_default_connection] if args.key?(:fallback_to_default_connection)
  @non_matching_networks = args[:non_matching_networks] if args.key?(:non_matching_networks)
  @preferential_network_id = args[:preferential_network_id] if args.key?(:preferential_network_id)
end