Class: Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Preferential network service settings.
Instance Attribute Summary collapse
-
#default_preferential_network_id ⇒ String
Required.
-
#preferential_network_service_configs ⇒ Array<Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceConfig>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreferentialNetworkServiceSettings
constructor
A new instance of PreferentialNetworkServiceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreferentialNetworkServiceSettings
Returns a new instance of PreferentialNetworkServiceSettings.
6182 6183 6184 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_preferential_network_id ⇒ String
Required. Default preferential network ID for the applications that are not in
applications or if ApplicationPolicy.preferentialNetworkId is set to
PREFERENTIAL_NETWORK_ID_UNSPECIFIED. There must be a configuration for the
specified network ID in preferentialNetworkServiceConfigs, unless this is set
to NO_PREFERENTIAL_NETWORK. If set to PREFERENTIAL_NETWORK_ID_UNSPECIFIED or
unset, this defaults to NO_PREFERENTIAL_NETWORK. Note: If the default
preferential network is misconfigured, applications with no ApplicationPolicy.
preferentialNetworkId set are not able to access the internet. This setting
does not apply to the following critical apps: com.google.android.apps.work.
clouddpc com.google.android.gmsApplicationPolicy.preferentialNetworkId can
still be used to configure the preferential network for them.
Corresponds to the JSON property defaultPreferentialNetworkId
6169 6170 6171 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6169 def default_preferential_network_id @default_preferential_network_id end |
#preferential_network_service_configs ⇒ Array<Google::Apis::AndroidmanagementV1::PreferentialNetworkServiceConfig>
Required. Preferential network service configurations which enables having
multiple enterprise slices. There must not be multiple configurations with the
same preferentialNetworkId. If a configuration is not referenced by any
application by setting ApplicationPolicy.preferentialNetworkId or by setting
defaultPreferentialNetworkId, it will be ignored. For devices on 4G networks,
enterprise APN needs to be configured additionally to set up data call for
preferential network service. These APNs can be added using apnPolicy.
Corresponds to the JSON property preferentialNetworkServiceConfigs
6180 6181 6182 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6180 def preferential_network_service_configs @preferential_network_service_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6187 6188 6189 6190 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6187 def update!(**args) @default_preferential_network_id = args[:default_preferential_network_id] if args.key?(:default_preferential_network_id) @preferential_network_service_configs = args[:preferential_network_service_configs] if args.key?(:preferential_network_service_configs) end |