Class: Google::Apis::AndroidmanagementV1::ProvisioningInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information about a device that is available during setup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProvisioningInfo

Returns a new instance of ProvisioningInfo.



6298
6299
6300
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_levelFixnum

The API level of the Android platform version running on the device. Corresponds to the JSON property apiLevel

Returns:

  • (Fixnum)


6243
6244
6245
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6243

def api_level
  @api_level
end

#authenticated_user_emailString

The email address of the authenticated user (only present for Google Account provisioning method). Corresponds to the JSON property authenticatedUserEmail

Returns:

  • (String)


6249
6250
6251
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6249

def authenticated_user_email
  @authenticated_user_email
end

#brandString

The brand of the device. For example, Google. Corresponds to the JSON property brand

Returns:

  • (String)


6254
6255
6256
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6254

def brand
  @brand
end

#enterpriseString

The name of the enterprise in the form enterprises/enterprise. Corresponds to the JSON property enterprise

Returns:

  • (String)


6259
6260
6261
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6259

def enterprise
  @enterprise
end

#imeiString

For corporate-owned devices, IMEI number of the GSM device. For example, A1000031212. Corresponds to the JSON property imei

Returns:

  • (String)


6265
6266
6267
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6265

def imei
  @imei
end

#management_modeString

The management mode of the device or profile. Corresponds to the JSON property managementMode

Returns:

  • (String)


6270
6271
6272
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6270

def management_mode
  @management_mode
end

#meidString

For corporate-owned devices, MEID number of the CDMA device. For example, A00000292788E1. Corresponds to the JSON property meid

Returns:

  • (String)


6276
6277
6278
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6276

def meid
  @meid
end

#modelString

The model of the device. For example, Asus Nexus 7. Corresponds to the JSON property model

Returns:

  • (String)


6281
6282
6283
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6281

def model
  @model
end

#nameString

The name of this resource in the form provisioningInfo/provisioning_info. Corresponds to the JSON property name

Returns:

  • (String)


6286
6287
6288
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6286

def name
  @name
end

#ownershipString

Ownership of the managed device. Corresponds to the JSON property ownership

Returns:

  • (String)


6291
6292
6293
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6291

def ownership
  @ownership
end

#serial_numberString

For corporate-owned devices, The device serial number. Corresponds to the JSON property serialNumber

Returns:

  • (String)


6296
6297
6298
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6296

def serial_number
  @serial_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
6315
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6303

def update!(**args)
  @api_level = args[:api_level] if args.key?(:api_level)
  @authenticated_user_email = args[:authenticated_user_email] if args.key?(:authenticated_user_email)
  @brand = args[:brand] if args.key?(:brand)
  @enterprise = args[:enterprise] if args.key?(:enterprise)
  @imei = args[:imei] if args.key?(:imei)
  @management_mode = args[:management_mode] if args.key?(:management_mode)
  @meid = args[:meid] if args.key?(:meid)
  @model = args[:model] if args.key?(:model)
  @name = args[:name] if args.key?(:name)
  @ownership = args[:ownership] if args.key?(:ownership)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
end