Class: Google::Apis::AndroidmanagementV1::RemovePolicyApplicationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Response to a request to remove ApplicationPolicy objects in the given policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemovePolicyApplicationsResponse

Returns a new instance of RemovePolicyApplicationsResponse.



6395
6396
6397
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::AndroidmanagementV1::Policy

A policy resource represents a group of settings that govern the behavior of a managed device and the apps installed on it. Corresponds to the JSON property policy



6393
6394
6395
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6393

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6400
6401
6402
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6400

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
end