Class: Google::Apis::AndroidmanagementV1::ScreenTimeoutSettings
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::ScreenTimeoutSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Controls the screen timeout settings.
Instance Attribute Summary collapse
-
#screen_timeout ⇒ String
Optional.
-
#screen_timeout_mode ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScreenTimeoutSettings
constructor
A new instance of ScreenTimeoutSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScreenTimeoutSettings
Returns a new instance of ScreenTimeoutSettings.
6633 6634 6635 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#screen_timeout ⇒ String
Optional. Controls the screen timeout duration. The screen timeout duration
must be greater than 0, otherwise it is rejected. Additionally, it should not
be greater than maximumTimeToLock, otherwise the screen timeout is set to
maximumTimeToLock and a NonComplianceDetail with INVALID_VALUE reason and
SCREEN_TIMEOUT_GREATER_THAN_MAXIMUM_TIME_TO_LOCK specific reason is reported.
If the screen timeout is less than a certain lower bound, it is set to the
lower bound. The lower bound may vary across devices. If this is set,
screenTimeoutMode must be SCREEN_TIMEOUT_ENFORCED. Supported on Android 9 and
above on fully managed devices. A NonComplianceDetail with API_LEVEL is
reported if the Android version is less than 9. Supported on work profiles on
company-owned devices on Android 15 and above.
Corresponds to the JSON property screenTimeout
6626 6627 6628 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6626 def screen_timeout @screen_timeout end |
#screen_timeout_mode ⇒ String
Optional. Controls whether the user is allowed to configure the screen timeout.
Corresponds to the JSON property screenTimeoutMode
6631 6632 6633 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6631 def screen_timeout_mode @screen_timeout_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6638 6639 6640 6641 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6638 def update!(**args) @screen_timeout = args[:screen_timeout] if args.key?(:screen_timeout) @screen_timeout_mode = args[:screen_timeout_mode] if args.key?(:screen_timeout_mode) end |