Class: Google::Apis::AndroidmanagementV1::SignupUrl
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SignupUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An enterprise signup URL.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the resource.
-
#url ⇒ String
A URL where an enterprise admin can register their enterprise.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignupUrl
constructor
A new instance of SignupUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignupUrl
Returns a new instance of SignupUrl.
6848 6849 6850 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the resource. Use this value in the signupUrl field when calling
enterprises.create to complete the enterprise signup flow.
Corresponds to the JSON property name
6840 6841 6842 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6840 def name @name end |
#url ⇒ String
A URL where an enterprise admin can register their enterprise. The page can't
be rendered in an iframe.
Corresponds to the JSON property url
6846 6847 6848 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6846 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6853 6854 6855 6856 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6853 def update!(**args) @name = args[:name] if args.key?(:name) @url = args[:url] if args.key?(:url) end |