Class: Google::Apis::AndroidmanagementV1::SignupUrl
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SignupUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An enterprise signup URL.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the resource.
-
#url ⇒ String
A URL where an enterprise admin can register their enterprise.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignupUrl
constructor
A new instance of SignupUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignupUrl
Returns a new instance of SignupUrl.
6751 6752 6753 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the resource. Use this value in the signupUrl field when calling
enterprises.create to complete the enterprise signup flow.
Corresponds to the JSON property name
6743 6744 6745 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6743 def name @name end |
#url ⇒ String
A URL where an enterprise admin can register their enterprise. The page can't
be rendered in an iframe.
Corresponds to the JSON property url
6749 6750 6751 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6749 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6756 6757 6758 6759 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6756 def update!(**args) @name = args[:name] if args.key?(:name) @url = args[:url] if args.key?(:url) end |