Class: Google::Apis::AndroidmanagementV1::SignupUrl
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SignupUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An enterprise signup URL.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the resource.
-
#url ⇒ String
A URL where an enterprise admin can register their enterprise.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignupUrl
constructor
A new instance of SignupUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignupUrl
Returns a new instance of SignupUrl.
6696 6697 6698 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6696 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the resource. Use this value in the signupUrl field when calling
enterprises.create to complete the enterprise signup flow.
Corresponds to the JSON property name
6688 6689 6690 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6688 def name @name end |
#url ⇒ String
A URL where an enterprise admin can register their enterprise. The page can't
be rendered in an iframe.
Corresponds to the JSON property url
6694 6695 6696 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6694 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6701 6702 6703 6704 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6701 def update!(**args) @name = args[:name] if args.key?(:name) @url = args[:url] if args.key?(:url) end |