Class: Google::Apis::AndroidmanagementV1::SoftwareInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Information about device software.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareInfo

Returns a new instance of SoftwareInfo.



6770
6771
6772
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_build_numberString

Android build ID string meant for displaying to the user. For example, shamu- userdebug 6.0.1 MOB30I 2756745 dev-keys. Corresponds to the JSON property androidBuildNumber

Returns:

  • (String)


6715
6716
6717
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6715

def android_build_number
  @android_build_number
end

#android_build_timeString

Build time. Corresponds to the JSON property androidBuildTime

Returns:

  • (String)


6720
6721
6722
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6720

def android_build_time
  @android_build_time
end

#android_device_policy_version_codeFixnum

The Android Device Policy app version code. Corresponds to the JSON property androidDevicePolicyVersionCode

Returns:

  • (Fixnum)


6725
6726
6727
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6725

def android_device_policy_version_code
  @android_device_policy_version_code
end

#android_device_policy_version_nameString

The Android Device Policy app version as displayed to the user. Corresponds to the JSON property androidDevicePolicyVersionName

Returns:

  • (String)


6730
6731
6732
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6730

def android_device_policy_version_name
  @android_device_policy_version_name
end

#android_versionString

The user-visible Android version string. For example, 6.0.1. Corresponds to the JSON property androidVersion

Returns:

  • (String)


6735
6736
6737
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6735

def android_version
  @android_version
end

#bootloader_versionString

The system bootloader version number, e.g. 0.6.7. Corresponds to the JSON property bootloaderVersion

Returns:

  • (String)


6740
6741
6742
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6740

def bootloader_version
  @bootloader_version
end

#device_build_signatureString

SHA-256 hash of android.content.pm.Signature (https://developer.android.com/ reference/android/content/pm/Signature.html) associated with the system package, which can be used to verify that the system build hasn't been modified. Corresponds to the JSON property deviceBuildSignature

Returns:

  • (String)


6748
6749
6750
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6748

def device_build_signature
  @device_build_signature
end

#device_kernel_versionString

Kernel version, for example, 2.6.32.9-g103d848. Corresponds to the JSON property deviceKernelVersion

Returns:

  • (String)


6753
6754
6755
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6753

def device_kernel_version
  @device_kernel_version
end

#primary_language_codeString

An IETF BCP 47 language code for the primary locale on the device. Corresponds to the JSON property primaryLanguageCode

Returns:

  • (String)


6758
6759
6760
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6758

def primary_language_code
  @primary_language_code
end

#security_patch_levelString

Security patch level, e.g. 2016-05-01. Corresponds to the JSON property securityPatchLevel

Returns:

  • (String)


6763
6764
6765
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6763

def security_patch_level
  @security_patch_level
end

#system_update_infoGoogle::Apis::AndroidmanagementV1::SystemUpdateInfo

Information about a potential pending system update. Corresponds to the JSON property systemUpdateInfo



6768
6769
6770
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6768

def system_update_info
  @system_update_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6775
6776
6777
6778
6779
6780
6781
6782
6783
6784
6785
6786
6787
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6775

def update!(**args)
  @android_build_number = args[:android_build_number] if args.key?(:android_build_number)
  @android_build_time = args[:android_build_time] if args.key?(:android_build_time)
  @android_device_policy_version_code = args[:android_device_policy_version_code] if args.key?(:android_device_policy_version_code)
  @android_device_policy_version_name = args[:android_device_policy_version_name] if args.key?(:android_device_policy_version_name)
  @android_version = args[:android_version] if args.key?(:android_version)
  @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version)
  @device_build_signature = args[:device_build_signature] if args.key?(:device_build_signature)
  @device_kernel_version = args[:device_kernel_version] if args.key?(:device_kernel_version)
  @primary_language_code = args[:primary_language_code] if args.key?(:primary_language_code)
  @security_patch_level = args[:security_patch_level] if args.key?(:security_patch_level)
  @system_update_info = args[:system_update_info] if args.key?(:system_update_info)
end