Class: Google::Apis::AndroidmanagementV1::StartLostModeParams
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::StartLostModeParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Parameters associated with the START_LOST_MODE command to put the device into lost mode. At least one of the parameters, not including the organization name, must be provided in order for the device to be put into lost mode.
Instance Attribute Summary collapse
-
#lost_email_address ⇒ String
The email address displayed to the user when the device is in lost mode.
-
#lost_message ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#lost_organization ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#lost_phone_number ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#lost_street_address ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartLostModeParams
constructor
A new instance of StartLostModeParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartLostModeParams
Returns a new instance of StartLostModeParams.
7043 7044 7045 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lost_email_address ⇒ String
The email address displayed to the user when the device is in lost mode.
Corresponds to the JSON property lostEmailAddress
7017 7018 7019 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7017 def lost_email_address @lost_email_address end |
#lost_message ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostMessage
7023 7024 7025 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7023 def @lost_message end |
#lost_organization ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostOrganization
7029 7030 7031 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7029 def lost_organization @lost_organization end |
#lost_phone_number ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostPhoneNumber
7035 7036 7037 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7035 def lost_phone_number @lost_phone_number end |
#lost_street_address ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostStreetAddress
7041 7042 7043 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7041 def lost_street_address @lost_street_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7048 7049 7050 7051 7052 7053 7054 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7048 def update!(**args) @lost_email_address = args[:lost_email_address] if args.key?(:lost_email_address) @lost_message = args[:lost_message] if args.key?(:lost_message) @lost_organization = args[:lost_organization] if args.key?(:lost_organization) @lost_phone_number = args[:lost_phone_number] if args.key?(:lost_phone_number) @lost_street_address = args[:lost_street_address] if args.key?(:lost_street_address) end |