Class: Google::Apis::AndroidmanagementV1::StartLostModeParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Parameters associated with the START_LOST_MODE command to put the device into lost mode. At least one of the parameters, not including the organization name, must be provided in order for the device to be put into lost mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartLostModeParams

Returns a new instance of StartLostModeParams.



7007
7008
7009
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lost_email_addressString

The email address displayed to the user when the device is in lost mode. Corresponds to the JSON property lostEmailAddress

Returns:

  • (String)


6981
6982
6983
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6981

def lost_email_address
  @lost_email_address
end

#lost_messageGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostMessage



6987
6988
6989
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6987

def lost_message
  @lost_message
end

#lost_organizationGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostOrganization



6993
6994
6995
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6993

def lost_organization
  @lost_organization
end

#lost_phone_numberGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostPhoneNumber



6999
7000
7001
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6999

def lost_phone_number
  @lost_phone_number
end

#lost_street_addressGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostStreetAddress



7005
7006
7007
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7005

def lost_street_address
  @lost_street_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7012
7013
7014
7015
7016
7017
7018
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7012

def update!(**args)
  @lost_email_address = args[:lost_email_address] if args.key?(:lost_email_address)
  @lost_message = args[:lost_message] if args.key?(:lost_message)
  @lost_organization = args[:lost_organization] if args.key?(:lost_organization)
  @lost_phone_number = args[:lost_phone_number] if args.key?(:lost_phone_number)
  @lost_street_address = args[:lost_street_address] if args.key?(:lost_street_address)
end