Class: Google::Apis::AndroidmanagementV1::StartLostModeParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Parameters associated with the START_LOST_MODE command to put the device into lost mode. At least one of the parameters, not including the organization name, must be provided in order for the device to be put into lost mode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StartLostModeParams

Returns a new instance of StartLostModeParams.



7002
7003
7004
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lost_email_addressString

The email address displayed to the user when the device is in lost mode. Corresponds to the JSON property lostEmailAddress

Returns:

  • (String)


6976
6977
6978
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6976

def lost_email_address
  @lost_email_address
end

#lost_messageGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostMessage



6982
6983
6984
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6982

def lost_message
  @lost_message
end

#lost_organizationGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostOrganization



6988
6989
6990
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6988

def lost_organization
  @lost_organization
end

#lost_phone_numberGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostPhoneNumber



6994
6995
6996
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6994

def lost_phone_number
  @lost_phone_number
end

#lost_street_addressGoogle::Apis::AndroidmanagementV1::UserFacingMessage

Provides a user-facing message with locale info. The maximum message length is 4096 characters. Corresponds to the JSON property lostStreetAddress



7000
7001
7002
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7000

def lost_street_address
  @lost_street_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7007
7008
7009
7010
7011
7012
7013
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7007

def update!(**args)
  @lost_email_address = args[:lost_email_address] if args.key?(:lost_email_address)
  @lost_message = args[:lost_message] if args.key?(:lost_message)
  @lost_organization = args[:lost_organization] if args.key?(:lost_organization)
  @lost_phone_number = args[:lost_phone_number] if args.key?(:lost_phone_number)
  @lost_street_address = args[:lost_street_address] if args.key?(:lost_street_address)
end