Class: Google::Apis::AndroidmanagementV1::StartLostModeParams
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::StartLostModeParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Parameters associated with the START_LOST_MODE command to put the device into lost mode. At least one of the parameters, not including the organization name, must be provided in order for the device to be put into lost mode.
Instance Attribute Summary collapse
-
#lost_email_address ⇒ String
The email address displayed to the user when the device is in lost mode.
-
#lost_message ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#lost_organization ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#lost_phone_number ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
-
#lost_street_address ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StartLostModeParams
constructor
A new instance of StartLostModeParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StartLostModeParams
Returns a new instance of StartLostModeParams.
6899 6900 6901 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lost_email_address ⇒ String
The email address displayed to the user when the device is in lost mode.
Corresponds to the JSON property lostEmailAddress
6873 6874 6875 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6873 def lost_email_address @lost_email_address end |
#lost_message ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostMessage
6879 6880 6881 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6879 def @lost_message end |
#lost_organization ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostOrganization
6885 6886 6887 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6885 def lost_organization @lost_organization end |
#lost_phone_number ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostPhoneNumber
6891 6892 6893 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6891 def lost_phone_number @lost_phone_number end |
#lost_street_address ⇒ Google::Apis::AndroidmanagementV1::UserFacingMessage
Provides a user-facing message with locale info. The maximum message length is
4096 characters.
Corresponds to the JSON property lostStreetAddress
6897 6898 6899 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6897 def lost_street_address @lost_street_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 6904 def update!(**args) @lost_email_address = args[:lost_email_address] if args.key?(:lost_email_address) @lost_message = args[:lost_message] if args.key?(:lost_message) @lost_organization = args[:lost_organization] if args.key?(:lost_organization) @lost_phone_number = args[:lost_phone_number] if args.key?(:lost_phone_number) @lost_street_address = args[:lost_street_address] if args.key?(:lost_street_address) end |