Class: Google::Apis::AndroidmanagementV1::SystemUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SystemUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Configuration for managing system updatesNote: Google Play system updates ( https://source.android.com/docs/core/ota/modular-system) (also called Mainline updates) are automatically downloaded but require a device reboot to be installed. Refer to the mainline section in Manage system updates (https:// developer.android.com/work/dpc/system-updates#mainline) for further details.
Instance Attribute Summary collapse
-
#end_minutes ⇒ Fixnum
If the type is WINDOWED, the end of the maintenance window, measured as the number of minutes after midnight in device's local time.
-
#freeze_periods ⇒ Array<Google::Apis::AndroidmanagementV1::FreezePeriod>
An annually repeating time period in which over-the-air (OTA) system updates are postponed to freeze the OS version running on a device.
-
#start_minutes ⇒ Fixnum
If the type is WINDOWED, the start of the maintenance window, measured as the number of minutes after midnight in the device's local time.
-
#type ⇒ String
The type of system update to configure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SystemUpdate
constructor
A new instance of SystemUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SystemUpdate
Returns a new instance of SystemUpdate.
7173 7174 7175 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_minutes ⇒ Fixnum
If the type is WINDOWED, the end of the maintenance window, measured as the
number of minutes after midnight in device's local time. This value must be
between 0 and 1439, inclusive. If this value is less than start_minutes, then
the maintenance window spans midnight. If the maintenance window specified is
smaller than 30 minutes, the actual window is extended to 30 minutes beyond
the start time.
Corresponds to the JSON property endMinutes
7151 7152 7153 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7151 def end_minutes @end_minutes end |
#freeze_periods ⇒ Array<Google::Apis::AndroidmanagementV1::FreezePeriod>
An annually repeating time period in which over-the-air (OTA) system updates
are postponed to freeze the OS version running on a device. To prevent
freezing the device indefinitely, each freeze period must be separated by at
least 60 days.
Corresponds to the JSON property freezePeriods
7159 7160 7161 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7159 def freeze_periods @freeze_periods end |
#start_minutes ⇒ Fixnum
If the type is WINDOWED, the start of the maintenance window, measured as the
number of minutes after midnight in the device's local time. This value must
be between 0 and 1439, inclusive.
Corresponds to the JSON property startMinutes
7166 7167 7168 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7166 def start_minutes @start_minutes end |
#type ⇒ String
The type of system update to configure.
Corresponds to the JSON property type
7171 7172 7173 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7171 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7178 7179 7180 7181 7182 7183 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7178 def update!(**args) @end_minutes = args[:end_minutes] if args.key?(:end_minutes) @freeze_periods = args[:freeze_periods] if args.key?(:freeze_periods) @start_minutes = args[:start_minutes] if args.key?(:start_minutes) @type = args[:type] if args.key?(:type) end |