Class: Google::Apis::AndroidmanagementV1::SystemUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Configuration for managing system updatesNote: Google Play system updates ( https://source.android.com/docs/core/ota/modular-system) (also called Mainline updates) are automatically downloaded but require a device reboot to be installed. Refer to the mainline section in Manage system updates (https:// developer.android.com/work/dpc/system-updates#mainline) for further details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SystemUpdate

Returns a new instance of SystemUpdate.



7161
7162
7163
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_minutesFixnum

If the type is WINDOWED, the end of the maintenance window, measured as the number of minutes after midnight in device's local time. This value must be between 0 and 1439, inclusive. If this value is less than start_minutes, then the maintenance window spans midnight. If the maintenance window specified is smaller than 30 minutes, the actual window is extended to 30 minutes beyond the start time. Corresponds to the JSON property endMinutes

Returns:

  • (Fixnum)


7139
7140
7141
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7139

def end_minutes
  @end_minutes
end

#freeze_periodsArray<Google::Apis::AndroidmanagementV1::FreezePeriod>

An annually repeating time period in which over-the-air (OTA) system updates are postponed to freeze the OS version running on a device. To prevent freezing the device indefinitely, each freeze period must be separated by at least 60 days. Corresponds to the JSON property freezePeriods



7147
7148
7149
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7147

def freeze_periods
  @freeze_periods
end

#start_minutesFixnum

If the type is WINDOWED, the start of the maintenance window, measured as the number of minutes after midnight in the device's local time. This value must be between 0 and 1439, inclusive. Corresponds to the JSON property startMinutes

Returns:

  • (Fixnum)


7154
7155
7156
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7154

def start_minutes
  @start_minutes
end

#typeString

The type of system update to configure. Corresponds to the JSON property type

Returns:

  • (String)


7159
7160
7161
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7159

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7166
7167
7168
7169
7170
7171
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7166

def update!(**args)
  @end_minutes = args[:end_minutes] if args.key?(:end_minutes)
  @freeze_periods = args[:freeze_periods] if args.key?(:freeze_periods)
  @start_minutes = args[:start_minutes] if args.key?(:start_minutes)
  @type = args[:type] if args.key?(:type)
end