Class: Google::Apis::AndroidmanagementV1::SystemUpdate
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::SystemUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Configuration for managing system updatesNote: Google Play system updates ( https://source.android.com/docs/core/ota/modular-system) (also called Mainline updates) are automatically downloaded but require a device reboot to be installed. Refer to the mainline section in Manage system updates (https:// developer.android.com/work/dpc/system-updates#mainline) for further details.
Instance Attribute Summary collapse
-
#allowed_days_without_update ⇒ Fixnum
If this is greater than zero, then this is the number of days after a pending update becoming available that a device can remain compliant, without taking the update.
-
#end_minutes ⇒ Fixnum
If the type is WINDOWED, the end of the maintenance window, measured as the number of minutes after midnight in device's local time.
-
#freeze_periods ⇒ Array<Google::Apis::AndroidmanagementV1::FreezePeriod>
An annually repeating time period in which over-the-air (OTA) system updates are postponed to freeze the OS version running on a device.
-
#start_minutes ⇒ Fixnum
If the type is WINDOWED, the start of the maintenance window, measured as the number of minutes after midnight in the device's local time.
-
#type ⇒ String
The type of system update to configure.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SystemUpdate
constructor
A new instance of SystemUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SystemUpdate
Returns a new instance of SystemUpdate.
7125 7126 7127 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_days_without_update ⇒ Fixnum
If this is greater than zero, then this is the number of days after a pending
update becoming available that a device can remain compliant, without taking
the update. Has no effect otherwise.
Corresponds to the JSON property allowedDaysWithoutUpdate
7093 7094 7095 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7093 def allowed_days_without_update @allowed_days_without_update end |
#end_minutes ⇒ Fixnum
If the type is WINDOWED, the end of the maintenance window, measured as the
number of minutes after midnight in device's local time. This value must be
between 0 and 1439, inclusive. If this value is less than start_minutes, then
the maintenance window spans midnight. If the maintenance window specified is
smaller than 30 minutes, the actual window is extended to 30 minutes beyond
the start time.
Corresponds to the JSON property endMinutes
7103 7104 7105 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7103 def end_minutes @end_minutes end |
#freeze_periods ⇒ Array<Google::Apis::AndroidmanagementV1::FreezePeriod>
An annually repeating time period in which over-the-air (OTA) system updates
are postponed to freeze the OS version running on a device. To prevent
freezing the device indefinitely, each freeze period must be separated by at
least 60 days.
Corresponds to the JSON property freezePeriods
7111 7112 7113 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7111 def freeze_periods @freeze_periods end |
#start_minutes ⇒ Fixnum
If the type is WINDOWED, the start of the maintenance window, measured as the
number of minutes after midnight in the device's local time. This value must
be between 0 and 1439, inclusive.
Corresponds to the JSON property startMinutes
7118 7119 7120 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7118 def start_minutes @start_minutes end |
#type ⇒ String
The type of system update to configure.
Corresponds to the JSON property type
7123 7124 7125 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7123 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7130 7131 7132 7133 7134 7135 7136 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7130 def update!(**args) @allowed_days_without_update = args[:allowed_days_without_update] if args.key?(:allowed_days_without_update) @end_minutes = args[:end_minutes] if args.key?(:end_minutes) @freeze_periods = args[:freeze_periods] if args.key?(:freeze_periods) @start_minutes = args[:start_minutes] if args.key?(:start_minutes) @type = args[:type] if args.key?(:type) end |