Class: Google::Apis::AndroidmanagementV1::TelephonyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Telephony information associated with a given SIM card on the device. This is supported for all SIM cards on fully managed devices on Android 6 and above. In addition, this is supported for admin-added eSIMs on all devices for Android 15 and above.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TelephonyInfo

Returns a new instance of TelephonyInfo.



7347
7348
7349
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_stateString

Output only. Activation state of the SIM card on the device. This is applicable for eSIMs only. This is supported on all devices for Android 15 and above. This is always ACTIVATION_STATE_UNSPECIFIED for physical SIMs and for devices below Android 15. Corresponds to the JSON property activationState

Returns:

  • (String)


7322
7323
7324
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7322

def activation_state
  @activation_state
end

#carrier_nameString

The carrier name associated with this SIM card. Corresponds to the JSON property carrierName

Returns:

  • (String)


7327
7328
7329
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7327

def carrier_name
  @carrier_name
end

#config_modeString

Output only. The configuration mode of the SIM card on the device. This is applicable for eSIMs only. This is supported on all devices for Android 15 and above. This is always CONFIG_MODE_UNSPECIFIED for physical SIMs and for devices below Android 15. Corresponds to the JSON property configMode

Returns:

  • (String)


7335
7336
7337
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7335

def config_mode
  @config_mode
end

#icc_idString

Output only. The ICCID associated with this SIM card. Corresponds to the JSON property iccId

Returns:

  • (String)


7340
7341
7342
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7340

def icc_id
  @icc_id
end

#phone_numberString

The phone number associated with this SIM card. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


7345
7346
7347
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7345

def phone_number
  @phone_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7352
7353
7354
7355
7356
7357
7358
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7352

def update!(**args)
  @activation_state = args[:activation_state] if args.key?(:activation_state)
  @carrier_name = args[:carrier_name] if args.key?(:carrier_name)
  @config_mode = args[:config_mode] if args.key?(:config_mode)
  @icc_id = args[:icc_id] if args.key?(:icc_id)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
end