Class: Google::Apis::AndroidmanagementV1::TelephonyInfo
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::TelephonyInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Telephony information associated with a given SIM card on the device. This is supported for all SIM cards on fully managed devices on Android 6 and above. In addition, this is supported for admin-added eSIMs on all devices for Android 15 and above.
Instance Attribute Summary collapse
-
#activation_state ⇒ String
Output only.
-
#carrier_name ⇒ String
The carrier name associated with this SIM card.
-
#config_mode ⇒ String
Output only.
-
#icc_id ⇒ String
Output only.
-
#phone_number ⇒ String
The phone number associated with this SIM card.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TelephonyInfo
constructor
A new instance of TelephonyInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TelephonyInfo
Returns a new instance of TelephonyInfo.
7239 7240 7241 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_state ⇒ String
Output only. Activation state of the SIM card on the device. This is
applicable for eSIMs only. This is supported on all devices for Android 15 and
above. This is always ACTIVATION_STATE_UNSPECIFIED for physical SIMs and for
devices below Android 15.
Corresponds to the JSON property activationState
7214 7215 7216 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7214 def activation_state @activation_state end |
#carrier_name ⇒ String
The carrier name associated with this SIM card.
Corresponds to the JSON property carrierName
7219 7220 7221 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7219 def carrier_name @carrier_name end |
#config_mode ⇒ String
Output only. The configuration mode of the SIM card on the device. This is
applicable for eSIMs only. This is supported on all devices for Android 15 and
above. This is always CONFIG_MODE_UNSPECIFIED for physical SIMs and for
devices below Android 15.
Corresponds to the JSON property configMode
7227 7228 7229 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7227 def config_mode @config_mode end |
#icc_id ⇒ String
Output only. The ICCID associated with this SIM card.
Corresponds to the JSON property iccId
7232 7233 7234 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7232 def icc_id @icc_id end |
#phone_number ⇒ String
The phone number associated with this SIM card.
Corresponds to the JSON property phoneNumber
7237 7238 7239 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7237 def phone_number @phone_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7244 7245 7246 7247 7248 7249 7250 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7244 def update!(**args) @activation_state = args[:activation_state] if args.key?(:activation_state) @carrier_name = args[:carrier_name] if args.key?(:carrier_name) @config_mode = args[:config_mode] if args.key?(:config_mode) @icc_id = args[:icc_id] if args.key?(:icc_id) @phone_number = args[:phone_number] if args.key?(:phone_number) end |