Class: Google::Apis::AndroidmanagementV1::UsageLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls types of device activity logs collected from the device and reported via Pub/Sub notification (https://developers.google.com/android/management/ notifications).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageLog

Returns a new instance of UsageLog.



7406
7407
7408
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabled_log_typesArray<String>

Specifies which log types are enabled. Note that users will receive on-device messaging when usage logging is enabled. Corresponds to the JSON property enabledLogTypes

Returns:

  • (Array<String>)


7398
7399
7400
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7398

def enabled_log_types
  @enabled_log_types
end

#upload_on_cellular_allowedArray<String>

Specifies which of the enabled log types can be uploaded over mobile data. By default logs are queued for upload when the device connects to WiFi. Corresponds to the JSON property uploadOnCellularAllowed

Returns:

  • (Array<String>)


7404
7405
7406
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7404

def upload_on_cellular_allowed
  @upload_on_cellular_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7411
7412
7413
7414
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7411

def update!(**args)
  @enabled_log_types = args[:enabled_log_types] if args.key?(:enabled_log_types)
  @upload_on_cellular_allowed = args[:upload_on_cellular_allowed] if args.key?(:upload_on_cellular_allowed)
end