Class: Google::Apis::AndroidmanagementV1::UsageLog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls types of device activity logs collected from the device and reported via Pub/Sub notification (https://developers.google.com/android/management/ notifications).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageLog

Returns a new instance of UsageLog.



7401
7402
7403
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabled_log_typesArray<String>

Specifies which log types are enabled. Note that users will receive on-device messaging when usage logging is enabled. Corresponds to the JSON property enabledLogTypes

Returns:

  • (Array<String>)


7393
7394
7395
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7393

def enabled_log_types
  @enabled_log_types
end

#upload_on_cellular_allowedArray<String>

Specifies which of the enabled log types can be uploaded over mobile data. By default logs are queued for upload when the device connects to WiFi. Corresponds to the JSON property uploadOnCellularAllowed

Returns:

  • (Array<String>)


7399
7400
7401
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7399

def upload_on_cellular_allowed
  @upload_on_cellular_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7406
7407
7408
7409
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7406

def update!(**args)
  @enabled_log_types = args[:enabled_log_types] if args.key?(:enabled_log_types)
  @upload_on_cellular_allowed = args[:upload_on_cellular_allowed] if args.key?(:upload_on_cellular_allowed)
end