Class: Google::Apis::AndroidmanagementV1::UsageLog
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::UsageLog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Controls types of device activity logs collected from the device and reported via Pub/Sub notification (https://developers.google.com/android/management/ notifications).
Instance Attribute Summary collapse
-
#enabled_log_types ⇒ Array<String>
Specifies which log types are enabled.
-
#upload_on_cellular_allowed ⇒ Array<String>
Specifies which of the enabled log types can be uploaded over mobile data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageLog
constructor
A new instance of UsageLog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageLog
Returns a new instance of UsageLog.
7298 7299 7300 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_log_types ⇒ Array<String>
Specifies which log types are enabled. Note that users will receive on-device
messaging when usage logging is enabled.
Corresponds to the JSON property enabledLogTypes
7290 7291 7292 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7290 def enabled_log_types @enabled_log_types end |
#upload_on_cellular_allowed ⇒ Array<String>
Specifies which of the enabled log types can be uploaded over mobile data. By
default logs are queued for upload when the device connects to WiFi.
Corresponds to the JSON property uploadOnCellularAllowed
7296 7297 7298 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7296 def upload_on_cellular_allowed @upload_on_cellular_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7303 7304 7305 7306 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7303 def update!(**args) @enabled_log_types = args[:enabled_log_types] if args.key?(:enabled_log_types) @upload_on_cellular_allowed = args[:upload_on_cellular_allowed] if args.key?(:upload_on_cellular_allowed) end |