Class: Google::Apis::AndroidmanagementV1::UsageLogEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::UsageLogEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An event logged on the device.
Instance Attribute Summary collapse
-
#adb_shell_command_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellCommandEvent
A shell command was issued over ADB via “adb shell command”.
-
#adb_shell_interactive_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellInteractiveEvent
An ADB interactive shell was opened via “adb shell”.
-
#app_process_start_event ⇒ Google::Apis::AndroidmanagementV1::AppProcessStartEvent
An app process was started.
-
#backup_service_toggled_event ⇒ Google::Apis::AndroidmanagementV1::BackupServiceToggledEvent
An admin has enabled or disabled backup service.
-
#cert_authority_installed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityInstalledEvent
A new root certificate was installed into the system's trusted credential storage.
-
#cert_authority_removed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityRemovedEvent
A root certificate was removed from the system's trusted credential storage.
-
#cert_validation_failure_event ⇒ Google::Apis::AndroidmanagementV1::CertValidationFailureEvent
An X.509v3 certificate failed to validate, currently this validation is performed on the Wi-FI access point and failure may be due to a mismatch upon server certificate validation.
-
#connect_event ⇒ Google::Apis::AndroidmanagementV1::ConnectEvent
A TCP connect event was initiated through the standard network stack.
-
#crypto_self_test_completed_event ⇒ Google::Apis::AndroidmanagementV1::CryptoSelfTestCompletedEvent
Validates whether Android’s built-in cryptographic library (BoringSSL) is valid.
-
#dns_event ⇒ Google::Apis::AndroidmanagementV1::DnsEvent
A DNS lookup event was initiated through the standard network stack.
-
#enrollment_complete_event ⇒ Google::Apis::AndroidmanagementV1::EnrollmentCompleteEvent
Represents that the device has completed enrollment.
-
#event_id ⇒ Fixnum
Unique id of the event.
-
#event_time ⇒ String
Device timestamp when the event was logged.
-
#event_type ⇒ String
The particular usage log event type that was reported on the device.
-
#file_pulled_event ⇒ Google::Apis::AndroidmanagementV1::FilePulledEvent
A file was downloaded from the device.
-
#file_pushed_event ⇒ Google::Apis::AndroidmanagementV1::FilePushedEvent
A file was uploaded onto the device.
-
#key_destruction_event ⇒ Google::Apis::AndroidmanagementV1::KeyDestructionEvent
A cryptographic key including user installed, admin installed and system maintained private key is removed from the device either by the user or management.
-
#key_generated_event ⇒ Google::Apis::AndroidmanagementV1::KeyGeneratedEvent
A cryptographic key including user installed, admin installed and system maintained private key is installed on the device either by the user or management.This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.
-
#key_import_event ⇒ Google::Apis::AndroidmanagementV1::KeyImportEvent
A cryptographic key including user installed, admin installed and system maintained private key is imported on the device either by the user or management.
-
#key_integrity_violation_event ⇒ Google::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent
A cryptographic key including user installed, admin installed and system maintained private key is determined to be corrupted due to storage corruption, hardware failure or some OS issue.
-
#keyguard_dismiss_auth_attempt_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissAuthAttemptEvent
An attempt was made to unlock the device.
-
#keyguard_dismissed_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissedEvent
The keyguard was dismissed.
-
#keyguard_secured_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardSecuredEvent
The device was locked either by user or timeout.
-
#log_buffer_size_critical_event ⇒ Google::Apis::AndroidmanagementV1::LogBufferSizeCriticalEvent
The usageLog buffer on the device has reached 90% of its capacity, therefore older events may be dropped.
-
#logging_started_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStartedEvent
usageLog policy has been enabled.
-
#logging_stopped_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStoppedEvent
usageLog policy has been disabled.
-
#lost_mode_location_event ⇒ Google::Apis::AndroidmanagementV1::LostModeLocationEvent
A lost mode event containing the device location and battery level as a percentage.
-
#lost_mode_outgoing_phone_call_event ⇒ Google::Apis::AndroidmanagementV1::LostModeOutgoingPhoneCallEvent
An event indicating an outgoing phone call has been made when a device is in lost mode.
-
#media_mount_event ⇒ Google::Apis::AndroidmanagementV1::MediaMountEvent
Removable media was mounted.
-
#media_unmount_event ⇒ Google::Apis::AndroidmanagementV1::MediaUnmountEvent
Removable media was unmounted.
-
#os_shutdown_event ⇒ Google::Apis::AndroidmanagementV1::OsShutdownEvent
Device was shutdown.
-
#os_startup_event ⇒ Google::Apis::AndroidmanagementV1::OsStartupEvent
Device was started.
-
#remote_lock_event ⇒ Google::Apis::AndroidmanagementV1::RemoteLockEvent
The device or profile has been remotely locked via the LOCK command.
-
#stop_lost_mode_user_attempt_event ⇒ Google::Apis::AndroidmanagementV1::StopLostModeUserAttemptEvent
A lost mode event indicating the user has attempted to stop lost mode.
-
#wipe_failure_event ⇒ Google::Apis::AndroidmanagementV1::WipeFailureEvent
The work profile or company-owned device failed to wipe when requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageLogEvent
constructor
A new instance of UsageLogEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageLogEvent
Returns a new instance of UsageLogEvent.
7623 7624 7625 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adb_shell_command_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellCommandEvent
A shell command was issued over ADB via “adb shell command”.
Corresponds to the JSON property adbShellCommandEvent
7419 7420 7421 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7419 def adb_shell_command_event @adb_shell_command_event end |
#adb_shell_interactive_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellInteractiveEvent
An ADB interactive shell was opened via “adb shell”. Intentionally empty.
Corresponds to the JSON property adbShellInteractiveEvent
7424 7425 7426 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7424 def adb_shell_interactive_event @adb_shell_interactive_event end |
#app_process_start_event ⇒ Google::Apis::AndroidmanagementV1::AppProcessStartEvent
An app process was started. This is available device-wide on fully managed
devices and within the work profile on organization-owned devices with a work
profile.
Corresponds to the JSON property appProcessStartEvent
7431 7432 7433 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7431 def app_process_start_event @app_process_start_event end |
#backup_service_toggled_event ⇒ Google::Apis::AndroidmanagementV1::BackupServiceToggledEvent
An admin has enabled or disabled backup service.
Corresponds to the JSON property backupServiceToggledEvent
7436 7437 7438 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7436 def backup_service_toggled_event @backup_service_toggled_event end |
#cert_authority_installed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityInstalledEvent
A new root certificate was installed into the system's trusted credential
storage. This is available device-wide on fully managed devices and within the
work profile on organization-owned devices with a work profile.
Corresponds to the JSON property certAuthorityInstalledEvent
7443 7444 7445 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7443 def @cert_authority_installed_event end |
#cert_authority_removed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityRemovedEvent
A root certificate was removed from the system's trusted credential storage.
This is available device-wide on fully managed devices and within the work
profile on organization-owned devices with a work profile.
Corresponds to the JSON property certAuthorityRemovedEvent
7450 7451 7452 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7450 def @cert_authority_removed_event end |
#cert_validation_failure_event ⇒ Google::Apis::AndroidmanagementV1::CertValidationFailureEvent
An X.509v3 certificate failed to validate, currently this validation is
performed on the Wi-FI access point and failure may be due to a mismatch upon
server certificate validation. However it may in the future include other
validation events of an X.509v3 certificate.
Corresponds to the JSON property certValidationFailureEvent
7458 7459 7460 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7458 def cert_validation_failure_event @cert_validation_failure_event end |
#connect_event ⇒ Google::Apis::AndroidmanagementV1::ConnectEvent
A TCP connect event was initiated through the standard network stack.
Corresponds to the JSON property connectEvent
7463 7464 7465 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7463 def connect_event @connect_event end |
#crypto_self_test_completed_event ⇒ Google::Apis::AndroidmanagementV1::CryptoSelfTestCompletedEvent
Validates whether Android’s built-in cryptographic library (BoringSSL) is
valid. Should always succeed on device boot, if it fails, the device should be
considered untrusted.
Corresponds to the JSON property cryptoSelfTestCompletedEvent
7470 7471 7472 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7470 def crypto_self_test_completed_event @crypto_self_test_completed_event end |
#dns_event ⇒ Google::Apis::AndroidmanagementV1::DnsEvent
A DNS lookup event was initiated through the standard network stack.
Corresponds to the JSON property dnsEvent
7475 7476 7477 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7475 def dns_event @dns_event end |
#enrollment_complete_event ⇒ Google::Apis::AndroidmanagementV1::EnrollmentCompleteEvent
Represents that the device has completed enrollment. User should be in the
launcher at this point, device at this point will be compliant and all setup
steps have been completed. Intentionally empty.
Corresponds to the JSON property enrollmentCompleteEvent
7482 7483 7484 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7482 def enrollment_complete_event @enrollment_complete_event end |
#event_id ⇒ Fixnum
Unique id of the event.
Corresponds to the JSON property eventId
7487 7488 7489 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7487 def event_id @event_id end |
#event_time ⇒ String
Device timestamp when the event was logged.
Corresponds to the JSON property eventTime
7492 7493 7494 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7492 def event_time @event_time end |
#event_type ⇒ String
The particular usage log event type that was reported on the device. Use this
to determine which event field to access.
Corresponds to the JSON property eventType
7498 7499 7500 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7498 def event_type @event_type end |
#file_pulled_event ⇒ Google::Apis::AndroidmanagementV1::FilePulledEvent
A file was downloaded from the device.
Corresponds to the JSON property filePulledEvent
7503 7504 7505 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7503 def file_pulled_event @file_pulled_event end |
#file_pushed_event ⇒ Google::Apis::AndroidmanagementV1::FilePushedEvent
A file was uploaded onto the device.
Corresponds to the JSON property filePushedEvent
7508 7509 7510 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7508 def file_pushed_event @file_pushed_event end |
#key_destruction_event ⇒ Google::Apis::AndroidmanagementV1::KeyDestructionEvent
A cryptographic key including user installed, admin installed and system
maintained private key is removed from the device either by the user or
management. This is available device-wide on fully managed devices and within
the work profile on organization-owned devices with a work profile.
Corresponds to the JSON property keyDestructionEvent
7516 7517 7518 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7516 def key_destruction_event @key_destruction_event end |
#key_generated_event ⇒ Google::Apis::AndroidmanagementV1::KeyGeneratedEvent
A cryptographic key including user installed, admin installed and system
maintained private key is installed on the device either by the user or
management.This is available device-wide on fully managed devices and within
the work profile on organization-owned devices with a work profile.
Corresponds to the JSON property keyGeneratedEvent
7524 7525 7526 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7524 def key_generated_event @key_generated_event end |
#key_import_event ⇒ Google::Apis::AndroidmanagementV1::KeyImportEvent
A cryptographic key including user installed, admin installed and system
maintained private key is imported on the device either by the user or
management. This is available device-wide on fully managed devices and within
the work profile on organization-owned devices with a work profile.
Corresponds to the JSON property keyImportEvent
7532 7533 7534 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7532 def key_import_event @key_import_event end |
#key_integrity_violation_event ⇒ Google::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent
A cryptographic key including user installed, admin installed and system
maintained private key is determined to be corrupted due to storage corruption,
hardware failure or some OS issue. This is available device-wide on fully
managed devices and within the work profile on organization-owned devices with
a work profile.
Corresponds to the JSON property keyIntegrityViolationEvent
7541 7542 7543 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7541 def key_integrity_violation_event @key_integrity_violation_event end |
#keyguard_dismiss_auth_attempt_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissAuthAttemptEvent
An attempt was made to unlock the device.
Corresponds to the JSON property keyguardDismissAuthAttemptEvent
7546 7547 7548 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7546 def keyguard_dismiss_auth_attempt_event @keyguard_dismiss_auth_attempt_event end |
#keyguard_dismissed_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissedEvent
The keyguard was dismissed. Intentionally empty.
Corresponds to the JSON property keyguardDismissedEvent
7551 7552 7553 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7551 def keyguard_dismissed_event @keyguard_dismissed_event end |
#keyguard_secured_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardSecuredEvent
The device was locked either by user or timeout. Intentionally empty.
Corresponds to the JSON property keyguardSecuredEvent
7556 7557 7558 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7556 def keyguard_secured_event @keyguard_secured_event end |
#log_buffer_size_critical_event ⇒ Google::Apis::AndroidmanagementV1::LogBufferSizeCriticalEvent
The usageLog buffer on the device has reached 90% of its capacity, therefore
older events may be dropped. Intentionally empty.
Corresponds to the JSON property logBufferSizeCriticalEvent
7562 7563 7564 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7562 def log_buffer_size_critical_event @log_buffer_size_critical_event end |
#logging_started_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStartedEvent
usageLog policy has been enabled. Intentionally empty.
Corresponds to the JSON property loggingStartedEvent
7567 7568 7569 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7567 def logging_started_event @logging_started_event end |
#logging_stopped_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStoppedEvent
usageLog policy has been disabled. Intentionally empty.
Corresponds to the JSON property loggingStoppedEvent
7572 7573 7574 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7572 def logging_stopped_event @logging_stopped_event end |
#lost_mode_location_event ⇒ Google::Apis::AndroidmanagementV1::LostModeLocationEvent
A lost mode event containing the device location and battery level as a
percentage.
Corresponds to the JSON property lostModeLocationEvent
7578 7579 7580 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7578 def lost_mode_location_event @lost_mode_location_event end |
#lost_mode_outgoing_phone_call_event ⇒ Google::Apis::AndroidmanagementV1::LostModeOutgoingPhoneCallEvent
An event indicating an outgoing phone call has been made when a device is in
lost mode. Intentionally empty.
Corresponds to the JSON property lostModeOutgoingPhoneCallEvent
7584 7585 7586 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7584 def lost_mode_outgoing_phone_call_event @lost_mode_outgoing_phone_call_event end |
#media_mount_event ⇒ Google::Apis::AndroidmanagementV1::MediaMountEvent
Removable media was mounted.
Corresponds to the JSON property mediaMountEvent
7589 7590 7591 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7589 def media_mount_event @media_mount_event end |
#media_unmount_event ⇒ Google::Apis::AndroidmanagementV1::MediaUnmountEvent
Removable media was unmounted.
Corresponds to the JSON property mediaUnmountEvent
7594 7595 7596 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7594 def media_unmount_event @media_unmount_event end |
#os_shutdown_event ⇒ Google::Apis::AndroidmanagementV1::OsShutdownEvent
Device was shutdown. Intentionally empty.
Corresponds to the JSON property osShutdownEvent
7599 7600 7601 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7599 def os_shutdown_event @os_shutdown_event end |
#os_startup_event ⇒ Google::Apis::AndroidmanagementV1::OsStartupEvent
Device was started.
Corresponds to the JSON property osStartupEvent
7604 7605 7606 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7604 def os_startup_event @os_startup_event end |
#remote_lock_event ⇒ Google::Apis::AndroidmanagementV1::RemoteLockEvent
The device or profile has been remotely locked via the LOCK command.
Corresponds to the JSON property remoteLockEvent
7609 7610 7611 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7609 def remote_lock_event @remote_lock_event end |
#stop_lost_mode_user_attempt_event ⇒ Google::Apis::AndroidmanagementV1::StopLostModeUserAttemptEvent
A lost mode event indicating the user has attempted to stop lost mode.
Corresponds to the JSON property stopLostModeUserAttemptEvent
7614 7615 7616 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7614 def stop_lost_mode_user_attempt_event @stop_lost_mode_user_attempt_event end |
#wipe_failure_event ⇒ Google::Apis::AndroidmanagementV1::WipeFailureEvent
The work profile or company-owned device failed to wipe when requested. This
could be user initiated or admin initiated e.g. delete was received.
Intentionally empty.
Corresponds to the JSON property wipeFailureEvent
7621 7622 7623 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7621 def wipe_failure_event @wipe_failure_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7628 7629 7630 7631 7632 7633 7634 7635 7636 7637 7638 7639 7640 7641 7642 7643 7644 7645 7646 7647 7648 7649 7650 7651 7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7628 def update!(**args) @adb_shell_command_event = args[:adb_shell_command_event] if args.key?(:adb_shell_command_event) @adb_shell_interactive_event = args[:adb_shell_interactive_event] if args.key?(:adb_shell_interactive_event) @app_process_start_event = args[:app_process_start_event] if args.key?(:app_process_start_event) @backup_service_toggled_event = args[:backup_service_toggled_event] if args.key?(:backup_service_toggled_event) @cert_authority_installed_event = args[:cert_authority_installed_event] if args.key?(:cert_authority_installed_event) @cert_authority_removed_event = args[:cert_authority_removed_event] if args.key?(:cert_authority_removed_event) @cert_validation_failure_event = args[:cert_validation_failure_event] if args.key?(:cert_validation_failure_event) @connect_event = args[:connect_event] if args.key?(:connect_event) @crypto_self_test_completed_event = args[:crypto_self_test_completed_event] if args.key?(:crypto_self_test_completed_event) @dns_event = args[:dns_event] if args.key?(:dns_event) @enrollment_complete_event = args[:enrollment_complete_event] if args.key?(:enrollment_complete_event) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @event_type = args[:event_type] if args.key?(:event_type) @file_pulled_event = args[:file_pulled_event] if args.key?(:file_pulled_event) @file_pushed_event = args[:file_pushed_event] if args.key?(:file_pushed_event) @key_destruction_event = args[:key_destruction_event] if args.key?(:key_destruction_event) @key_generated_event = args[:key_generated_event] if args.key?(:key_generated_event) @key_import_event = args[:key_import_event] if args.key?(:key_import_event) @key_integrity_violation_event = args[:key_integrity_violation_event] if args.key?(:key_integrity_violation_event) @keyguard_dismiss_auth_attempt_event = args[:keyguard_dismiss_auth_attempt_event] if args.key?(:keyguard_dismiss_auth_attempt_event) @keyguard_dismissed_event = args[:keyguard_dismissed_event] if args.key?(:keyguard_dismissed_event) @keyguard_secured_event = args[:keyguard_secured_event] if args.key?(:keyguard_secured_event) @log_buffer_size_critical_event = args[:log_buffer_size_critical_event] if args.key?(:log_buffer_size_critical_event) @logging_started_event = args[:logging_started_event] if args.key?(:logging_started_event) @logging_stopped_event = args[:logging_stopped_event] if args.key?(:logging_stopped_event) @lost_mode_location_event = args[:lost_mode_location_event] if args.key?(:lost_mode_location_event) @lost_mode_outgoing_phone_call_event = args[:lost_mode_outgoing_phone_call_event] if args.key?(:lost_mode_outgoing_phone_call_event) @media_mount_event = args[:media_mount_event] if args.key?(:media_mount_event) @media_unmount_event = args[:media_unmount_event] if args.key?(:media_unmount_event) @os_shutdown_event = args[:os_shutdown_event] if args.key?(:os_shutdown_event) @os_startup_event = args[:os_startup_event] if args.key?(:os_startup_event) @remote_lock_event = args[:remote_lock_event] if args.key?(:remote_lock_event) @stop_lost_mode_user_attempt_event = args[:stop_lost_mode_user_attempt_event] if args.key?(:stop_lost_mode_user_attempt_event) @wipe_failure_event = args[:wipe_failure_event] if args.key?(:wipe_failure_event) end |