Class: Google::Apis::AndroidmanagementV1::UsageLogEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

An event logged on the device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsageLogEvent

Returns a new instance of UsageLogEvent.



7532
7533
7534
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adb_shell_command_eventGoogle::Apis::AndroidmanagementV1::AdbShellCommandEvent

A shell command was issued over ADB via “adb shell command”. Corresponds to the JSON property adbShellCommandEvent



7328
7329
7330
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7328

def adb_shell_command_event
  @adb_shell_command_event
end

#adb_shell_interactive_eventGoogle::Apis::AndroidmanagementV1::AdbShellInteractiveEvent

An ADB interactive shell was opened via “adb shell”. Intentionally empty. Corresponds to the JSON property adbShellInteractiveEvent



7333
7334
7335
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7333

def adb_shell_interactive_event
  @adb_shell_interactive_event
end

#app_process_start_eventGoogle::Apis::AndroidmanagementV1::AppProcessStartEvent

An app process was started. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property appProcessStartEvent



7340
7341
7342
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7340

def app_process_start_event
  @app_process_start_event
end

#backup_service_toggled_eventGoogle::Apis::AndroidmanagementV1::BackupServiceToggledEvent

An admin has enabled or disabled backup service. Corresponds to the JSON property backupServiceToggledEvent



7345
7346
7347
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7345

def backup_service_toggled_event
  @backup_service_toggled_event
end

#cert_authority_installed_eventGoogle::Apis::AndroidmanagementV1::CertAuthorityInstalledEvent

A new root certificate was installed into the system's trusted credential storage. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property certAuthorityInstalledEvent



7352
7353
7354
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7352

def cert_authority_installed_event
  @cert_authority_installed_event
end

#cert_authority_removed_eventGoogle::Apis::AndroidmanagementV1::CertAuthorityRemovedEvent

A root certificate was removed from the system's trusted credential storage. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property certAuthorityRemovedEvent



7359
7360
7361
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7359

def cert_authority_removed_event
  @cert_authority_removed_event
end

#cert_validation_failure_eventGoogle::Apis::AndroidmanagementV1::CertValidationFailureEvent

An X.509v3 certificate failed to validate, currently this validation is performed on the Wi-FI access point and failure may be due to a mismatch upon server certificate validation. However it may in the future include other validation events of an X.509v3 certificate. Corresponds to the JSON property certValidationFailureEvent



7367
7368
7369
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7367

def cert_validation_failure_event
  @cert_validation_failure_event
end

#connect_eventGoogle::Apis::AndroidmanagementV1::ConnectEvent

A TCP connect event was initiated through the standard network stack. Corresponds to the JSON property connectEvent



7372
7373
7374
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7372

def connect_event
  @connect_event
end

#crypto_self_test_completed_eventGoogle::Apis::AndroidmanagementV1::CryptoSelfTestCompletedEvent

Validates whether Android’s built-in cryptographic library (BoringSSL) is valid. Should always succeed on device boot, if it fails, the device should be considered untrusted. Corresponds to the JSON property cryptoSelfTestCompletedEvent



7379
7380
7381
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7379

def crypto_self_test_completed_event
  @crypto_self_test_completed_event
end

#dns_eventGoogle::Apis::AndroidmanagementV1::DnsEvent

A DNS lookup event was initiated through the standard network stack. Corresponds to the JSON property dnsEvent



7384
7385
7386
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7384

def dns_event
  @dns_event
end

#enrollment_complete_eventGoogle::Apis::AndroidmanagementV1::EnrollmentCompleteEvent

Represents that the device has completed enrollment. User should be in the launcher at this point, device at this point will be compliant and all setup steps have been completed. Intentionally empty. Corresponds to the JSON property enrollmentCompleteEvent



7391
7392
7393
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7391

def enrollment_complete_event
  @enrollment_complete_event
end

#event_idFixnum

Unique id of the event. Corresponds to the JSON property eventId

Returns:

  • (Fixnum)


7396
7397
7398
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7396

def event_id
  @event_id
end

#event_timeString

Device timestamp when the event was logged. Corresponds to the JSON property eventTime

Returns:

  • (String)


7401
7402
7403
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7401

def event_time
  @event_time
end

#event_typeString

The particular usage log event type that was reported on the device. Use this to determine which event field to access. Corresponds to the JSON property eventType

Returns:

  • (String)


7407
7408
7409
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7407

def event_type
  @event_type
end

#file_pulled_eventGoogle::Apis::AndroidmanagementV1::FilePulledEvent

A file was downloaded from the device. Corresponds to the JSON property filePulledEvent



7412
7413
7414
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7412

def file_pulled_event
  @file_pulled_event
end

#file_pushed_eventGoogle::Apis::AndroidmanagementV1::FilePushedEvent

A file was uploaded onto the device. Corresponds to the JSON property filePushedEvent



7417
7418
7419
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7417

def file_pushed_event
  @file_pushed_event
end

#key_destruction_eventGoogle::Apis::AndroidmanagementV1::KeyDestructionEvent

A cryptographic key including user installed, admin installed and system maintained private key is removed from the device either by the user or management. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property keyDestructionEvent



7425
7426
7427
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7425

def key_destruction_event
  @key_destruction_event
end

#key_generated_eventGoogle::Apis::AndroidmanagementV1::KeyGeneratedEvent

A cryptographic key including user installed, admin installed and system maintained private key is installed on the device either by the user or management.This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property keyGeneratedEvent



7433
7434
7435
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7433

def key_generated_event
  @key_generated_event
end

#key_import_eventGoogle::Apis::AndroidmanagementV1::KeyImportEvent

A cryptographic key including user installed, admin installed and system maintained private key is imported on the device either by the user or management. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property keyImportEvent



7441
7442
7443
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7441

def key_import_event
  @key_import_event
end

#key_integrity_violation_eventGoogle::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent

A cryptographic key including user installed, admin installed and system maintained private key is determined to be corrupted due to storage corruption, hardware failure or some OS issue. This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile. Corresponds to the JSON property keyIntegrityViolationEvent



7450
7451
7452
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7450

def key_integrity_violation_event
  @key_integrity_violation_event
end

#keyguard_dismiss_auth_attempt_eventGoogle::Apis::AndroidmanagementV1::KeyguardDismissAuthAttemptEvent

An attempt was made to unlock the device. Corresponds to the JSON property keyguardDismissAuthAttemptEvent



7455
7456
7457
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7455

def keyguard_dismiss_auth_attempt_event
  @keyguard_dismiss_auth_attempt_event
end

#keyguard_dismissed_eventGoogle::Apis::AndroidmanagementV1::KeyguardDismissedEvent

The keyguard was dismissed. Intentionally empty. Corresponds to the JSON property keyguardDismissedEvent



7460
7461
7462
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7460

def keyguard_dismissed_event
  @keyguard_dismissed_event
end

#keyguard_secured_eventGoogle::Apis::AndroidmanagementV1::KeyguardSecuredEvent

The device was locked either by user or timeout. Intentionally empty. Corresponds to the JSON property keyguardSecuredEvent



7465
7466
7467
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7465

def keyguard_secured_event
  @keyguard_secured_event
end

#log_buffer_size_critical_eventGoogle::Apis::AndroidmanagementV1::LogBufferSizeCriticalEvent

The usageLog buffer on the device has reached 90% of its capacity, therefore older events may be dropped. Intentionally empty. Corresponds to the JSON property logBufferSizeCriticalEvent



7471
7472
7473
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7471

def log_buffer_size_critical_event
  @log_buffer_size_critical_event
end

#logging_started_eventGoogle::Apis::AndroidmanagementV1::LoggingStartedEvent

usageLog policy has been enabled. Intentionally empty. Corresponds to the JSON property loggingStartedEvent



7476
7477
7478
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7476

def logging_started_event
  @logging_started_event
end

#logging_stopped_eventGoogle::Apis::AndroidmanagementV1::LoggingStoppedEvent

usageLog policy has been disabled. Intentionally empty. Corresponds to the JSON property loggingStoppedEvent



7481
7482
7483
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7481

def logging_stopped_event
  @logging_stopped_event
end

#lost_mode_location_eventGoogle::Apis::AndroidmanagementV1::LostModeLocationEvent

A lost mode event containing the device location and battery level as a percentage. Corresponds to the JSON property lostModeLocationEvent



7487
7488
7489
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7487

def lost_mode_location_event
  @lost_mode_location_event
end

#lost_mode_outgoing_phone_call_eventGoogle::Apis::AndroidmanagementV1::LostModeOutgoingPhoneCallEvent

An event indicating an outgoing phone call has been made when a device is in lost mode. Intentionally empty. Corresponds to the JSON property lostModeOutgoingPhoneCallEvent



7493
7494
7495
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7493

def lost_mode_outgoing_phone_call_event
  @lost_mode_outgoing_phone_call_event
end

#media_mount_eventGoogle::Apis::AndroidmanagementV1::MediaMountEvent

Removable media was mounted. Corresponds to the JSON property mediaMountEvent



7498
7499
7500
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7498

def media_mount_event
  @media_mount_event
end

#media_unmount_eventGoogle::Apis::AndroidmanagementV1::MediaUnmountEvent

Removable media was unmounted. Corresponds to the JSON property mediaUnmountEvent



7503
7504
7505
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7503

def media_unmount_event
  @media_unmount_event
end

#os_shutdown_eventGoogle::Apis::AndroidmanagementV1::OsShutdownEvent

Device was shutdown. Intentionally empty. Corresponds to the JSON property osShutdownEvent



7508
7509
7510
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7508

def os_shutdown_event
  @os_shutdown_event
end

#os_startup_eventGoogle::Apis::AndroidmanagementV1::OsStartupEvent

Device was started. Corresponds to the JSON property osStartupEvent



7513
7514
7515
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7513

def os_startup_event
  @os_startup_event
end

#remote_lock_eventGoogle::Apis::AndroidmanagementV1::RemoteLockEvent

The device or profile has been remotely locked via the LOCK command. Corresponds to the JSON property remoteLockEvent



7518
7519
7520
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7518

def remote_lock_event
  @remote_lock_event
end

#stop_lost_mode_user_attempt_eventGoogle::Apis::AndroidmanagementV1::StopLostModeUserAttemptEvent

A lost mode event indicating the user has attempted to stop lost mode. Corresponds to the JSON property stopLostModeUserAttemptEvent



7523
7524
7525
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7523

def stop_lost_mode_user_attempt_event
  @stop_lost_mode_user_attempt_event
end

#wipe_failure_eventGoogle::Apis::AndroidmanagementV1::WipeFailureEvent

The work profile or company-owned device failed to wipe when requested. This could be user initiated or admin initiated e.g. delete was received. Intentionally empty. Corresponds to the JSON property wipeFailureEvent



7530
7531
7532
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7530

def wipe_failure_event
  @wipe_failure_event
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7537

def update!(**args)
  @adb_shell_command_event = args[:adb_shell_command_event] if args.key?(:adb_shell_command_event)
  @adb_shell_interactive_event = args[:adb_shell_interactive_event] if args.key?(:adb_shell_interactive_event)
  @app_process_start_event = args[:app_process_start_event] if args.key?(:app_process_start_event)
  @backup_service_toggled_event = args[:backup_service_toggled_event] if args.key?(:backup_service_toggled_event)
  @cert_authority_installed_event = args[:cert_authority_installed_event] if args.key?(:cert_authority_installed_event)
  @cert_authority_removed_event = args[:cert_authority_removed_event] if args.key?(:cert_authority_removed_event)
  @cert_validation_failure_event = args[:cert_validation_failure_event] if args.key?(:cert_validation_failure_event)
  @connect_event = args[:connect_event] if args.key?(:connect_event)
  @crypto_self_test_completed_event = args[:crypto_self_test_completed_event] if args.key?(:crypto_self_test_completed_event)
  @dns_event = args[:dns_event] if args.key?(:dns_event)
  @enrollment_complete_event = args[:enrollment_complete_event] if args.key?(:enrollment_complete_event)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @file_pulled_event = args[:file_pulled_event] if args.key?(:file_pulled_event)
  @file_pushed_event = args[:file_pushed_event] if args.key?(:file_pushed_event)
  @key_destruction_event = args[:key_destruction_event] if args.key?(:key_destruction_event)
  @key_generated_event = args[:key_generated_event] if args.key?(:key_generated_event)
  @key_import_event = args[:key_import_event] if args.key?(:key_import_event)
  @key_integrity_violation_event = args[:key_integrity_violation_event] if args.key?(:key_integrity_violation_event)
  @keyguard_dismiss_auth_attempt_event = args[:keyguard_dismiss_auth_attempt_event] if args.key?(:keyguard_dismiss_auth_attempt_event)
  @keyguard_dismissed_event = args[:keyguard_dismissed_event] if args.key?(:keyguard_dismissed_event)
  @keyguard_secured_event = args[:keyguard_secured_event] if args.key?(:keyguard_secured_event)
  @log_buffer_size_critical_event = args[:log_buffer_size_critical_event] if args.key?(:log_buffer_size_critical_event)
  @logging_started_event = args[:logging_started_event] if args.key?(:logging_started_event)
  @logging_stopped_event = args[:logging_stopped_event] if args.key?(:logging_stopped_event)
  @lost_mode_location_event = args[:lost_mode_location_event] if args.key?(:lost_mode_location_event)
  @lost_mode_outgoing_phone_call_event = args[:lost_mode_outgoing_phone_call_event] if args.key?(:lost_mode_outgoing_phone_call_event)
  @media_mount_event = args[:media_mount_event] if args.key?(:media_mount_event)
  @media_unmount_event = args[:media_unmount_event] if args.key?(:media_unmount_event)
  @os_shutdown_event = args[:os_shutdown_event] if args.key?(:os_shutdown_event)
  @os_startup_event = args[:os_startup_event] if args.key?(:os_startup_event)
  @remote_lock_event = args[:remote_lock_event] if args.key?(:remote_lock_event)
  @stop_lost_mode_user_attempt_event = args[:stop_lost_mode_user_attempt_event] if args.key?(:stop_lost_mode_user_attempt_event)
  @wipe_failure_event = args[:wipe_failure_event] if args.key?(:wipe_failure_event)
end