Class: Google::Apis::AndroidmanagementV1::UsageLogEvent
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::UsageLogEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
An event logged on the device.
Instance Attribute Summary collapse
-
#adb_shell_command_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellCommandEvent
A shell command was issued over ADB via “adb shell command”.
-
#adb_shell_interactive_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellInteractiveEvent
An ADB interactive shell was opened via “adb shell”.
-
#app_process_start_event ⇒ Google::Apis::AndroidmanagementV1::AppProcessStartEvent
An app process was started.
-
#backup_service_toggled_event ⇒ Google::Apis::AndroidmanagementV1::BackupServiceToggledEvent
An admin has enabled or disabled backup service.
-
#cert_authority_installed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityInstalledEvent
A new root certificate was installed into the system's trusted credential storage.
-
#cert_authority_removed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityRemovedEvent
A root certificate was removed from the system's trusted credential storage.
-
#cert_validation_failure_event ⇒ Google::Apis::AndroidmanagementV1::CertValidationFailureEvent
An X.509v3 certificate failed to validate, currently this validation is performed on the Wi-FI access point and failure may be due to a mismatch upon server certificate validation.
-
#connect_event ⇒ Google::Apis::AndroidmanagementV1::ConnectEvent
A TCP connect event was initiated through the standard network stack.
-
#crypto_self_test_completed_event ⇒ Google::Apis::AndroidmanagementV1::CryptoSelfTestCompletedEvent
Validates whether Android’s built-in cryptographic library (BoringSSL) is valid.
-
#dns_event ⇒ Google::Apis::AndroidmanagementV1::DnsEvent
A DNS lookup event was initiated through the standard network stack.
-
#enrollment_complete_event ⇒ Google::Apis::AndroidmanagementV1::EnrollmentCompleteEvent
Represents that the device has completed enrollment.
-
#event_id ⇒ Fixnum
Unique id of the event.
-
#event_time ⇒ String
Device timestamp when the event was logged.
-
#event_type ⇒ String
The particular usage log event type that was reported on the device.
-
#file_pulled_event ⇒ Google::Apis::AndroidmanagementV1::FilePulledEvent
A file was downloaded from the device.
-
#file_pushed_event ⇒ Google::Apis::AndroidmanagementV1::FilePushedEvent
A file was uploaded onto the device.
-
#key_destruction_event ⇒ Google::Apis::AndroidmanagementV1::KeyDestructionEvent
A cryptographic key including user installed, admin installed and system maintained private key is removed from the device either by the user or management.
-
#key_generated_event ⇒ Google::Apis::AndroidmanagementV1::KeyGeneratedEvent
A cryptographic key including user installed, admin installed and system maintained private key is installed on the device either by the user or management.This is available device-wide on fully managed devices and within the work profile on organization-owned devices with a work profile.
-
#key_import_event ⇒ Google::Apis::AndroidmanagementV1::KeyImportEvent
A cryptographic key including user installed, admin installed and system maintained private key is imported on the device either by the user or management.
-
#key_integrity_violation_event ⇒ Google::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent
A cryptographic key including user installed, admin installed and system maintained private key is determined to be corrupted due to storage corruption, hardware failure or some OS issue.
-
#keyguard_dismiss_auth_attempt_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissAuthAttemptEvent
An attempt was made to unlock the device.
-
#keyguard_dismissed_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissedEvent
The keyguard was dismissed.
-
#keyguard_secured_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardSecuredEvent
The device was locked either by user or timeout.
-
#log_buffer_size_critical_event ⇒ Google::Apis::AndroidmanagementV1::LogBufferSizeCriticalEvent
The usageLog buffer on the device has reached 90% of its capacity, therefore older events may be dropped.
-
#logging_started_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStartedEvent
usageLog policy has been enabled.
-
#logging_stopped_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStoppedEvent
usageLog policy has been disabled.
-
#lost_mode_location_event ⇒ Google::Apis::AndroidmanagementV1::LostModeLocationEvent
A lost mode event containing the device location and battery level as a percentage.
-
#lost_mode_outgoing_phone_call_event ⇒ Google::Apis::AndroidmanagementV1::LostModeOutgoingPhoneCallEvent
An event indicating an outgoing phone call has been made when a device is in lost mode.
-
#media_mount_event ⇒ Google::Apis::AndroidmanagementV1::MediaMountEvent
Removable media was mounted.
-
#media_unmount_event ⇒ Google::Apis::AndroidmanagementV1::MediaUnmountEvent
Removable media was unmounted.
-
#os_shutdown_event ⇒ Google::Apis::AndroidmanagementV1::OsShutdownEvent
Device was shutdown.
-
#os_startup_event ⇒ Google::Apis::AndroidmanagementV1::OsStartupEvent
Device was started.
-
#remote_lock_event ⇒ Google::Apis::AndroidmanagementV1::RemoteLockEvent
The device or profile has been remotely locked via the LOCK command.
-
#stop_lost_mode_user_attempt_event ⇒ Google::Apis::AndroidmanagementV1::StopLostModeUserAttemptEvent
A lost mode event indicating the user has attempted to stop lost mode.
-
#wipe_failure_event ⇒ Google::Apis::AndroidmanagementV1::WipeFailureEvent
The work profile or company-owned device failed to wipe when requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageLogEvent
constructor
A new instance of UsageLogEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageLogEvent
Returns a new instance of UsageLogEvent.
7485 7486 7487 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adb_shell_command_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellCommandEvent
A shell command was issued over ADB via “adb shell command”.
Corresponds to the JSON property adbShellCommandEvent
7281 7282 7283 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7281 def adb_shell_command_event @adb_shell_command_event end |
#adb_shell_interactive_event ⇒ Google::Apis::AndroidmanagementV1::AdbShellInteractiveEvent
An ADB interactive shell was opened via “adb shell”. Intentionally empty.
Corresponds to the JSON property adbShellInteractiveEvent
7286 7287 7288 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7286 def adb_shell_interactive_event @adb_shell_interactive_event end |
#app_process_start_event ⇒ Google::Apis::AndroidmanagementV1::AppProcessStartEvent
An app process was started. This is available device-wide on fully managed
devices and within the work profile on organization-owned devices with a work
profile.
Corresponds to the JSON property appProcessStartEvent
7293 7294 7295 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7293 def app_process_start_event @app_process_start_event end |
#backup_service_toggled_event ⇒ Google::Apis::AndroidmanagementV1::BackupServiceToggledEvent
An admin has enabled or disabled backup service.
Corresponds to the JSON property backupServiceToggledEvent
7298 7299 7300 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7298 def backup_service_toggled_event @backup_service_toggled_event end |
#cert_authority_installed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityInstalledEvent
A new root certificate was installed into the system's trusted credential
storage. This is available device-wide on fully managed devices and within the
work profile on organization-owned devices with a work profile.
Corresponds to the JSON property certAuthorityInstalledEvent
7305 7306 7307 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7305 def @cert_authority_installed_event end |
#cert_authority_removed_event ⇒ Google::Apis::AndroidmanagementV1::CertAuthorityRemovedEvent
A root certificate was removed from the system's trusted credential storage.
This is available device-wide on fully managed devices and within the work
profile on organization-owned devices with a work profile.
Corresponds to the JSON property certAuthorityRemovedEvent
7312 7313 7314 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7312 def @cert_authority_removed_event end |
#cert_validation_failure_event ⇒ Google::Apis::AndroidmanagementV1::CertValidationFailureEvent
An X.509v3 certificate failed to validate, currently this validation is
performed on the Wi-FI access point and failure may be due to a mismatch upon
server certificate validation. However it may in the future include other
validation events of an X.509v3 certificate.
Corresponds to the JSON property certValidationFailureEvent
7320 7321 7322 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7320 def cert_validation_failure_event @cert_validation_failure_event end |
#connect_event ⇒ Google::Apis::AndroidmanagementV1::ConnectEvent
A TCP connect event was initiated through the standard network stack.
Corresponds to the JSON property connectEvent
7325 7326 7327 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7325 def connect_event @connect_event end |
#crypto_self_test_completed_event ⇒ Google::Apis::AndroidmanagementV1::CryptoSelfTestCompletedEvent
Validates whether Android’s built-in cryptographic library (BoringSSL) is
valid. Should always succeed on device boot, if it fails, the device should be
considered untrusted.
Corresponds to the JSON property cryptoSelfTestCompletedEvent
7332 7333 7334 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7332 def crypto_self_test_completed_event @crypto_self_test_completed_event end |
#dns_event ⇒ Google::Apis::AndroidmanagementV1::DnsEvent
A DNS lookup event was initiated through the standard network stack.
Corresponds to the JSON property dnsEvent
7337 7338 7339 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7337 def dns_event @dns_event end |
#enrollment_complete_event ⇒ Google::Apis::AndroidmanagementV1::EnrollmentCompleteEvent
Represents that the device has completed enrollment. User should be in the
launcher at this point, device at this point will be compliant and all setup
steps have been completed. Intentionally empty.
Corresponds to the JSON property enrollmentCompleteEvent
7344 7345 7346 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7344 def enrollment_complete_event @enrollment_complete_event end |
#event_id ⇒ Fixnum
Unique id of the event.
Corresponds to the JSON property eventId
7349 7350 7351 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7349 def event_id @event_id end |
#event_time ⇒ String
Device timestamp when the event was logged.
Corresponds to the JSON property eventTime
7354 7355 7356 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7354 def event_time @event_time end |
#event_type ⇒ String
The particular usage log event type that was reported on the device. Use this
to determine which event field to access.
Corresponds to the JSON property eventType
7360 7361 7362 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7360 def event_type @event_type end |
#file_pulled_event ⇒ Google::Apis::AndroidmanagementV1::FilePulledEvent
A file was downloaded from the device.
Corresponds to the JSON property filePulledEvent
7365 7366 7367 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7365 def file_pulled_event @file_pulled_event end |
#file_pushed_event ⇒ Google::Apis::AndroidmanagementV1::FilePushedEvent
A file was uploaded onto the device.
Corresponds to the JSON property filePushedEvent
7370 7371 7372 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7370 def file_pushed_event @file_pushed_event end |
#key_destruction_event ⇒ Google::Apis::AndroidmanagementV1::KeyDestructionEvent
A cryptographic key including user installed, admin installed and system
maintained private key is removed from the device either by the user or
management. This is available device-wide on fully managed devices and within
the work profile on organization-owned devices with a work profile.
Corresponds to the JSON property keyDestructionEvent
7378 7379 7380 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7378 def key_destruction_event @key_destruction_event end |
#key_generated_event ⇒ Google::Apis::AndroidmanagementV1::KeyGeneratedEvent
A cryptographic key including user installed, admin installed and system
maintained private key is installed on the device either by the user or
management.This is available device-wide on fully managed devices and within
the work profile on organization-owned devices with a work profile.
Corresponds to the JSON property keyGeneratedEvent
7386 7387 7388 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7386 def key_generated_event @key_generated_event end |
#key_import_event ⇒ Google::Apis::AndroidmanagementV1::KeyImportEvent
A cryptographic key including user installed, admin installed and system
maintained private key is imported on the device either by the user or
management. This is available device-wide on fully managed devices and within
the work profile on organization-owned devices with a work profile.
Corresponds to the JSON property keyImportEvent
7394 7395 7396 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7394 def key_import_event @key_import_event end |
#key_integrity_violation_event ⇒ Google::Apis::AndroidmanagementV1::KeyIntegrityViolationEvent
A cryptographic key including user installed, admin installed and system
maintained private key is determined to be corrupted due to storage corruption,
hardware failure or some OS issue. This is available device-wide on fully
managed devices and within the work profile on organization-owned devices with
a work profile.
Corresponds to the JSON property keyIntegrityViolationEvent
7403 7404 7405 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7403 def key_integrity_violation_event @key_integrity_violation_event end |
#keyguard_dismiss_auth_attempt_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissAuthAttemptEvent
An attempt was made to unlock the device.
Corresponds to the JSON property keyguardDismissAuthAttemptEvent
7408 7409 7410 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7408 def keyguard_dismiss_auth_attempt_event @keyguard_dismiss_auth_attempt_event end |
#keyguard_dismissed_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardDismissedEvent
The keyguard was dismissed. Intentionally empty.
Corresponds to the JSON property keyguardDismissedEvent
7413 7414 7415 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7413 def keyguard_dismissed_event @keyguard_dismissed_event end |
#keyguard_secured_event ⇒ Google::Apis::AndroidmanagementV1::KeyguardSecuredEvent
The device was locked either by user or timeout. Intentionally empty.
Corresponds to the JSON property keyguardSecuredEvent
7418 7419 7420 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7418 def keyguard_secured_event @keyguard_secured_event end |
#log_buffer_size_critical_event ⇒ Google::Apis::AndroidmanagementV1::LogBufferSizeCriticalEvent
The usageLog buffer on the device has reached 90% of its capacity, therefore
older events may be dropped. Intentionally empty.
Corresponds to the JSON property logBufferSizeCriticalEvent
7424 7425 7426 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7424 def log_buffer_size_critical_event @log_buffer_size_critical_event end |
#logging_started_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStartedEvent
usageLog policy has been enabled. Intentionally empty.
Corresponds to the JSON property loggingStartedEvent
7429 7430 7431 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7429 def logging_started_event @logging_started_event end |
#logging_stopped_event ⇒ Google::Apis::AndroidmanagementV1::LoggingStoppedEvent
usageLog policy has been disabled. Intentionally empty.
Corresponds to the JSON property loggingStoppedEvent
7434 7435 7436 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7434 def logging_stopped_event @logging_stopped_event end |
#lost_mode_location_event ⇒ Google::Apis::AndroidmanagementV1::LostModeLocationEvent
A lost mode event containing the device location and battery level as a
percentage.
Corresponds to the JSON property lostModeLocationEvent
7440 7441 7442 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7440 def lost_mode_location_event @lost_mode_location_event end |
#lost_mode_outgoing_phone_call_event ⇒ Google::Apis::AndroidmanagementV1::LostModeOutgoingPhoneCallEvent
An event indicating an outgoing phone call has been made when a device is in
lost mode. Intentionally empty.
Corresponds to the JSON property lostModeOutgoingPhoneCallEvent
7446 7447 7448 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7446 def lost_mode_outgoing_phone_call_event @lost_mode_outgoing_phone_call_event end |
#media_mount_event ⇒ Google::Apis::AndroidmanagementV1::MediaMountEvent
Removable media was mounted.
Corresponds to the JSON property mediaMountEvent
7451 7452 7453 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7451 def media_mount_event @media_mount_event end |
#media_unmount_event ⇒ Google::Apis::AndroidmanagementV1::MediaUnmountEvent
Removable media was unmounted.
Corresponds to the JSON property mediaUnmountEvent
7456 7457 7458 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7456 def media_unmount_event @media_unmount_event end |
#os_shutdown_event ⇒ Google::Apis::AndroidmanagementV1::OsShutdownEvent
Device was shutdown. Intentionally empty.
Corresponds to the JSON property osShutdownEvent
7461 7462 7463 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7461 def os_shutdown_event @os_shutdown_event end |
#os_startup_event ⇒ Google::Apis::AndroidmanagementV1::OsStartupEvent
Device was started.
Corresponds to the JSON property osStartupEvent
7466 7467 7468 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7466 def os_startup_event @os_startup_event end |
#remote_lock_event ⇒ Google::Apis::AndroidmanagementV1::RemoteLockEvent
The device or profile has been remotely locked via the LOCK command.
Corresponds to the JSON property remoteLockEvent
7471 7472 7473 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7471 def remote_lock_event @remote_lock_event end |
#stop_lost_mode_user_attempt_event ⇒ Google::Apis::AndroidmanagementV1::StopLostModeUserAttemptEvent
A lost mode event indicating the user has attempted to stop lost mode.
Corresponds to the JSON property stopLostModeUserAttemptEvent
7476 7477 7478 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7476 def stop_lost_mode_user_attempt_event @stop_lost_mode_user_attempt_event end |
#wipe_failure_event ⇒ Google::Apis::AndroidmanagementV1::WipeFailureEvent
The work profile or company-owned device failed to wipe when requested. This
could be user initiated or admin initiated e.g. delete was received.
Intentionally empty.
Corresponds to the JSON property wipeFailureEvent
7483 7484 7485 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7483 def wipe_failure_event @wipe_failure_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 7509 7510 7511 7512 7513 7514 7515 7516 7517 7518 7519 7520 7521 7522 7523 7524 7525 7526 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7490 def update!(**args) @adb_shell_command_event = args[:adb_shell_command_event] if args.key?(:adb_shell_command_event) @adb_shell_interactive_event = args[:adb_shell_interactive_event] if args.key?(:adb_shell_interactive_event) @app_process_start_event = args[:app_process_start_event] if args.key?(:app_process_start_event) @backup_service_toggled_event = args[:backup_service_toggled_event] if args.key?(:backup_service_toggled_event) @cert_authority_installed_event = args[:cert_authority_installed_event] if args.key?(:cert_authority_installed_event) @cert_authority_removed_event = args[:cert_authority_removed_event] if args.key?(:cert_authority_removed_event) @cert_validation_failure_event = args[:cert_validation_failure_event] if args.key?(:cert_validation_failure_event) @connect_event = args[:connect_event] if args.key?(:connect_event) @crypto_self_test_completed_event = args[:crypto_self_test_completed_event] if args.key?(:crypto_self_test_completed_event) @dns_event = args[:dns_event] if args.key?(:dns_event) @enrollment_complete_event = args[:enrollment_complete_event] if args.key?(:enrollment_complete_event) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @event_type = args[:event_type] if args.key?(:event_type) @file_pulled_event = args[:file_pulled_event] if args.key?(:file_pulled_event) @file_pushed_event = args[:file_pushed_event] if args.key?(:file_pushed_event) @key_destruction_event = args[:key_destruction_event] if args.key?(:key_destruction_event) @key_generated_event = args[:key_generated_event] if args.key?(:key_generated_event) @key_import_event = args[:key_import_event] if args.key?(:key_import_event) @key_integrity_violation_event = args[:key_integrity_violation_event] if args.key?(:key_integrity_violation_event) @keyguard_dismiss_auth_attempt_event = args[:keyguard_dismiss_auth_attempt_event] if args.key?(:keyguard_dismiss_auth_attempt_event) @keyguard_dismissed_event = args[:keyguard_dismissed_event] if args.key?(:keyguard_dismissed_event) @keyguard_secured_event = args[:keyguard_secured_event] if args.key?(:keyguard_secured_event) @log_buffer_size_critical_event = args[:log_buffer_size_critical_event] if args.key?(:log_buffer_size_critical_event) @logging_started_event = args[:logging_started_event] if args.key?(:logging_started_event) @logging_stopped_event = args[:logging_stopped_event] if args.key?(:logging_stopped_event) @lost_mode_location_event = args[:lost_mode_location_event] if args.key?(:lost_mode_location_event) @lost_mode_outgoing_phone_call_event = args[:lost_mode_outgoing_phone_call_event] if args.key?(:lost_mode_outgoing_phone_call_event) @media_mount_event = args[:media_mount_event] if args.key?(:media_mount_event) @media_unmount_event = args[:media_unmount_event] if args.key?(:media_unmount_event) @os_shutdown_event = args[:os_shutdown_event] if args.key?(:os_shutdown_event) @os_startup_event = args[:os_startup_event] if args.key?(:os_startup_event) @remote_lock_event = args[:remote_lock_event] if args.key?(:remote_lock_event) @stop_lost_mode_user_attempt_event = args[:stop_lost_mode_user_attempt_event] if args.key?(:stop_lost_mode_user_attempt_event) @wipe_failure_event = args[:wipe_failure_event] if args.key?(:wipe_failure_event) end |