Class: Google::Apis::AndroidmanagementV1::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A user belonging to an enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



7686
7687
7688
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_identifierString

A unique identifier you create for this user, such as user342 or asset#44418. This field must be set when the user is created and can't be updated. This field must not contain personally identifiable information (PII). This identifier must be 1024 characters or less; otherwise, the update policy request will fail. Corresponds to the JSON property accountIdentifier

Returns:

  • (String)


7684
7685
7686
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7684

def 
  @account_identifier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7691
7692
7693
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7691

def update!(**args)
  @account_identifier = args[:account_identifier] if args.key?(:account_identifier)
end