Class: Google::Apis::AndroidmanagementV1::WebApp
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::WebApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A web app.
Instance Attribute Summary collapse
-
#display_mode ⇒ String
The display mode of the web app.
-
#icons ⇒ Array<Google::Apis::AndroidmanagementV1::WebAppIcon>
A list of icons for the web app.
-
#name ⇒ String
The name of the web app, which is generated by the server during creation in the form enterprises/
enterpriseId/webApps/packageName. -
#start_url ⇒ String
The start URL, i.e.
-
#title ⇒ String
The title of the web app as displayed to the user (e.g., amongst a list of other applications, or as a label for an icon).
-
#version_code ⇒ Fixnum
The current version of the app.Note that the version can automatically increase during the lifetime of the web app, while Google does internal housekeeping to keep the web app up-to-date.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WebApp
constructor
A new instance of WebApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WebApp
Returns a new instance of WebApp.
7621 7622 7623 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_mode ⇒ String
The display mode of the web app.
Corresponds to the JSON property displayMode
7589 7590 7591 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7589 def display_mode @display_mode end |
#icons ⇒ Array<Google::Apis::AndroidmanagementV1::WebAppIcon>
A list of icons for the web app. Must have at least one element.
Corresponds to the JSON property icons
7594 7595 7596 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7594 def icons @icons end |
#name ⇒ String
The name of the web app, which is generated by the server during creation in
the form enterprises/enterpriseId/webApps/packageName.
Corresponds to the JSON property name
7600 7601 7602 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7600 def name @name end |
#start_url ⇒ String
The start URL, i.e. the URL that should load when the user opens the
application.
Corresponds to the JSON property startUrl
7606 7607 7608 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7606 def start_url @start_url end |
#title ⇒ String
The title of the web app as displayed to the user (e.g., amongst a list of
other applications, or as a label for an icon).
Corresponds to the JSON property title
7612 7613 7614 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7612 def title @title end |
#version_code ⇒ Fixnum
The current version of the app.Note that the version can automatically
increase during the lifetime of the web app, while Google does internal
housekeeping to keep the web app up-to-date.
Corresponds to the JSON property versionCode
7619 7620 7621 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7619 def version_code @version_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7626 7627 7628 7629 7630 7631 7632 7633 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7626 def update!(**args) @display_mode = args[:display_mode] if args.key?(:display_mode) @icons = args[:icons] if args.key?(:icons) @name = args[:name] if args.key?(:name) @start_url = args[:start_url] if args.key?(:start_url) @title = args[:title] if args.key?(:title) @version_code = args[:version_code] if args.key?(:version_code) end |