Class: Google::Apis::AndroidmanagementV1::WebToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

A web token used to access the managed Google Play iframe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebToken

Returns a new instance of WebToken.



7744
7745
7746
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabled_featuresArray<String>

The features to enable. Use this if you want to control exactly which feature( s) will be activated; leave empty to allow all features.Restrictions / things to note: - If no features are listed here, all features are enabled — this is the default behavior where you give access to all features to your admins. - This must not contain any FEATURE_UNSPECIFIED values. - Repeated values are ignored Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


7717
7718
7719
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7717

def enabled_features
  @enabled_features
end

#nameString

The name of the web token, which is generated by the server during creation in the form enterprises/enterpriseId/webTokens/webTokenId. Corresponds to the JSON property name

Returns:

  • (String)


7723
7724
7725
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7723

def name
  @name
end

#parent_frame_urlString

The URL of the parent frame hosting the iframe with the embedded UI. To prevent XSS, the iframe may not be hosted at other URLs. The URL must use the https scheme. Corresponds to the JSON property parentFrameUrl

Returns:

  • (String)


7730
7731
7732
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7730

def parent_frame_url
  @parent_frame_url
end

#permissionsArray<String>

Permissions available to an admin in the embedded UI. An admin must have all of these permissions in order to view the UI. This field is deprecated. Corresponds to the JSON property permissions

Returns:

  • (Array<String>)


7736
7737
7738
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7736

def permissions
  @permissions
end

#valueString

The token value which is used in the hosting page to generate the iframe with the embedded UI. This is a read-only field generated by the server. Corresponds to the JSON property value

Returns:

  • (String)


7742
7743
7744
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7742

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7749
7750
7751
7752
7753
7754
7755
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7749

def update!(**args)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @name = args[:name] if args.key?(:name)
  @parent_frame_url = args[:parent_frame_url] if args.key?(:parent_frame_url)
  @permissions = args[:permissions] if args.key?(:permissions)
  @value = args[:value] if args.key?(:value)
end