Class: Google::Apis::AndroidmanagementV1::WebToken
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::WebToken
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
A web token used to access the managed Google Play iframe.
Instance Attribute Summary collapse
-
#enabled_features ⇒ Array<String>
The features to enable.
-
#name ⇒ String
The name of the web token, which is generated by the server during creation in the form enterprises/
enterpriseId/webTokens/webTokenId. -
#parent_frame_url ⇒ String
The URL of the parent frame hosting the iframe with the embedded UI.
-
#permissions ⇒ Array<String>
Permissions available to an admin in the embedded UI.
-
#value ⇒ String
The token value which is used in the hosting page to generate the iframe with the embedded UI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WebToken
constructor
A new instance of WebToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WebToken
Returns a new instance of WebToken.
7697 7698 7699 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_features ⇒ Array<String>
The features to enable. Use this if you want to control exactly which feature(
s) will be activated; leave empty to allow all features.Restrictions / things
to note: - If no features are listed here, all features are enabled — this is
the default behavior where you give access to all features to your admins. -
This must not contain any FEATURE_UNSPECIFIED values. - Repeated values are
ignored
Corresponds to the JSON property enabledFeatures
7670 7671 7672 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7670 def enabled_features @enabled_features end |
#name ⇒ String
The name of the web token, which is generated by the server during creation in
the form enterprises/enterpriseId/webTokens/webTokenId.
Corresponds to the JSON property name
7676 7677 7678 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7676 def name @name end |
#parent_frame_url ⇒ String
The URL of the parent frame hosting the iframe with the embedded UI. To
prevent XSS, the iframe may not be hosted at other URLs. The URL must use the
https scheme.
Corresponds to the JSON property parentFrameUrl
7683 7684 7685 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7683 def parent_frame_url @parent_frame_url end |
#permissions ⇒ Array<String>
Permissions available to an admin in the embedded UI. An admin must have all
of these permissions in order to view the UI. This field is deprecated.
Corresponds to the JSON property permissions
7689 7690 7691 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7689 def @permissions end |
#value ⇒ String
The token value which is used in the hosting page to generate the iframe with
the embedded UI. This is a read-only field generated by the server.
Corresponds to the JSON property value
7695 7696 7697 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7695 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7702 7703 7704 7705 7706 7707 7708 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7702 def update!(**args) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @name = args[:name] if args.key?(:name) @parent_frame_url = args[:parent_frame_url] if args.key?(:parent_frame_url) @permissions = args[:permissions] if args.key?(:permissions) @value = args[:value] if args.key?(:value) end |