Class: Google::Apis::AndroidmanagementV1::WorkAccountSetupConfig
- Inherits:
-
Object
- Object
- Google::Apis::AndroidmanagementV1::WorkAccountSetupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb
Overview
Controls the work account setup configuration, such as details of whether a Google authenticated account is required.
Instance Attribute Summary collapse
-
#authentication_type ⇒ String
Optional.
-
#required_account_email ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkAccountSetupConfig
constructor
A new instance of WorkAccountSetupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkAccountSetupConfig
Returns a new instance of WorkAccountSetupConfig.
8039 8040 8041 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8039 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_type ⇒ String
Optional. The authentication type of the user on the device.
Corresponds to the JSON property authenticationType
8028 8029 8030 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8028 def authentication_type @authentication_type end |
#required_account_email ⇒ String
Optional. The specific google work account email address to be added. This
field is only relevant if authenticationType is GOOGLE_AUTHENTICATED. This
must be an enterprise account and not a consumer account. Once set and a
Google authenticated account is added to the device, changing this field will
have no effect, and thus recommended to be set only once.
Corresponds to the JSON property requiredAccountEmail
8037 8038 8039 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8037 def required_account_email @required_account_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8044 8045 8046 8047 |
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8044 def update!(**args) @authentication_type = args[:authentication_type] if args.key?(:authentication_type) @required_account_email = args[:required_account_email] if args.key?(:required_account_email) end |