Class: Google::Apis::AndroidmanagementV1::WorkAccountSetupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls the work account setup configuration, such as details of whether a Google authenticated account is required.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkAccountSetupConfig

Returns a new instance of WorkAccountSetupConfig.



8034
8035
8036
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. The authentication type of the user on the device. Corresponds to the JSON property authenticationType

Returns:

  • (String)


8023
8024
8025
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8023

def authentication_type
  @authentication_type
end

#required_account_emailString

Optional. The specific google work account email address to be added. This field is only relevant if authenticationType is GOOGLE_AUTHENTICATED. This must be an enterprise account and not a consumer account. Once set and a Google authenticated account is added to the device, changing this field will have no effect, and thus recommended to be set only once. Corresponds to the JSON property requiredAccountEmail

Returns:

  • (String)


8032
8033
8034
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8032

def 
  @required_account_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8039
8040
8041
8042
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 8039

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @required_account_email = args[:required_account_email] if args.key?(:required_account_email)
end