Class: Google::Apis::AndroidmanagementV1::WorkAccountSetupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/androidmanagement_v1/classes.rb,
lib/google/apis/androidmanagement_v1/representations.rb,
lib/google/apis/androidmanagement_v1/representations.rb

Overview

Controls the work account setup configuration, such as details of whether a Google authenticated account is required.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkAccountSetupConfig

Returns a new instance of WorkAccountSetupConfig.



7896
7897
7898
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_typeString

Optional. The authentication type of the user on the device. Corresponds to the JSON property authenticationType

Returns:

  • (String)


7885
7886
7887
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7885

def authentication_type
  @authentication_type
end

#required_account_emailString

Optional. The specific google work account email address to be added. This field is only relevant if authenticationType is GOOGLE_AUTHENTICATED. This must be an enterprise account and not a consumer account. Once set and a Google authenticated account is added to the device, changing this field will have no effect, and thus recommended to be set only once. Corresponds to the JSON property requiredAccountEmail

Returns:

  • (String)


7894
7895
7896
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7894

def 
  @required_account_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7901
7902
7903
7904
# File 'lib/google/apis/androidmanagement_v1/classes.rb', line 7901

def update!(**args)
  @authentication_type = args[:authentication_type] if args.key?(:authentication_type)
  @required_account_email = args[:required_account_email] if args.key?(:required_account_email)
end